@@ -56,13 +56,14 @@
 if ( ! defined('ALLOWED')) define ('ALLOWED',1);
 
 require_once '../include/constant.php';
-require_once('class_database.php');
-require_once ('class_fiche.php');
-require_once('class_iradio.php');
-require_once('function_javascript.php');
-require_once('ac_common.php');
-require_once ('class_user.php');
-require_once ('class_fiche_attr.php');
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_fiche.php';
+require_once NOALYSS_INCLUDE.'/class_iradio.php';
+require_once NOALYSS_INCLUDE.'/function_javascript.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/class_user.php';
+require_once NOALYSS_INCLUDE.'/class_fiche_attr.php';
+
 mb_internal_encoding("UTF-8");
 
 $var=array('gDossier','op','ctl');
@@ -173,12 +174,13 @@ case 'dc':
 		$html.=HtmlInput::hidden('ctl',$ctl);
 	      }
 	    $html.=$card;
+            $html.='<p style="text-align:center">';
 	    if ( $can_modify==1)
 	      {
 		$html.=HtmlInput::submit('save',_('Sauver'));
 	      }
-	    $html.=HtmlInput::button('close_'.$ctl,'Fermer',"onclick=\"removeDiv('$ctl')\"");
 	    if ( ! isset ($nohistory))$html.=HtmlInput::history_card_button($f->id,_('Historique'));
+            $html.='</p>';
 	    if ($can_modify==1)
 	      {
 		$html.='</form>';
@@ -188,7 +190,6 @@ case 'dc':
     else
       {
       $html.='<h2 class="error">'._('Aucune fiche demandée').'</h2>';
-      $html.=HtmlInput::button('close_'.$ctl,_('Fermer'),"onclick=\"removeDiv('$ctl')\"");
       }
     break;
     /* ------------------------------------------------------------ */
@@ -208,7 +209,9 @@ case 'bc':
         $r.=HtmlInput::hidden('fd_id',$fd_id);
         $r.=HtmlInput::hidden('ctl',$ctl);
         $r.=$f->blank($fd_id);
+        $r.='<p style="text-align:center">';
         $r.=HtmlInput::submit('sc',_('Sauve'));
+        $r.='</p>';
         $r.='</form>';
         $html=$r;
     }
@@ -315,7 +318,7 @@ case 'st':
         }
         $r.='</table>';
         $r.=HtmlInput::hidden('fd_id',0);
-	$r.='<p>';
+        $r.='<p style="text-align:center">';
         $r.=HtmlInput::submit('st','choix');
 	$r.=HtmlInput::button('Annuler',_('Annuler')," onclick=\"removeDiv('$ctl')\" ");
 	$r.='</p>';
@@ -347,14 +350,13 @@ case 'sc':
     {
         $html.=alert(_('Action interdite'),true);
     }
-    $html.=HtmlInput::button('fermer',_('Fermer')," onclick=\"removeDiv('$ctl')\";");
     break;
     /*----------------------------------------------------------------------
      * Search a card
      *
      *----------------------------------------------------------------------*/
 case 'fs':
-    require_once('class_acc_ledger.php');
+    require_once NOALYSS_INCLUDE.'/class_acc_ledger.php';
     $r=HtmlInput::title_box(_("Détail fiche"), 'search_card');
     $r.='<form method="GET" onsubmit="this.ctl=\'ipop_card\';search_get_card(this);return false;">';
     $q=new IText('query');
@@ -425,14 +427,14 @@ case 'fs':
     }//foreach
 
     ob_start();
-    require_once('template/card_result.php');
+    require_once NOALYSS_INCLUDE.'/template/card_result.php';
     $r.=ob_get_contents();
     ob_end_clean();
     $ctl=$ctl.'_content';
     $html=$r;
     break;
     case 'action_add_concerned_card':
-        require_once 'ajax_add_concerned_card.php';
+        require_once NOALYSS_INCLUDE.'/ajax_add_concerned_card.php';
         return;
     break;
     case 'action_save_concerned':
@@ -468,9 +470,15 @@ case 'ac':
 	case FICHE_TYPE_CONTACT:
             $msg=_(' de contacts');
             $base='';
+            break;
         case FICHE_TYPE_FIN:
             $msg=_(' Banque');
             $base=$cn->get_value("select p_value from parm_code where p_code='BANQUE'");
+            break;
+        case FICHE_TYPE_EMPL:
+            $msg=_(' Employé ou administrateur');
+            $base='';
+            break;
          
         }
 
@@ -509,23 +517,23 @@ case 'scc':
     {
 		$script=create_script("removeDiv('$ctl')");
 		$html.=$script;
-        if ( strlen(trim($_GET['nom_mod'])) != 0 &&
-                strlen(trim($_GET['class_base'])) != 0 )
+        if ( strlen(trim($_GET['nom_mod'])) != 0 )
         {
             $array=array("FICHE_REF"=>$cat,
                          "nom_mod"=>$_GET['nom_mod'],
-                         "class_base"=>$_GET['class_base']);
+                         "class_base"=>$_GET['class_base'],
+                          "fd_description"=>$_GET['fd_description']);
             if ( isset ($_POST['create'])) $array['create']=1;
             $catcard=new Fiche_Def($cn);
             if ( $catcard->Add($array) == -1)
-                $script="alert('"._('Catégorie existe déjà')."')";
+                $script="alert_box('"._('Catégorie existe déjà')."')";
             else
-                $script="alert('"._('Catégorie sauvée')."')";
+                $script="alert_box('"._('Catégorie sauvée')."')";
             $html.=create_script($script);
         }
         else
         {
-            $script="alert('"._("Le nom et la classe base ne peuvent être vide")."')";
+            $script="alert_box('"._("Le nom ne peut pas être vide")."')";
             $html.=create_script($script);
 
             $invalid=1;
@@ -560,7 +568,6 @@ case 'upc':
 	  $html.=ob_get_contents();
 	  ob_end_clean();
 	  $html.=$f->Display(true);
-	  $html.=HtmlInput::button('close_'.$ctl,'Fermer',"onclick=\"removeDiv('$ctl')\"");
 	}
       }
 } // switch
