@@ -26,13 +26,13 @@
 if ( ! defined('ALLOWED')) define ('ALLOWED',1);
 
 require_once '../include/constant.php';
-require_once('class_database.php');
-require_once('class_user.php');
-require_once('class_dossier.php');
-require_once('class_periode.php');
-require_once('class_html_input.php');
-require_once('class_acc_account.php');
-require_once('class_exercice.php');
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_user.php';
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
+require_once NOALYSS_INCLUDE.'/class_periode.php';
+require_once NOALYSS_INCLUDE.'/class_html_input.php';
+require_once NOALYSS_INCLUDE.'/class_acc_account.php';
+require_once NOALYSS_INCLUDE.'/class_exercice.php';
 $div=$_REQUEST['div'];
 mb_internal_encoding("UTF-8");
 
@@ -43,6 +43,7 @@ ajax_disconnected($div);
 global $g_user,$cn;
 $cn=new Database(dossier::id());
 $g_user=new User($cn);
+set_language();
 /* security */
 if ( $g_user->check_dossier(dossier::id(),true) == 'X' ) exit();
 
@@ -122,7 +123,7 @@ if ( isset($_GET['f_id']))
 	  }
 
         ob_start();
-        require_once('template/history_top.php');
+        require_once NOALYSS_INCLUDE.'/template/history_top.php';
 	$detail_card=HtmlInput::card_detail($fiche->strAttribut(ATTR_DEF_QUICKCODE),$fiche->getName());
 	echo h2(  $fiche->getName().'['.$fiche->strAttribut(ATTR_DEF_QUICKCODE).']',' class="title" ');
 	echo '<p style="text-align:center;">'.$detail_card.'</p>';
@@ -194,7 +195,7 @@ if ( isset($_REQUEST['pcm_val']))
 	  }
 
         ob_start();
-        require_once('template/history_top.php');
+        require_once NOALYSS_INCLUDE.'/template/history_top.php';
 
         if ( $poste->HtmlTable($array) == -1)
 	  {
