@@ -31,16 +31,16 @@
 if ( ! defined('ALLOWED')) define ('ALLOWED',1);
 
 require_once '../include/constant.php';
-require_once('class_database.php');
-require_once('class_user.php');
-require_once('class_acc_operation.php');
-require_once('class_acc_ledger.php');
-require_once ('class_fiche.php');
-require_once('class_acc_reconciliation.php');
-require_once('class_anc_operation.php');
-require_once('class_idate.php');
-require_once 'class_own.php';
-require_once 'class_iconcerned.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_user.php';
+require_once NOALYSS_INCLUDE.'/class_acc_operation.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger.php';
+require_once NOALYSS_INCLUDE.'/class_fiche.php';
+require_once NOALYSS_INCLUDE.'/class_acc_reconciliation.php';
+require_once NOALYSS_INCLUDE.'/class_anc_operation.php';
+require_once NOALYSS_INCLUDE.'/class_idate.php';
+require_once NOALYSS_INCLUDE.'/class_own.php';
+require_once NOALYSS_INCLUDE.'/class_iconcerned.php';
 /**
  * Check if we receive the needed data (jr_id...)
  */
@@ -85,11 +85,12 @@ if ( LOGINPUT)
 // check if the user is valid and can access this folder
 global $g_user;
 $g_user=new User($cn);
+set_language();
 $g_user->check();
 if ( $g_user->check_dossier(dossier::id(),true)=='X' )
 {
     ob_start();
-    require_once ('template/ledger_detail_forbidden.php');
+    require_once  NOALYSS_INCLUDE.'/template/ledger_detail_forbidden.php';
 	echo HtmlInput::button_close($div);
     $html=ob_get_contents();
     ob_end_clean();
@@ -116,7 +117,7 @@ if ($ledger=="")
 
     ob_start();
 	echo HtmlInput::title_box(_("Information"), $div);
-    require_once ('template/ledger_detail_forbidden.php');
+    require_once NOALYSS_INCLUDE.'/template/ledger_detail_forbidden.php';
 	echo HtmlInput::button_close($div);
     $html=ob_get_contents();
     ob_end_clean();
@@ -138,7 +139,7 @@ if ( $access == 'X' )
 {
     ob_start();
 	echo HtmlInput::title_box(_("Information"), $div);
-    require_once ('template/ledger_detail_forbidden.php');
+    require_once NOALYSS_INCLUDE.'/template/ledger_detail_forbidden.php';
 	echo HtmlInput::button_close($div);
     $html=ob_get_contents();
     ob_end_clean();
@@ -160,7 +161,7 @@ switch ($action)
     //  remove op
     ///////////////////////////////////////////////////////////////////////////
 case 'rmop':
-        if ( $access=='W')
+        if ( $access=='W' && $g_user->check_action(RMOPER) == 1)
         {
             ob_start();
             /* get the ledger */
@@ -181,6 +182,10 @@ case 'rmop':
             $html=ob_get_contents();
             ob_end_clean();
         }
+        else 
+        {
+            $html= _("Effacement refusé");
+        }
     break;
     //////////////////////////////////////////////////////////////////////
     // DE Detail
@@ -190,26 +195,28 @@ case 'de':
 
     try
     {
-        $op->get();			/* get detail op (D/C) */
-        $obj=$op->get_quant();	/* return an obj. ACH / FIN or VEN or null if nothing is found*/
+        /* get detail op (D/C) */
+        $op->get();			
+        /* return an obj. ACH / FIN or VEN or null if nothing is found*/
+        $obj=$op->get_quant();	
 
         $oLedger=new Acc_Ledger($cn,$ledger);
         if ( $obj==null || $obj->signature == 'ODS'  )
         {
             /* only the details */
-            require_once('template/ledger_detail_misc.php');
+            require_once NOALYSS_INCLUDE.'/template/ledger_detail_misc.php';
         }
         elseif ( $obj->signature=='ACH')
         {
-            require_once('template/ledger_detail_ach.php');
+            require_once NOALYSS_INCLUDE.'/template/ledger_detail_ach.php';
         }
         elseif ($obj->signature=='FIN')
         {
-            require_once('template/ledger_detail_fin.php');
+            require_once NOALYSS_INCLUDE.'/template/ledger_detail_fin.php';
         }
         elseif ( $obj->signature=='VEN')
         {
-            require_once('template/ledger_detail_ven.php');
+            require_once NOALYSS_INCLUDE.'/template/ledger_detail_ven.php';
         }
     }
     catch (Exception $e)
@@ -227,22 +234,20 @@ case 'de':
 case 'file':
     $op->get();
     $obj=$op->get_quant();	/* return an obj. ACH / FIN or VEN or null if nothing is found*/
+    
+    $repo = new Database();
+    $theme = $repo->get_value("select the_filestyle from theme where the_name=$1", array($_SESSION['g_theme']));
+    html_min_page_start($theme);
 
+    // if there is a receipt document
     if ( $obj->det->jr_pj_name=='')
     {
-        echo "<html><head>";
-        $repo=new Database();
-        $theme=$repo->get_value("select the_filestyle from theme where the_name=$1",array($_SESSION['g_theme']));
-        echo    "<LINK REL=\"stylesheet\" type=\"text/css\" href=\"$theme\" media=\"screen\">";
- 		if ( ! isset($_REQUEST['ajax']) ) {
-			echo "<body class=\"op_detail_frame\">";
-			echo '<div class="op_detail_frame">';
-		}else {
-			echo "<body>";
-			echo "<div>";
+        if ( ! isset($_REQUEST['ajax']) ) {
+                echo '<div class="op_detail_frame">';
+        }else {
+                echo "<div>";
 
-		}
-		echo "<h1 class=\"legend\">Document</h1>";
+        }
         if ( $access=='W')
         {
             echo '<FORM METHOD="POST" ENCTYPE="multipart/form-data" id="form_file">';
@@ -261,51 +266,41 @@ case 'file':
         }
         else
         {
-				echo "<html><head>";
-				if (!isset($_REQUEST['ajax']))
-				{
-					echo "<body class=\"op_detail_frame\">";
-					echo '<div class="op_detail_frame">';
-				}
-				else
-				{
-					echo "<body>";
-					echo "<div>";
-				}
-				$repo = new Database();
-				$theme = $repo->get_value("select the_filestyle from theme where the_name=$1", array($_SESSION['g_theme']));
-				echo "   <LINK REL=\"stylesheet\" type=\"text/css\" href=\"$theme\" media=\"screen\">";
-				echo "</head>";
-				echo '<div class="op_detail_frame">';
+            if (!isset($_REQUEST['ajax']))
+            {
+                    echo '<div class="op_detail_frame">';
+            }
+            else
+            {
+                    echo "<div>";
+            }
+            
 
-				echo _('Aucun fichier');
-			}
-			echo '</div>';
-			echo '</body></html>';
-			exit();
+            echo _('Aucun fichier');
+    }
+    echo '</div>';
+    exit();
     }
     else
     {
-        echo "<html><head>";
-        $repo=new Database();
-        $theme=$repo->get_value("select the_filestyle from theme where the_name=$1",array($_SESSION['g_theme']));
-        echo    "   <LINK REL=\"stylesheet\" type=\"text/css\" href=\"$theme\" media=\"screen\">";
-        echo "</head>";
-		if ( ! isset($_REQUEST['ajax']) ) {
-			echo "<body class=\"op_detail_frame\">";
-			echo '<div class="op_detail_frame">';
-		}else {
-			echo "<body>";
-			echo "<div>";
+        // There is no document attached to this writing
+        //
+        if ( ! isset($_REQUEST['ajax']) ) {
+                echo '<div class="op_detail_frame">';
+        }else {
+                echo "<div>";
 
-		}
-		echo "<h1 class=\"legend\">"._("Document")."</h1>";
+        }
         echo '<div class="op_detail_frame">';
         $x='';
-        if ($access=='W')
-            $x=sprintf('<a class="notice" style="margin-left:12;margin-right:12" href="ajax_ledger.php?gDossier=%d&div=%s&jr_id=%s&act=rmf" onclick="return confirm(\'Effacer le document ?\')">'._('enlever').'</a>',
+        if ($access=='W' && $g_user->check_action (RMRECEIPT) == 1)
+        {
+            // Not possible to remove the file thanks a modal dialog box,
+            // because of the frameset
+            $x=sprintf('<a class="smallbutton" style="margin-left:12;margin-right:12" href="ajax_ledger.php?gDossier=%d&div=%s&jr_id=%s&act=rmf" onclick="return confirm(\'Effacer le document ?\')">'.SMALLX.'</a>',
                        $gDossier,$div,$jr_id);
-        echo $x;
+            
+        }  
         $filename= $obj->det->jr_pj_name;
         if ( strlen($obj->det->jr_pj_name) > 20 )
         {
@@ -314,6 +309,7 @@ case 'file':
         $h=sprintf('<a class="mtitle"  href="show_pj.php?gDossier=%d&jrn=%d&jr_grpt_id=%d">%s</a>',
                    $gDossier,$ledger,$obj->det->jr_grpt_id,h( $filename));
         echo $h;
+        echo $x;
         echo '</div>';
         echo '</body></html>';
         exit();
@@ -341,9 +337,15 @@ case 'loadfile':
 		if ( ! isset($_REQUEST['ajax']) ) echo "<body class=\"op_detail_frame\">"; else echo "<body>";
 		echo "<h2>"._("Document")."</h2>";
         echo '<div class="op_detail_frame">';
-        $x=sprintf('<a class="mtitle" class="notice" style="margin-left:12;margin-right:12px" href="ajax_ledger.php?gDossier=%d&div=%s&jr_id=%s&act=rmf" onclick="return confirm(\'Effacer le document ?\')">'._('enlever').'</a>',
+        
+        // check if the user can remove a document
+        if ($g_user->check_action (RMRECEIPT) == 1) {
+            // Not possible to remove the file thanks a modal dialog box,
+            // because of the frameset
+            $x=sprintf('<a class="mtitle" class="notice" style="margin-left:12;margin-right:12px" href="ajax_ledger.php?gDossier=%d&div=%s&jr_id=%s&act=rmf" onclick="return confirm(\'Effacer le document ?\')">'.SMALLX.'</a>',
                    $gDossier,$div,$jr_id);
-        echo $x;
+            echo $x;
+        }
         $filename= $obj->det->jr_pj_name;
         $h=sprintf('<a class="mtitle"  href="show_pj.php?gDossier=%d&jrn=%d&jr_grpt_id=%d">%s</a>',
                    $gDossier,$ledger,$obj->det->jr_grpt_id,h($filename));
@@ -356,7 +358,7 @@ case 'loadfile':
 // remove a file
 /////////////////////////////////////////////////////////////////////////////
 case 'rmf':
-    if (   $access == 'W' )
+    if (   $access == 'W' && $g_user->check_action (RMRECEIPT) == 1)
     {
         echo "<html><head>";
         $repo=new Database();
@@ -515,7 +517,8 @@ case 'save':
             // Save related
             //////////////////////////////////////////////////////////////////
             $related=HtmlInput::default_value_post("related", "0");
-            if ($related == "0" )                throw new Exception('Parameter not send -> related'.__FILE__.__LINE__,10);
+            if ($related == "0" )                
+                throw new Exception('Parameter not send -> related'.__FILE__.__LINE__,10);
             $op->insert_related_action($related);
 
         }
@@ -531,9 +534,9 @@ case 'save':
     ob_end_clean();
 
     break;
-/////////////////////////////////////////////////////////////////////////////
+    ////////////////////////////////////////////////////////////////////////////
     // remove a reconciliation
-/////////////////////////////////////////////////////////////////////////////
+    ////////////////////////////////////////////////////////////////////////////
 case 'rmr':
     if ( $access=='W')
     {
@@ -542,20 +545,25 @@ case 'rmr':
         $rec->remove($_GET['jr_id2']);
     }
     break;
-    ////////////////////////////////////////////////////////////////////////////////
+    ////////////////////////////////////////////////////////////////////////////
     // ask for a date for reversing the operation
+    ////////////////////////////////////////////////////////////////////////////
 case 'ask_extdate':
     $date=new IDate('p_date');
     $html.="<form id=\"form_".$div."\" onsubmit=\"return reverseOperation(this);\">";
-    $html.=HtmlInput::hidden('jr_id',$_REQUEST['jr_id']).HtmlInput::hidden('div',$div).dossier::hidden().HtmlInput::hidden('act','reverseop');
+    $html.=HtmlInput::hidden('jr_id',$_REQUEST['jr_id']).
+            HtmlInput::hidden('div',$div).
+            dossier::hidden().
+            HtmlInput::hidden('act','reverseop');
+    
     $html.='<h2 class="info">'._('entrez une date').' </H2>'.$date->input();
     $html.=HtmlInput::submit('x','accepter');
-	$html=HtmlInput::button_close($div);
+    $html.=HtmlInput::button_close($div);
     $html.='</form>';
     break;
-    ////////////////////////////////////////////////////////////////////////////////
+    ////////////////////////////////////////////////////////////////////////////
     // Reverse an operation
-    ////////////////////////////////////////////////////////////////////////////////
+    ////////////////////////////////////////////////////////////////////////////
 case 'reverseop':
     if ( $access=='W')
     {
