@@ -37,12 +37,12 @@
 if ( ! defined('ALLOWED')) define ('ALLOWED',1);
 
 require_once '../include/constant.php';
-require_once('class_database.php');
-require_once ('class_fiche.php');
-require_once('class_iradio.php');
-require_once('function_javascript.php');
-require_once('ac_common.php');
-require_once ('class_user.php');
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once  NOALYSS_INCLUDE.'/class_fiche.php';
+require_once NOALYSS_INCLUDE.'/class_iradio.php';
+require_once NOALYSS_INCLUDE.'/function_javascript.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once  NOALYSS_INCLUDE.'/class_user.php';
 mb_internal_encoding("UTF-8");
 
 $var = array('gDossier', 'op');
@@ -61,12 +61,23 @@ if ($cont != 0)
 extract($_REQUEST);
 set_language();
 global $g_user, $cn, $g_parameter;
-$cn = new Database($gDossier);
-$g_user = new User($cn);
-$g_user->check(true);
-$g_user->check_dossier($gDossier, true);
+//
+// If database id == 0 then we are not connected to a folder 
+// but to the administration
+// 
 if ($gDossier<>0) {
+    $cn = new Database($gDossier);
     $g_parameter=new Own($cn);
+    $g_user = new User($cn);
+    $g_user->check(true);
+    $g_user->check_dossier($gDossier, true);
+}
+else
+{
+    // connect to repository
+    $cn=new Database(); 
+    $g_user = new User($cn);
+    $g_user->check(true);
 }
 $html = var_export($_REQUEST, true);
 
@@ -90,6 +101,9 @@ if ( LOGINPUT)
     }
 switch ($op)
 {
+        case 'pcmn_update':
+            require 'ajax_pcmn_update.php';
+            return;
 	case "remove_anc":
 		if ($g_user->check_module('ANCODS') == 0)
 			exit();
@@ -98,7 +112,7 @@ switch ($op)
 	case "rm_stock":
 		if ($g_user->check_module('STOCK') == 0)
 			exit();
-		require_once('constant.security.php');
+		require_once NOALYSS_INCLUDE.'/constant.security.php';
 		$cn->exec_sql('delete from stock_goods where sg_id=$1', array($s_id));
 		$html = escape_xml($s_id);
 		header('Content-type: text/xml; charset=UTF-8');
@@ -108,7 +122,7 @@ switch ($op)
 	//--------------------------------------------------
 	// get the last date of a ledger
 	case 'lastdate':
-		require_once('class_acc_ledger_fin.php');
+		require_once NOALYSS_INCLUDE.'/class_acc_ledger_fin.php';
 		$ledger = new Acc_Ledger_Fin($cn, $_GET['p_jrn']);
 		$html = $ledger->get_last_date();
 		$html = escape_xml($html);
@@ -123,7 +137,7 @@ EOF;
 
 		break;
 	case 'bkname':
-		require_once('class_acc_ledger_fin.php');
+		require_once NOALYSS_INCLUDE.'/class_acc_ledger_fin.php';
 		$ledger = new Acc_Ledger_Fin($cn, $_GET['p_jrn']);
 		$html = $ledger->get_bank_name();
 		$html = escape_xml($html);
@@ -138,13 +152,13 @@ EOF;
 		break;
 	// display new calendar
 	case 'cal':
-		require_once('class_calendar.php');
+		require_once NOALYSS_INCLUDE.'/class_calendar.php';
 		/* others report */
 		$cal = new Calendar();
 		$cal->set_periode($per);
-
+                $notitle=HtmlInput::default_value_get("notitle", 0);
 		$html = "";
-		$html = $cal->display($_GET['t']);
+		$html = $cal->display($_GET['t'],$notitle);
 		$html = escape_xml($html);
 		header('Content-type: text/xml; charset=UTF-8');
 		echo <<<EOF
@@ -156,16 +170,19 @@ EOF;
 		break;
 	/* rem a cat of document */
 	case 'rem_cat_doc':
-		require_once('class_document_type.php');
+		require_once NOALYSS_INCLUDE.'/class_document_type.php';
 		// if user can not return error message
+                $message="";
 		if ($g_user->check_action(PARCATDOC) == 0)
 		{
 			$html = "nok";
+                        $message=_('Action non autorisée');
 			header('Content-type: text/xml; charset=UTF-8');
 			echo <<<EOF
 <?xml version="1.0" encoding="UTF-8"?>
 <data>
 <dtid>$html</dtid>
+<message>$message</message>                                
 </data>
 EOF;
 			return;
@@ -176,12 +193,14 @@ EOF;
 
 		if ($count_md != 0 || $count_a != 0)
 		{
+                    $message=_('Des actions dépendent de cette catégorie');
 			$html = "nok";
 			header('Content-type: text/xml; charset=UTF-8');
 			echo <<<EOF
 <?xml version="1.0" encoding="UTF-8"?>
 <data>
 <dtid>$html</dtid>
+<message>$message</message>                                
 </data>
 EOF;
 			exit;
@@ -191,14 +210,15 @@ EOF;
 		header('Content-type: text/xml; charset=UTF-8');
 		echo <<<EOF
 <?xml version="1.0" encoding="UTF-8"?>
-                                 <data>
-                                 <dtid>$html</dtid>
-                                 </data>
+<data>
+<dtid>$html</dtid>
+<message>$message</message>                                
+</data>
 EOF;
 		return;
 		break;
 	case 'mod_cat_doc':
-		require_once 'template/document_mod_change.php';
+		require_once NOALYSS_INCLUDE.'/template/document_mod_change.php';
 		break;
 	case 'dsp_tva':
 		$cn = new Database($gDossier);
@@ -208,8 +228,8 @@ EOF;
 		$r = HtmlInput::anchor_close('tva_select');
 		$r.=h2(_('Choisissez la TVA '),'class="title"');
 		$r.='<div >';
-		$r.= '<TABLE style="width:100%">';
-		$r.=th('');
+                $r.=_('Filter')." ".HtmlInput::filter_table("tva_select_table",'0,1,2,3' , 1);
+		$r.= '<TABLE style="width:100%" id="tva_select_table">';
 		$r.=th(_('code'));
 		$r.=th(_('Taux'));
 		$r.=th(_('Symbole'));
@@ -242,8 +262,7 @@ EOF;
 			}
 			$set = '<INPUT TYPE="BUTTON" class="button" Value="select" ' . $script . '>';
 			$class=($i%2 == 0)?' class="odd" ':' class="even" ';
-			$r.='<tr'.$class. '>';
-			$r.=td($set);
+			$r.='<tr'.$class. $script.' style="cursor : pointer">';
 			$r.=td($row['tva_id']);
 			$r.=td($row['tva_rate']);
 			$r.=td($row['tva_label']);
@@ -252,6 +271,7 @@ EOF;
 		}
 		$r.='</TABLE>';
 		$r.='</div>';
+                
 		$html = escape_xml($r);
 
 		header('Content-type: text/xml; charset=UTF-8');
@@ -289,7 +309,7 @@ EOF;
 	 * display the lettering
 	 */
 	case 'dl':
-		require_once('class_lettering.php');
+		require_once NOALYSS_INCLUDE.'/class_lettering.php';
 		$exercice = $g_user->get_exercice();
 		if ($g_user->check_module("LETCARD") == 0 && $g_user->check_module("LETACC") == 0)
 			exit();
@@ -496,37 +516,43 @@ EOF;
 EOF;
 		break;
 	case 'mod_doc':
-		require_once('ajax_mod_document.php');
+		require_once NOALYSS_INCLUDE.'/ajax_mod_document.php';
 		break;
 	case 'input_per':
-		require_once('ajax_mod_periode.php');
+		require_once NOALYSS_INCLUDE.'/ajax_mod_periode.php';
 		break;
 	case 'save_per':
-		require_once('ajax_mod_periode.php');
+		require_once NOALYSS_INCLUDE.'/ajax_mod_periode.php';
 		break;
 	case 'mod_predf':
-		require_once('ajax_mod_predf_op.php');
+		require_once NOALYSS_INCLUDE.'/ajax_mod_predf_op.php';
 		break;
 	case 'save_predf':
-		require_once('ajax_save_predf_op.php');
+		require_once NOALYSS_INCLUDE.'/ajax_save_predf_op.php';
 		break;
 	case 'search_op':
-		require_once 'search.inc.php';
+		require_once NOALYSS_INCLUDE.'/search.inc.php';
 		break;
 	case 'search_action':
-		require_once 'ajax_search_action.php';
+		require_once NOALYSS_INCLUDE.'/ajax_search_action.php';
 		break;
 	case 'display_profile':
-		require_once("ajax_get_profile.php");
+		require_once NOALYSS_INCLUDE.'/ajax_get_profile.php';
 		break;
 	case 'det_menu':
-		require_once("ajax_get_menu_detail.php");
+		require_once NOALYSS_INCLUDE.'/ajax_get_menu_detail.php';
 		break;
 	case 'add_menu':
-		require_once 'ajax_add_menu.php';
+		require_once NOALYSS_INCLUDE.'/ajax_add_menu.php';
 		break;
+        case 'display_submenu':
+                require_once NOALYSS_INCLUDE.'/ajax_display_submenu.php';
+                break;
+        case 'remove_submenu':
+                require_once NOALYSS_INCLUDE.'/ajax_remove_submenu.php';
+                break;
 	case 'cardsearch':
-		require_once 'ajax_boxcard_search.php';
+		require_once NOALYSS_INCLUDE.'/ajax_boxcard_search.php';
 		break;
 	case 'add_plugin':
 		$me_code = new IText('me_code');
@@ -535,7 +561,7 @@ EOF;
 		$me_description = new IText("me_description");
 		$me_parameter = new IText("me_parameter");
 		$new = true;
-		require_once 'ajax_plugin_detail.php';
+		require_once NOALYSS_INCLUDE.'/ajax_plugin_detail.php';
 		break;
 	case 'mod_plugin':
 		$m = $cn->get_array("select me_code,me_file,me_menu,me_description,me_parameter
@@ -552,92 +578,92 @@ EOF;
 		$me_description = new IText("me_description", $m[0] ['me_description']);
 		$me_parameter = new IText("me_parameter", $m[0] ['me_parameter']);
 		$new = false;
-		require_once 'ajax_plugin_detail.php';
+		require_once NOALYSS_INCLUDE.'/ajax_plugin_detail.php';
 		break;
 	case 'saldo':
-		require_once 'ajax_bank_saldo.php';
+		require_once NOALYSS_INCLUDE.'/ajax_bank_saldo.php';
 		break;
 	case 'up_predef':
-		require_once 'ajax_update_predef.php';
+		require_once NOALYSS_INCLUDE.'/ajax_update_predef.php';
 		break;
 	case 'upd_receipt':
-		require_once 'ajax_get_receipt.php';
+		require_once NOALYSS_INCLUDE.'/ajax_get_receipt.php';
 		break;
 	case 'up_pay_method':
-		require_once 'ajax_update_payment.php';
+		require_once NOALYSS_INCLUDE.'/ajax_update_payment.php';
 		break;
 	case 'openancsearch':
 	case 'resultancsearch':
-		require_once('ajax_anc_search.php');
+		require_once NOALYSS_INCLUDE.'/ajax_anc_search.php';
 		break;
 	case 'autoanc':
-		require_once 'ajax_auto_anc_card.php';
+		require_once NOALYSS_INCLUDE.'/ajax_auto_anc_card.php';
 		break;
 	case 'create_menu';
-		require_once 'ajax_create_menu.php';
+		require_once NOALYSS_INCLUDE.'/ajax_create_menu.php';
 		break;
 	case 'modify_menu';
-		require_once 'ajax_mod_menu.php';
+		require_once NOALYSS_INCLUDE.'/ajax_mod_menu.php';
 		break;
 	case 'mod_stock_repo':
-		require_once 'ajax_mod_stock_repo.php';
+		require_once NOALYSS_INCLUDE.'/ajax_mod_stock_repo.php';
 		break;
 	case 'view_mod_stock':
-		require_once 'ajax_view_mod_stock.php';
+		require_once NOALYSS_INCLUDE.'/ajax_view_mod_stock.php';
 		break;
 	case 'fddetail':
-		require_once 'ajax_fiche_def_detail.php';
+		require_once NOALYSS_INCLUDE.'/ajax_fiche_def_detail.php';
 		break;
 	case 'vw_action':
-		require_once 'ajax_view_action.php';
+		require_once NOALYSS_INCLUDE.'/ajax_view_action.php';
 		break;
 	case 'minrow':
-		require_once 'ajax_min_row.php';
+		require_once NOALYSS_INCLUDE.'/ajax_min_row.php';
 		break;
         case 'navigator':
-                require_once 'ajax_navigator.php';
+                require_once NOALYSS_INCLUDE.'/ajax_navigator.php';
                 break;
         case 'preference':
-                require_once 'ajax_preference.php';
+                require_once NOALYSS_INCLUDE.'/ajax_preference.php';
                 break;
         case 'bookmark':
-            require_once 'ajax_bookmark.php';
+            require_once NOALYSS_INCLUDE.'/ajax_bookmark.php';
             break;
         case 'tag_detail':
-            require_once 'ajax_tag_detail.php';
+            require_once NOALYSS_INCLUDE.'/ajax_tag_detail.php';
             break;
         case 'tag_save':
-            require_once 'ajax_tag_save.php';
+            require_once NOALYSS_INCLUDE.'/ajax_tag_save.php';
             break;
         case 'tag_list':
-            require_once 'ajax_tag_list.php';
+            require_once NOALYSS_INCLUDE.'/ajax_tag_list.php';
             break;
         case 'tag_add':
-            require_once 'ajax_tag_add_action.php';
+            require_once NOALYSS_INCLUDE.'/ajax_tag_add_action.php';
             break;
         case 'tag_remove':
-            require_once 'ajax_tag_remove_action.php';
+            require_once NOALYSS_INCLUDE.'/ajax_tag_remove_action.php';
             break;
         case 'tag_choose':
-            require_once 'ajax_tag_choose.php';
+            require_once NOALYSS_INCLUDE.'/ajax_tag_choose.php';
             break;
         case 'tag_choose':
-            require_once 'ajax_tag_choose.php';
+            require_once NOALYSS_INCLUDE.'/ajax_tag_choose.php';
             break;
        case 'search_display_tag':
-            require_once 'ajax_search_display_tag.php';
+            require_once NOALYSS_INCLUDE.'/ajax_search_display_tag.php';
             break;
         case 'search_add_tag':
-            require_once 'ajax_search_add_tag.php';
+            require_once NOALYSS_INCLUDE.'/ajax_search_add_tag.php';
             break;
         case 'search_clear_tag':
-            require_once 'ajax_search_clear_tag.php';
+            require_once NOALYSS_INCLUDE.'/ajax_search_clear_tag.php';
             break;
         case 'calendar_zoom':
-            require_once 'ajax_calendar_zoom.php';
+            require_once NOALYSS_INCLUDE.'/ajax_calendar_zoom.php';
             break;
         case 'ledger_show':
-            require_once 'ajax_ledger_show.php';
+            require_once NOALYSS_INCLUDE.'/ajax_ledger_show.php';
         case 'ledger_description':
             $ajrn=$cn->get_array('select jrn_def_name,jrn_def_description from jrn_def where jrn_def_id=$1',array($l));
             if ( count($ajrn)==1)
@@ -656,19 +682,67 @@ EOF;
             /*
              *  Show the available distribution keys for analytic 
              */
-            require_once 'ajax_anc_key_choice.php';
+            require_once NOALYSS_INCLUDE.'/ajax_anc_key_choice.php';
             break;
         case 'anc_key_compute':
             /* 
              * Show the activities computed with the selected distribution key 
              */
-            require_once 'ajax_anc_key_compute.php';
+            require_once NOALYSS_INCLUDE.'/ajax_anc_key_compute.php';
             break;
         case 'account_update':
             /**
              * update an accounting (from CFGPCMN)
              */
-            require_once 'ajax_account_update.php';
+            require_once NOALYSS_INCLUDE.'/ajax_account_update.php';
+            break;
+        // From admin, revoke the access to a folder from an
+        // user
+        case 'folder_remove':
+            require_once NOALYSS_INCLUDE.'/ajax_admin.php';
+            break;
+        // From admin, display a list of folder to which the user has 
+        // no access
+        case 'folder_display':
+            require_once NOALYSS_INCLUDE.'/ajax_admin.php';
+            break;
+        // From admin, grant the access to a folder to an
+        // user
+        case 'folder_add':
+            require_once NOALYSS_INCLUDE.'/ajax_admin.php';
+            break;
+
+        // From admin, display info and propose to drop the folder
+        case 'folder_drop':
+            require_once NOALYSS_INCLUDE.'/ajax_admin.php';
+            break;
+
+        // From admin, display the information of a folder you can 
+        // modify
+        case 'folder_modify':
+            require_once NOALYSS_INCLUDE.'/ajax_admin.php';
+            break;
+        // From admin, display info and propose to drop the template
+        case 'modele_drop':
+            require_once NOALYSS_INCLUDE.'/ajax_admin.php';
+            break;
+
+        // From admin, display the information of a template you can 
+        // modify
+        case 'modele_modify':
+            require_once NOALYSS_INCLUDE.'/ajax_admin.php';
+            break;
+        // From dashboard, display detail about last operation 
+        case 'action_show':
+            require_once NOALYSS_INCLUDE.'/ajax_gestion.php';
+            break;
+        // From dashboard, display form for a new event
+        case 'action_add':
+            require_once NOALYSS_INCLUDE.'/ajax_gestion.php';
+            break;
+        // Save a event given in the short form
+        case 'action_save':
+            require_once NOALYSS_INCLUDE.'/ajax_gestion.php';
             break;
 	default:
 		var_dump($_GET);
