@@ -31,11 +31,11 @@
  * Must return at least tva, htva and tvac
  */
 require_once '../include/constant.php';
-require_once ('class_database.php');
-require_once ('class_acc_compute.php');
-require_once('class_dossier.php');
-require_once ('class_acc_tva.php');
-require_once ('class_user.php');
+require_once  NOALYSS_INCLUDE.'/class_database.php';
+require_once  NOALYSS_INCLUDE.'/class_acc_compute.php';
+require_once  NOALYSS_INCLUDE.'/class_dossier.php';
+require_once  NOALYSS_INCLUDE.'/class_acc_tva.php';
+require_once  NOALYSS_INCLUDE.'/class_user.php';
 
 // Check if the needed field does exist
 extract ($_GET);
