@@ -24,13 +24,13 @@ define('ALLOWED',1);
  * \brief Main file
  */
 require_once '../include/constant.php';
-require_once 'class_database.php';
-require_once ('class_dossier.php');
-require_once('user_common.php');
-require_once('ac_common.php');
-require_once 'function_javascript.php';
-require_once 'constant.security.php';
-require_once 'class_html_input.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
+require_once NOALYSS_INCLUDE.'/user_common.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/function_javascript.php';
+require_once NOALYSS_INCLUDE.'/constant.security.php';
+require_once NOALYSS_INCLUDE.'/class_html_input.php';
 mb_internal_encoding("UTF-8");
 
 // if gDossier is not set redirect to form to choose a folder
@@ -42,26 +42,64 @@ if ( ! isset($_REQUEST['gDossier']))
 if ( ! isset ($_SESSION['g_theme']))
   {
     echo "<h2>"._('Vous  êtes déconnecté')."</h2>";
-    redirect('user_login.php');
+    $backurl=$_SERVER['REQUEST_URI'];
+    $url="index.php?".http_build_query(array('reconnect'=>1,'backurl'=>urlencode($backurl)));
+    redirect($url);
     exit();
 
   }
 $style_user=HtmlInput::default_value_post("style_user",$_SESSION['g_theme']);
 
 html_page_start($style_user);
+if ( DEBUG ) {
+    ?>
+<div id="debug_div" style="border:slategray solid 1px;margin-left: 0px;position:absolute;background:white;display:fixed;top:2px;left:25px;z-index:1000;display:none">
+    <h2>$_POST</h2>
+    <?php        
+    var_dump($_POST);
+    ?>
+    <h2>$_GET</h2>
+    <?php        
+    var_dump($_GET);
+    ?>
+</div>
+<script>
+    function show_debug_request() {
+        var visible=document.getElementById('debug_div').style.display;
+        console.log(visible);
+        var new_state="";
+        if ( visible == 'block') { new_state='none';}
+        else
+        if ( visible == 'none') { new_state='block';}
+        else 
+            console.log('erreur');
+        document.getElementById('debug_div').style.display=new_state;
+    }
+</script>
+<input type="button" class="tinybutton" style="position:absolute;display:fixed;top:40px;left:50px;margin-left:50px;z-index:1000" value="show request" onclick="show_debug_request()">
 
+<?php
+}
 global $g_user, $cn,$g_parameter;
 
 
 
 $cn = new Database(Dossier::id());
+
+/*
+ * check that the database is not empty
+ */
+if ( ! $cn->exist_table('version')) {
+    echo '<h2 class="notice">'._('Désolé').'</h2>';
+    echo _('Ce dossier est vide');
+    echo '<p>';
+    echo '<a class="button" href="do.php">'._("Retour à l'accueil").'</a>';
+    echo '</p>';
+    return;
+}
+
 $g_user = new User($cn);
 
-if ($g_user->check_dossier(dossier::id()) == 'P')
-{
-    redirect("extension.php?" . dossier::get(), 0);
-    exit();
-}
 $g_parameter=new Own($cn);
 
 load_all_script();
@@ -124,9 +162,6 @@ if ($oPeriode->load() == -1)
     $g_user->set_periode($periode);
 }
 
-// Display available menu in the right order
-load_all_script();
-
 $module_selected = -1;
 
 /*
@@ -149,6 +184,7 @@ if ( isset ($_POST['set_preference'])) {
     $_SESSION['g_theme']=$style_user;
     $_SESSION['g_pagesize']=$p_size;
     $_SESSION['g_lang']=$lang;
+    $g_user->save_email($p_email);
 }
 
 /*
@@ -179,25 +215,67 @@ if (isset($_REQUEST['ac']))
     }
 
     $_REQUEST['ac']=  trim(strtoupper($_REQUEST['ac']));
-    $all = explode('/', $_REQUEST['ac']);
-    $module_selected = $all[0];
-    $g_user->audit();
-// Show module and highligt selected one
-    show_module($module_selected);
-    for ($i = 0; $i != count($all); $i++)
-    {   // show the menu
-		show_menu($all, $i);
+    $AC=$_REQUEST['ac'];
+    $user_profile=$g_user->get_profile();
+    
+    
+    $amenu_id=$cn->get_array('select 
+      pm_id_v3,pm_id_v2,pm_id_v1
+    from v_menu_profile where code= upper($1)  and p_id=$2',
+            array($AC,$user_profile));
+    try {        
+        if ( count($amenu_id) != 1 ) {
+            // if AC is a simple code and this menu can be accessed 
+            // we should find the first menu which used it and change the
+            // request AC to it
+            $pm_id=$cn->get_array('select pm_id from profile_menu '
+                    . ' where lower(me_code)=lower($1) and p_id=$2',
+                    array($AC,$user_profile));
+            if ( count($pm_id) > 0 ) {
+                show_menu($pm_id[0]['pm_id']);
+            } else {
+                throw new Exception(_('Erreur menu'),10);
+            }
+        }
+        
+        $module_id=$cn->get_value('select case when pm_id_v3 = 0 then (case when pm_id_v2 = 0 then pm_id_v1 else pm_id_v2 end) else pm_id_v3 end 
+            from v_menu_profile where p_id=$1 and upper(code)=upper($2)',
+                array($user_profile,$AC));
+        $g_user->audit();
+        // Show module and highligt selected one
+        show_module($module_id);
+        show_menu( $amenu_id[0]['pm_id_v3']);
+        show_menu( $amenu_id[0]['pm_id_v2']);
+        show_menu($amenu_id[0]['pm_id_v1']);
+    } catch (Exception $e) {
+        if ( $e->getCode() == 10 ) {
+            alert(_('Accès menu impossible'));
+        }
+        else {
+            alert($e->getTraceAsString());
+        }
     }
 }
 else
 {
     $default = find_default_module();
+    $user_profile=$g_user->get_profile();
+    
+    if ( $user_profile == "" ) 
+        throw new Exception (_('Aucun profil utilisateur'));
+    
+    $menu_id=$cn->get_value('select 
+        case when pm_id_v3 = 0 then 
+            (case when pm_id_v2 = 0 then pm_id_v1 else pm_id_v2 end) 
+       else pm_id_v3 end 
+    from v_menu_profile where code= upper($1)  and p_id=$2',
+            array($default,$user_profile));
     $_GET['ac']=$default;
     $_POST['ac']=$default;
     $_REQUEST['ac']=$default;
-    show_module($default);
+    show_module($menu_id);
     $all[0] = $default;
-    show_menu($all, 0);
+    show_menu($menu_id);
 }
 
 
