@@ -27,15 +27,15 @@
 define ('ALLOWED',1);
 require_once '../include/constant.php';
 global $g_user,$cn,$g_parameter;
-require_once('class_database.php');
-require_once('class_user.php');
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_user.php';
 $gDossier=dossier::id();
 $cn=new Database($gDossier);
 mb_internal_encoding("UTF-8");
 $g_user=new User($cn);
 $g_user->Check();
 $action=$g_user->check_dossier($gDossier);
-
+set_language();
 if ( $action=='X' || ! isset($_GET['act']) || $g_user->check_print($_GET['act'])==0 )
   {
     echo alert(_('Accès interdit'));
