@@ -42,6 +42,10 @@
  * <li>Dans le répertoire include: Les noms de fichiers sont *.php pour les fichiers contenant des fonctions uniquement</li>
  * <li>Dans le répertoire include: Les noms de fichier sont
  * class_*.php pour les fichiers contenant des classes.</li>
+ * <li>Dans le répertoire include: Les noms de fichier ajax* correspondent aux fichiers appelé par une fonction javascript en ajax, 
+ * normalement le nom de fichier est basé sur le nom de la fonction javascript
+ * exemple pour la fonction javascript anc_key_choice le fichier correspondant est
+ * ajax_anc_key_choice.php
  * <li>Dans le répertoire include/template: les fichiers de
  * présentation HTML </li>
  * <li>Utiliser sql/upgrade.sql comme fichier temporaire pour modifier la base de données, en général
@@ -81,16 +85,19 @@
  *
  * \section convention_code Coding convention
  * <p>
- * Some coding conventions to have a homogene code
+ * Some coding conventions to have a homogeneous code
  * <ol>
  * <li>Reuse the existing code , </li>
- * <li>Improve and check that the function is still working</li>
+ * <li>Improve and test that the function is still working</li>
  * <li>Make documentation thanks doxygen tag</li>
  * <li>In the folder include: filenames ending by  *.inc.php will be executer after being included</li>
- * <li>Dans le répertoire include: Les noms de fichiers sont *.php pour les fichiers contenant des fonctions uniquement</li>
  * <li>In the folder include: filenames end by  *.php if they contains only function</li>
  * <li>In the folder include: filenames starting with
  * class_*.php if it is related to a class.</li>
+ * <li>In the folder include, files starting with ajax are executed by ajax call, usually, the file name is
+ * based on the javascript function, example for the javascript function anc_key_choice the corresponding file is
+ * ajax_anc_key_choice.php
+ * 
  * <li>In the folder include/template: files for the HTML presentation
  * </li>
  * <li>Use sql/upgrade.sql as temporary file to modify the database,this file will be the base for a SQL patch
@@ -102,13 +109,13 @@
  * \section advice Advices
  * <p>
  * Use this document, it is generated automatically by doxygen, check the documentation your made, read it first this
- * documentation before making change
+ * documentation before making changes
  * <ul>
  * <li>Related contains all the \\todo</li>
  * <li>Global -> all the functions</li>
  * <li>check into mod1.html and account_repository.html for the database design
  *</ul>
- *  You need to know only this tags
+ *  You need to know only these tags
  * <ul>
  * <li> \\file in the beginning of a file</li>
  * <li> \\todo add a todo </li>
@@ -127,8 +134,7 @@
 
 if ( ! file_exists('..'.DIRECTORY_SEPARATOR.'include'.DIRECTORY_SEPARATOR.'config.inc.php'))
 {
-    $p_string='admin/setup.php';
-    echo '<HTML><head><META HTTP-EQUIV="REFRESH" content="0;url='.$p_string.'"></head><body> Connecting... </body></html>';
+    header("Location: admin/setup.php",true, 307);
     exit(0);
 }
 
@@ -139,10 +145,13 @@ echo '<!doctype html><HTML>
 <style>
 BODY {
 background-color:white;
-font-size:14px;
+font-size:12px;
 font-family:sans-serif,arial;
 color:blue;
 }
+.cell , #recover_box p{
+font-size : 18px;
+}
 .remark {
 border: solid black 1px;
 font-family:sans-serif;
@@ -160,34 +169,37 @@ color:red;
 .input_text {
 border:1px solid blue;
 margin:1px;
+padding: 10px;
+border-radius: 4px;
+font-size:18px;
 }
 .button {
-font-size:12px;
 color:white;
 font-weight: bold;
 border:0px;
 text-decoration:none;
 font-family: helvetica,arial,sans-serif;
 background-image: url("image/bg-submit2.gif");
-background-repeat: repeat-x;
+background-repeat: repeat-x repeat-y;
 background-position: left;
 text-decoration:none;
 font-family: helvetica,arial,sans-serif;
 border-width:0px;
 padding:2px 4px 2px 4px;
 cursor:pointer;
-margin:1px 2px 1px 2px;
+margin:31px 2px 1px 2px;
 -moz-border-radius:2px 2px;
 border-radius:2px 2px;
-
+font-size : 20px;
+margin-bottom: 10px;
 }
 .button:hover {
 cursor:pointer;
 background-color:white;
 border-style:  solid;
 border-width:  0px;
-font-color:blue;
-margin:1px 2px 1px 2px;
+background-image: url("image/bg-submit3.gif");
+background-repeat: repeat-x repeat-y;
 }
 </style>
 <script src="js/scripts.js" type="text/javascript"></script>
@@ -195,15 +207,26 @@ margin:1px 2px 1px 2px;
 <BODY>';
 $my_domain="";
 require_once '../include/constant.php';
-require_once ('config.inc.php');
+require_once '../include/config.inc.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+
 if ( strlen(domaine) > 0 )
 {
     $my_domain="Domaine : ".domaine;
 }
 
+if (defined("RECOVER") && isset ($_REQUEST['recover']) )
+{
+    require_once '../include/recover.php';
+}
+// reconnect , create a variable to reconnect properly in login.php
+$goto="";
+if (isset ($_REQUEST['reconnect']) && isset ($_REQUEST['backurl'])) {
+    $goto='<input type="hidden" value="'.$_REQUEST['backurl'].'" name="backurl">';
+}
 echo '
 <span style="background-color:#879ed4;color:white;padding-left:4px;padding-right:4px;">
-version  6.8.0.0 - '.$my_domain.'
+version  6.9 - '.$my_domain.'
 </span>
 <BR>
 <BR>
@@ -211,25 +234,25 @@ version  6.8.0.0 - '.$my_domain.'
 
 <BR>
 <center>
-<IMG SRC="image/logo6720.png" alt="NOALYSS">
+<IMG SRC="image/logo6820.png" style="width:420px;height:200px" alt="NOALYSS">
 <BR>
 <BR>
 <BR>
 
-<form action="login.php" method="post" name="loginform">
-<TABLE><TR><TD>
+<form action="login.php" method="post" name="loginform">'.
+       $goto .
+'<TABLE><TR><TD>
 <TABLE  BORDER=0 CELLSPACING=0>
 <TR>
-<TD class="cell">utilisateur</TD>
+<TD class="cell">Utilisateur</TD>
 <TD><input type="text" class="input_text" value="" id="p_user" name="p_user" tabindex="1"></TD>
 </TR>
 <TR>
-<TD> mot de passe </TD>
+<TD class="cell"> Mot de passe </TD>
 <TD><INPUT TYPE="PASSWORD"  class="input_text" value=""  NAME="p_pass" tabindex="2"></TD>
 </TR>';
 
-require_once('constant.php');
-require_once('ac_common.php');
+
 
 if ( $g_captcha == true )
   {
@@ -255,7 +278,7 @@ if ( $g_captcha == true )
 echo '
 <TR style="height:50px;vertical-align:bottom">
 <TD style="width:auto;text-align:center" colspan="2">
-<INPUT TYPE="SUBMIT"  style="width:60%;height:32px;-moz-border-radius:10px;border-radius:10px" class="button" NAME="login" value="Se connecter">
+<INPUT TYPE="SUBMIT"  style="width:250px;height:48px;-moz-border-radius:10px;border-radius:10px" class="button" NAME="login" value="Se connecter">
 </TD>
 </TR>
 </table>
@@ -265,6 +288,35 @@ echo '
 </table>
 
 </form>
+<?php if (defined("RECOVER")) : ?>
+    <a id="recover_link" href="#">Mot de passe oublié ? </a>
+    
+<div id="recover_box" style="display:none;position:absolute;top:40%;z-index:1;border:solid blue 2px;width:30%;margin-left: 25%;background-color: whitesmoke">
+    <span style="display:block;font-size:120%;padding:10px">Indiquez votre login ou votre email <span style="cursor: pointer;background-color: white;color:block;top:-5px;float: right;position:relative;right:-5px" id="close"><a ref="#" id="close_link"><?php echo SMALLX?></a></span></span>
+            <form method="POST">
+                <input type="hidden" value="send_email" name="id">
+                <input type="hidden" value="recover" name="recover" >
+                <p>
+                Login <input type="text"     class="input_text" name="login" nohistory>
+                </p>
+                <p>OU</p> 
+                <p>
+                Email <input type="text"  class="input_text" name="email" nohistory>
+                </p>
+                <input type="submit" class="button" name="send_email" value="Envoi email">
+                
+            </form>
+</div>
+    <script>
+        document.getElementById('recover_link').onclick=function() {
+            document.getElementById('recover_box').style.display="block";
+        }
+        document.getElementById('close_link').onclick=function() {
+            document.getElementById('recover_box').style.display="none";
+        }
+    </script>
+<?php endif; ?>
+        
 <div style="position:absolute;bottom: 0px;width:80%;right:10%">
     <p>Nous conseillons d'utiliser Firefox ou chrome.</p>
     <p>We recommend to use Firefox or Chrome.</p>
