@@ -31,7 +31,7 @@
 function add_row(p_table, p_seq)
 {
     var mytable = g(p_table).tBodies[0];
-    var max = parseFloat(g('amount_t' + p_seq).value);
+    var max =Math.abs( parseFloat(g('amount_t' + p_seq).value));
     if (!mytable)
     {
         return;
@@ -41,13 +41,13 @@ function add_row(p_table, p_seq)
 
     if (mytable.rows.length > 15)
     {
-        alert("Maximum 15 lignes ");
+        alert_box("Maximum 15 lignes ");
         return;
     }
     var amount = compute_total_table(p_table, p_seq);
     if (max < amount)
     {
-        alert('Montant incorrect : max = ' + max + " calculé=" + amount);
+        alert_box('Montant incorrect : max = ' + max + " calculé=" + amount);
         return;
     }
     // For the detail view (modify_op) there is several form and then several time the
@@ -81,15 +81,15 @@ function compute_total_table(p_table, seq)
         var col = document.getElementsByName("val[" + seq + "][]");
         for (i = 0; i < col.length; i++)
         {
-            // here is the problem
-            tot += parseFloat(col[i].value);
-
+            if ( $(p_table).contains(col[i])) {
+                tot += parseFloat(col[i].value);
+            }
         }
         return tot;
     }
     catch (e)
     {
-        alert(e.message);
+        alert_box(e.message);
     }
 }
 /**
@@ -102,7 +102,7 @@ function anc_refresh_remain(p_table, p_seq)
 {
     try
     {
-        var tot_line = parseFloat(g('amount_t' + p_seq).value);
+        var tot_line =Math.abs( parseFloat(g('amount_t' + p_seq).value));
         var tot_table = compute_total_table(p_table, p_seq);
         var remain = tot_line - tot_table;
         remain = Math.round(remain * 100) / 100;
@@ -119,7 +119,7 @@ function anc_refresh_remain(p_table, p_seq)
         }
     } catch (a)
     {
-        alert(a.message);
+        alert_box(a.message);
     }
 }
 /*!
@@ -155,7 +155,7 @@ function verify_ca(div)
 
                     total_amount += parseFloat(array_value[i].value);
                 }
-                var amount = parseFloat(g('amount_t' + idx).value);
+                var amount = Math.abs(parseFloat(g('amount_t' + idx).value));
                 var diff = amount - total_amount;
 
                 if (Math.round(diff, 2) != 0.0)
@@ -175,14 +175,14 @@ function verify_ca(div)
         }
         if (amount_error != 0)
         {
-            alert('Désolé, les montants pour la comptabilité analytique sont incorrects');
+            alert_box('Désolé, les montants pour la comptabilité analytique sont incorrects');
             return false;
         }
         return true;
     }
     catch (e)
     {
-        alert(e.message);
+        alert_box(e.message);
         return false;
     }
 }
@@ -221,7 +221,7 @@ function search_ca(p_dossier, p_target, p_source)
                         $('searchanc').innerHTML = req.responseText;
 
                     } catch (e) {
-                        alert(e.message);
+                        alert_box(e.message);
                     }
                 }
             }
@@ -246,7 +246,7 @@ function search_anc_form(obj)
                         req.responseText.evalScripts();
 
                     } catch (e) {
-                        alert(e.message);
+                        alert_box(e.message);
                     }
                 }
             }
@@ -322,17 +322,23 @@ function caod_checkTotal()
  */
 function anc_remove_operation(p_dossier, p_oa_group)
 {
-    var a = confirm("Etes-vous sur de vouloir effacer cette operation ?\n");
-    if (a == false)
-        return;
-    var obj = {"oa":
-                p_oa_group, "gDossier":
-                p_dossier, "op": "remove_anc"};
-    var queryString = encodeJSON(obj);
-    g(p_oa_group).style.display = 'none';
-    var e = new Ajax.Request("ajax_misc.php",
-            {method: 'get', parameters: queryString});
-
+     smoke.confirm("Etes-vous sur de vouloir effacer cette operation ?\n",
+     function (a)
+     {
+         if ( a) {
+            var obj = {"oa":
+                        p_oa_group, "gDossier":
+                        p_dossier, "op": "remove_anc"};
+            var queryString = encodeJSON(obj);
+            g(p_oa_group).style.display = 'none';
+            var e = new Ajax.Request("ajax_misc.php",
+                    {method: 'get', parameters: queryString});
+             
+         } else
+         {
+             return;
+         }
+     });
 }
 /**
  * add a row in misc operation for ANC
@@ -403,7 +409,7 @@ function anc_key_compute(p_dossier, p_table, p_amount, p_key_id)
                             var html = answer.getElementsByTagName('code');
                             if (html.length == 0) {
                                 var rec = req.responseText;
-                                alert('erreur :' + rec);
+                                alert_box('erreur :' + rec);
                             }
 
                             var code_html = getNodeText(html[0]); // Firefox ne prend que les 4096 car.
@@ -453,7 +459,7 @@ function anc_key_choice(p_dossier, p_table, p_amount,p_ledger)
                             var html = answer.getElementsByTagName('code');
                             if (html.length == 0) {
                                 var rec = req.responseText;
-                                alert('erreur :' + rec);
+                                alert_box('erreur :' + rec);
                             }
 
                             var code_html = getNodeText(html[0]); // Firefox ne prend que les 4096 car.
@@ -489,7 +495,7 @@ function add_row_key(p_table)
     var table_length=mytable.rows.length ;
     if ( table_length > 15)
     {
-        alert("Maximum 15 lignes ");
+        alert_box("Maximum 15 lignes ");
         return;
     }
     var rowToCopy = mytable.rows[1];
