@@ -51,7 +51,7 @@ function boxsearch_card(p_dossier)
 				  );
 	}catch( e)
 	{
-		alert(e.getMessage);
+		alert_box(e.getMessage);
 	}
 }
 /**
@@ -110,7 +110,7 @@ function search_card(obj)
     }
     catch(e)
     {
-        alert('search_card failed'+e.message);
+        alert_box('search_card failed'+e.message);
     }
 }
 /**
@@ -177,7 +177,7 @@ function action_add_concerned_card(obj)
                         if (a.length == 0)
                         {
                             var rec = req.responseText;
-                            alert('erreur :' + rec);
+                            alert_box('erreur :' + rec);
                         }
                         var html = answer.getElementsByTagName('code');
                         var namectl = a[0].firstChild.nodeValue;
@@ -199,7 +199,7 @@ function action_add_concerned_card(obj)
                         $('search_card').innerHTML = code_html;
                         $('query').focus();
                         }catch (e) {
-                            alert(e.message);
+                            alert_box(e.message);
                         }
                     }
                 }
@@ -207,7 +207,7 @@ function action_add_concerned_card(obj)
     }
     catch (e)
     {
-        alert('search_card failed' + e.message);
+        alert_box('search_card failed' + e.message);
         return false;
     }
     return false;
@@ -283,7 +283,7 @@ function result_card_search(req)
         if ( a.length == 0 )
         {
             var rec=req.responseText;
-            alert ('erreur :'+rec);
+            alert_box ('erreur :'+rec);
         }
         var html=answer.getElementsByTagName('code');
 
@@ -304,12 +304,14 @@ function result_card_search(req)
 
         var div_style="top:"+sx+"px;height:80%";
         add_div({id:'search_card',cssclass:'inner_box',html:"",style:div_style,drag:true,effect:'blinddown'});
+        
         $('search_card').innerHTML=code_html;
-        $('query').focus();
+        
+        if ($('query')) { $('query').focus();}
     }
     catch (e)
     {
-        alert(e.message);
+        alert_box(e.message);
     }
     try
     {
@@ -317,7 +319,7 @@ function result_card_search(req)
     }
     catch(e)
     {
-        alert("Impossible executer script de la reponse\n"+e.message);
+        alert_box("Impossible executer script de la reponse\n"+e.message);
     }
 
 }
@@ -374,7 +376,7 @@ function clean_Fid(p_ctl)
 }
 function errorFid(request,json)
 {
-    alert('erreur : ajax fiche');
+    alert_box('erreur : ajax fiche');
 }
 function update_value(text,li)
 {
@@ -435,10 +437,12 @@ function fill_ipopcard(obj)
     card_layer++;
 
     var content='card_'+card_layer;
-    var nTop=posY-40;
-    //var nLeft=posX-20;
-	var nLeft="20%";
-    var str_style="top:"+nTop+"px;left:"+nLeft+"px;width:45em;height:auto";
+    var nTop=170+card_layer;
+    if ( nTop > 300 ) {
+        nTop=170;
+    }
+    str_top=fixed_position(250,nTop)
+    var str_style=str_top+";width:45em;height:auto;position:absolute";
 
     var popup={'id':  content,'cssclass':'inner_box','style':str_style,'html':loading(),'drag':true};
 
@@ -494,7 +498,7 @@ function  successFill_ipopcard(req,json)
         if ( a.length == 0 )
         {
             var rec=req.responseText;
-            alert ('erreur :'+rec);
+            alert_box ('erreur :'+rec);
         }
         var name_ctl=a[0].firstChild.nodeValue;
         var code_html=getNodeText(html[0]);
@@ -504,7 +508,7 @@ function  successFill_ipopcard(req,json)
     }
     catch (e)
     {
-        alert(e.message);
+        alert_box(e.message);
     }
     try
     {
@@ -512,7 +516,7 @@ function  successFill_ipopcard(req,json)
     }
     catch(e)
     {
-        alert("Impossible executer script de la reponse\n"+e.message);
+        alert_box("Impossible executer script de la reponse\n"+e.message);
     }
 }
 /**
@@ -756,7 +760,7 @@ function save_card_category(obj)
 {
     if ( ! $(obj).ipopup)
     {
-        alert('Erreur pas d\' attribut ipopup '+obj.id);
+        alert_box('Erreur pas d\' attribut ipopup '+obj.id);
         return;
     };
 	try {
@@ -778,7 +782,7 @@ function save_card_category(obj)
                                 );
 	} catch(e)
 	{
-		alert(e.message);
+		alert_box(e.message);
 		return false;
 	}
 	return false;
@@ -826,7 +830,7 @@ try {
 				  }
 				);
     } catch (e) {
-	alert(e.message);
+	alert_box(e.message);
 	return false;
     }
 }
@@ -854,7 +858,7 @@ function action_save_concerned(p_dossier, p_fiche_id, p_action_id) {
                         if (a.length == 0)
                         {
                             var rec = req.responseText;
-                            alert('erreur :' + rec);
+                            alert_box('erreur :' + rec);
                         }
                         var html = answer.getElementsByTagName('code');
                         var namectl = a[0].firstChild.nodeValue;
@@ -887,7 +891,7 @@ function action_remove_concerned(p_dossier,p_fiche_id,p_action_id)
                         if (a.length == 0)
                         {
                             var rec = req.responseText;
-                            alert('erreur :' + rec);
+                            alert_box('erreur :' + rec);
                         }
                         var html = answer.getElementsByTagName('code');
                         var namectl = a[0].firstChild.nodeValue;
