@@ -69,9 +69,10 @@ content[38]='La numérotation est propre à chaque journal. Laissez à 0 pour ne
 content[39]='Le préfixe des pièces doit être différent pour chaque journal, on peut aussi utiliser l\'année';
 content[40]='Laissez à 0 pour ne pas changer le numéro';
 content[41]='Mettez le pourcentage à zéro pour effacer la ligne';
+content[42]="Selectionnez le plan qui vous intéresse avant de cliquer sur Recherche";
 
 function showBulle(p_ctl){
-    d=document.getElementById('bulle');
+    var d=document.getElementById('bulle');
     d.innerHTML=content[p_ctl];
     d.style.top=posY+offsetY+"px";
     d.style.left=posX+offsetX+"px";
@@ -92,6 +93,6 @@ function getPosition(e)
 }
 function hideBulle(p_ctl)
 {
-    d=document.getElementById('bulle');
+    var d=document.getElementById('bulle');
     d.style.visibility="hidden";
 }
