@@ -41,7 +41,7 @@ function infodiv(req, json)
         if (a.length === 0)
         {
             var rec = req.responseText;
-            alert('erreur :' + rec);
+            alert_box('erreur :' + rec);
         }
         var name_ctl = a[0].firstChild.nodeValue;
         var code_html = getNodeText(html[0]);
@@ -51,7 +51,7 @@ function infodiv(req, json)
     }
     catch (e)
     {
-        alert("success_box" + e.message);
+        alert_box("success_box" + e.message);
     }
     try
     {
@@ -59,7 +59,7 @@ function infodiv(req, json)
     }
     catch (e)
     {
-        alert("answer_box Impossible executer script de la reponse\n" + e.message);
+        alert_box("answer_box Impossible executer script de la reponse\n" + e.message);
     }
 
 }
@@ -69,18 +69,22 @@ function infodiv(req, json)
  */
 function deleteRow(tb, obj)
 {
-    if (confirm('Confirmez effacement'))
+    smoke.confirm('Confirmez effacement',function (e)
     {
-        var td = obj.parentNode;
-        var tr = td.parentNode;
-        var lidx = tr.rowIndex;
-        g(tb).deleteRow(lidx);
-    }
+        if (e) {
+            var td = obj.parentNode;
+            var tr = td.parentNode;
+            var lidx = tr.rowIndex;
+            g(tb).deleteRow(lidx);
+            
+        } else {
+            return ;
+        }
+    });
 }
 function deleteRowRec(tb, obj)
 {
-    var td = obj.parentNode;
-    var tr = td.parentNode;
+    var tr = obj;
     var lidx = tr.rowIndex;
     g(tb).deleteRow(lidx);
 }
@@ -154,7 +158,7 @@ function encodeJSON(obj)
 {
     if (typeof obj != 'object')
     {
-        alert('encodeParameter  obj n\'est pas  un objet');
+        alert_box('encodeParameter  obj n\'est pas  un objet');
     }
     try
     {
@@ -177,7 +181,7 @@ function encodeJSON(obj)
     }
     catch (e)
     {
-        alert('encodeParameter ' + e.message);
+        alert_box('encodeParameter ' + e.message);
         return "";
     }
 }
@@ -343,9 +347,14 @@ function getNodeText(xmlNode)
  */
 function change_month(obj)
 {
-    var queryString = "gDossier=" + obj.gDossier + "&op=cal" + "&per=" + obj.value + "&t=" + obj.type_display;
     var action = new Ajax.Request(
-            "ajax_misc.php", {method: 'get', parameters: queryString, onFailure: ajax_misc_failure, onSuccess: success_misc}
+            "ajax_misc.php", 
+            {
+                method: 'get', 
+                parameters: { gDossier : obj.gDossier , op:'cal' ,"per"  : obj.value , t: obj.type_display, notitle:obj.notitle},
+                onFailure: ajax_misc_failure, 
+                onSuccess: success_misc
+            }
     );
 
 }
@@ -367,7 +376,7 @@ function success_misc(req)
         if (html.length === 0)
         {
             var rec = req.responseText;
-            alert('erreur :' + rec);
+            alert_box('erreur :' + rec);
         }
         var nodeXml = html[0];
         var code_html = getNodeText(nodeXml);
@@ -376,7 +385,7 @@ function success_misc(req)
     }
     catch (e)
     {
-        alert(e.message);
+        alert_box(e.message);
     }
     try
     {
@@ -384,7 +393,7 @@ function success_misc(req)
     }
     catch (e)
     {
-        alert("Impossible executer script de la reponse\n" + e.message);
+        alert_box("Impossible executer script de la reponse\n" + e.message);
     }
 
 
@@ -398,7 +407,7 @@ function loading()
 
 function ajax_misc_failure()
 {
-    alert('Ajax Misc failed');
+    alert_box('Ajax Misc failed');
 }
 /**
  *@brief remove a document_modele
@@ -407,7 +416,40 @@ function cat_doc_remove(p_dt_id, p_dossier)
 {
     var queryString = "gDossier=" + p_dossier + "&op=rem_cat_doc" + "&dt_id=" + p_dt_id;
     var action = new Ajax.Request(
-            "ajax_misc.php", {method: 'get', parameters: queryString, onFailure: ajax_misc_failure, onSuccess: success_cat_doc_remove}
+            "ajax_misc.php", {method: 'get',
+                parameters: queryString,
+                onFailure: ajax_misc_failure,
+                onSuccess: function (req)
+                {
+                    try
+                    {
+                        var answer = req.responseXML;
+                        var html = answer.getElementsByTagName('dtid');
+                        if (html.length === 0)
+                        {
+                            var rec = req.responseText;
+                            alert_box('erreur <br>' + rec );
+                            return;
+                        }
+                        nodeXML = html[0];
+                        row_id = getNodeText(nodeXML);
+                        if (row_id === 'nok')
+                        {
+                            var message_node = answer.getElementsByTagName('message');
+                            var message_text = getNodeText(message_node[0]);
+                            alert_box('erreur <br>' + message_text);
+                            return;
+                        }
+                        $('row' + row_id).style.textDecoration = "line-through";
+                        $('X' + row_id).style.display='none';
+                        $('M' + row_id).style.display='none';
+                    }
+                    catch (e)
+                    {
+                        alert_box(e.message);
+                    }
+                }
+            }
     );
 }
 /**
@@ -437,32 +479,6 @@ function cat_doc_change(p_dt_id, p_dossier)
     );
 }
 
-function success_cat_doc_remove(req)
-{
-    try
-    {
-        var answer = req.responseXML;
-        var html = answer.getElementsByTagName('dtid');
-        if (html.length === 0)
-        {
-            var rec = req.responseText;
-            alert('erreur :' + rec);
-        }
-        nodeXML = html[0];
-        row_id = getNodeText(nodeXML);
-        if (row_id === 'nok')
-        {
-            alert('Error');
-            return;
-        }
-        $('row' + row_id).style.textDecoration = "line-through";
-        $('X' + row_id).style.display = 'none';
-    }
-    catch (e)
-    {
-        alert(e.message);
-    }
-}
 /**
  *@brief display the popup with vat and explanation
  *@param obj with 4 attributes gdossier, ctl,popup
@@ -495,7 +511,7 @@ function popup_select_tva(obj)
                             if (popup.length === 0)
                             {
                                 var rec = req.responseText;
-                                alert('erreur :' + rec);
+                                alert_box('erreur :' + rec);
                             }
                             var html = answer.getElementsByTagName('code');
 
@@ -510,11 +526,11 @@ function popup_select_tva(obj)
 
                             var popup = {'id': 'tva_select', 'cssclass': 'inner_box', 'style': str_style, 'html': code_html, 'drag': true};
                             add_div(popup);
-
+                            $('lk_tva_select_table').focus();
                         }
                         catch (e)
                         {
-                            alert("success_popup_select_tva " + e.message);
+                            alert_box("success_popup_select_tva " + e.message);
                         }
                     }
                 }
@@ -522,7 +538,7 @@ function popup_select_tva(obj)
     }
     catch (e)
     {
-        alert("popup_select_tva " + e.message);
+        alert_box("popup_select_tva " + e.message);
     }
 }
 /**
@@ -557,7 +573,7 @@ function set_tva_label(obj)
     }
     catch (e)
     {
-        alert("set_tva_label " + e.message);
+        alert_box("set_tva_label " + e.message);
     }
 }
 /**
@@ -574,7 +590,7 @@ function success_set_tva_label(req)
         if (code.length === 0)
         {
             var rec = req.responseText;
-            alert('erreur :' + rec);
+            alert_box('erreur :' + rec);
         }
 
         var label_code = code[0].firstChild.nodeValue;
@@ -583,7 +599,7 @@ function success_set_tva_label(req)
     }
     catch (e)
     {
-        alert("success_set_tva_label " + e.message);
+        alert_box("success_set_tva_label " + e.message);
     }
 
 }
@@ -599,26 +615,28 @@ function set_wait_obsolete(name)
     $(content).innerHTML = 'Un instant...<image src="image/loading.gif" border="0" alt="Chargement...">';
 }
 /**
- *@brief add dynamically a object for AJAX
- *@param obj.
- * the attributes are
+ * Create a div without showing it
+ * @param {type} obj
+ *  the attributes are
  *   - style to add style
  *   - id to add an id
  *   - cssclass to add a class
  *   - html is the content
  *   - drag is the div can be moved
+ * @returns html dom element
+ * @see add_div
  */
-function add_div(obj)
+function create_div(obj)
 {
     try
     {
         var top = document;
-
+        var elt = null;
         if (!$(obj.id)) {
-            var elt = top.createElement('div');
+             elt = top.createElement('div');
         }
         else {
-            var elt = $(obj.id);
+            elt = $(obj.id);
         }
         if (obj.id)
         {
@@ -637,7 +655,7 @@ function add_div(obj)
         }
         if (obj.cssclass)
         {
-            elt.setAttribute('class', obj.cssclass);/* FF */
+            elt.setAttribute('class', obj.cssclass); /* FF */
             elt.setAttribute('className', obj.cssclass); /* IE */
         }
         if (obj.html)
@@ -646,7 +664,9 @@ function add_div(obj)
         }
 
         var bottom_div = document.body;
+        elt.hide();
         bottom_div.appendChild(elt);
+        
         /* if ( obj.effect && obj.effect != 'none' ) { Effect.Grow(obj.id,{direction:'top-right',duration:0.1}); }
          else if ( ! obj.effect ){ Effect.Grow(obj.id,{direction:'top-right',duration:0.1}); }*/
         if (obj.drag)
@@ -657,12 +677,34 @@ function add_div(obj)
                 }}
             );
         }
-        /* elt.setStyle({visibility:'visible'}); */
-        elt.style.visibility='visible';
+        return elt;
     }
     catch (e)
     {
-        alert("add_div " + e.message);
+         error_message("create_div " + e.message);
+    }
+}
+/**
+ *@brief add dynamically a object for AJAX
+ *@param obj.
+ * the attributes are
+ *   - style to add style
+ *   - id to add an id
+ *   - cssclass to add a class
+ *   - html is the content
+ *   - drag is the div can be moved
+ */
+function add_div(obj)
+{
+    try {
+        var elt=create_div(obj);
+        /* elt.setStyle({visibility:'visible'}); */
+        elt.style.visibility = 'visible';
+        elt.show();
+    }
+    catch (e)
+    {
+        alert_box("add_div " + e.message);
     }
 }
 /**
@@ -683,6 +725,11 @@ function removeDiv(elt)
         window.location.reload();
     }
 }
+function waiting_node()
+{
+    $('info_div').innerHTML = 'Un instant';
+    $('info_div').style.display = "block";
+}
 /**
  *show a box while loading
  *must be remove when ajax is successfull
@@ -690,7 +737,7 @@ function removeDiv(elt)
  */
 function waiting_box()
 {
-    obj = {
+    var obj = {
         id: 'wait_box', html: '<h2 class="title">Chargement</h2>' + loading()
     };
     var y = fixed_position(10, 250)
@@ -698,10 +745,9 @@ function waiting_box()
     if ($('wait_box')) {
         removeDiv('wait_box');
     }
-    obj.effect = 'none';
+    waiting_node();
     add_div(obj);
-    $('info_div').innerHTML = 'Un instant';
-    $('info_div').style.display = "block";
+    $('wait_box').setOpacity(0.7);
 
 }
 /**
@@ -763,7 +809,7 @@ function success_box(req, json)
         if (a.length === 0)
         {
             var rec = req.responseText;
-            alert('erreur :' + rec);
+            alert_box('erreur :' + rec);
         }
         var name_ctl = a[0].firstChild.nodeValue;
         var code_html = getNodeText(html[0]);
@@ -777,7 +823,7 @@ function success_box(req, json)
     }
     catch (e)
     {
-        alert("success_box" + e.message);
+        alert_box("success_box" + e.message);
     }
     try
     {
@@ -785,13 +831,13 @@ function success_box(req, json)
     }
     catch (e)
     {
-        alert("answer_box Impossible executer script de la reponse\n" + e.message);
+        alert_box("answer_box Impossible executer script de la reponse\n" + e.message);
     }
 }
 
 function error_box()
 {
-    alert('[error_box] ajax not implemented');
+    alert_box('[error_box] ajax not implemented');
 }
 /**
  * show the ledger choice
@@ -838,7 +884,7 @@ function show_ledger_choice(json_obj)
                             var html = answer.getElementsByTagName('code');
                             if (a.length === 0) {
                                 var rec = req.responseText;
-                                alert('erreur :' + rec);
+                                alert_box('erreur :' + rec);
                             }
                             var name_ctl = a[0].firstChild.nodeValue;
                             var code_html = getNodeText(html[0]);
@@ -849,13 +895,13 @@ function show_ledger_choice(json_obj)
 
                         }
                         catch (e) {
-                            alert("show_ledger_callback" + e.message);
+                            alert_box("show_ledger_callback" + e.message);
                         }
                         try {
                             code_html.evalScripts();
                         }
                         catch (e) {
-                            alert("answer_box Impossible executer script de la reponse\n" + e.message);
+                            alert_box("answer_box Impossible executer script de la reponse\n" + e.message);
                         }
 
                     }
@@ -863,7 +909,7 @@ function show_ledger_choice(json_obj)
                 }
         );
     } catch (e) {
-        alert('show_ledger_choice' + e.message);
+        alert_box('show_ledger_choice' + e.message);
     }
 }
 /**
@@ -893,7 +939,7 @@ function hide_ledger_choice(p_frm_search)
         removeDiv(div + 'jrn_search');
         return false;
     } catch (e) {
-        alert('hide_ledger_choice' + e.message);
+        alert_box('hide_ledger_choice' + e.message);
         return false;
     }
 
@@ -1047,7 +1093,7 @@ function display_periode(p_dossier, p_id)
     }
     catch (e)
     {
-        alert("display_periode " + e.message);
+        alert_box("display_periode " + e.message);
     }
 
 }
@@ -1062,7 +1108,7 @@ function success_display_periode(req)
         if (html.length === 0)
         {
             var rec = req.responseText;
-            alert('erreur :' + rec);
+            alert_box('erreur :' + rec);
         }
 
         var code_html = getNodeText(html[0]);
@@ -1072,7 +1118,7 @@ function success_display_periode(req)
     }
     catch (e)
     {
-        alert("success_display_periode".e.message);
+        alert_box("success_display_periode".e.message);
     }
     try
     {
@@ -1080,7 +1126,7 @@ function success_display_periode(req)
     }
     catch (e)
     {
-        alert("success_display_periode Impossible executer script de la reponse\n" + e.message);
+        alert_box("success_display_periode Impossible executer script de la reponse\n" + e.message);
     }
 
 }
@@ -1102,7 +1148,7 @@ function save_periode(obj)
     }
     catch (e)
     {
-        alert("display_periode " + e.message);
+        alert_box("display_periode " + e.message);
     }
 
     return false;
@@ -1126,7 +1172,7 @@ function fill_box(req)
         var html = answer.getElementsByTagName('code');
         if (a.length === 0) {
             var rec = req.responseText;
-            alert('erreur :' + rec);
+            alert_box('erreur :' + rec);
         }
         var name_ctl = a[0].firstChild.nodeValue;
         var code_html = getNodeText(html[0]); // Firefox ne prend que les 4096 car.
@@ -1134,13 +1180,13 @@ function fill_box(req)
         $(name_ctl).innerHTML = code_html;
     }
     catch (e) {
-        alert(e.message);
+        alert_box(e.message);
     }
     try {
         code_html.evalScripts();
     }
     catch (e) {
-        alert("Impossible executer script de la reponse\n" + e.message);
+        alert_box("Impossible executer script de la reponse\n" + e.message);
     }
 
 
@@ -1227,7 +1273,7 @@ function search_reconcile(dossier, ctl_concern, amount_id, ledger, p_id_target)
     str_style += ";width:92%;overflow:auto;";
     waiting_box();
 
-    
+
     var target = {gDossier: dossier,
         ctlc: ctl_concern,
         op: 'search_op',
@@ -1279,7 +1325,7 @@ function search_operation(obj)
     } catch (e)
     {
         remove_waiting_box();
-        alert(e.message);
+        alert_box(e.message);
     }
 }
 /**
@@ -1295,6 +1341,7 @@ function set_reconcile(obj)
     try
     {
         var ctlc = obj.elements['ctlc'];
+        if ( ! obj.elements['target']) return;
         var target = obj.elements['target'].value;
         for (var e = 0; e < obj.elements.length; e++)
         {
@@ -1322,15 +1369,27 @@ function set_reconcile(obj)
     }
     catch (e)
     {
-        alert(e.message)
+        alert_box(e.message)
     }
 }
+function remove_waiting_node()
+{
+    $('info_div').innerHTML = "";
+    $('info_div').style.display = "none";
+    
+}
 function remove_waiting_box()
 {
     removeDiv('wait_box');
-    $('info_div').innerHTML = "";
-    $('info_div').style.display = "none";
+    remove_waiting_node();
 }
+/**
+ * Show all the detail of a profile : Menu, Management, Repository and
+ * let the user to modify it
+ * @param {type} gDossier
+ * @param {type} profile_id
+ * @returns {undefined}
+ */
 function get_profile_detail(gDossier, profile_id)
 {
     waiting_box();
@@ -1342,6 +1401,7 @@ function get_profile_detail(gDossier, profile_id)
                 onFailure: null,
                 onSuccess: function (req) {
                     remove_waiting_box();
+                    $('list_profile').hide();
                     $('detail_profile').innerHTML = req.responseText;
                     req.responseText.evalScripts();
                     $('detail_profile').show();
@@ -1387,6 +1447,12 @@ function calcy(p_sy)
     return sy;
 
 }
+/**
+ * @brief display a box with the menu option
+ * @param {type} gdossier
+ * @param {type} pm_id
+ * @returns {undefined}
+ */
 function mod_menu(gdossier, pm_id)
 {
     waiting_box();
@@ -1404,38 +1470,129 @@ function mod_menu(gdossier, pm_id)
                         add_div({id: "divdm" + pm_id, drag: 1, cssclass: "inner_box", style: pos});
                         $('divdm' + pm_id).innerHTML = req.responseText;
                     } catch (e) {
-                        alert(e.message);
+                        alert_box(e.message);
                     }
                 }
             }
     );
 }
+/**
+ * Display the submenu of a menu or a module, used in setting the menu
+ * 
+ * @param {type} p_dossier
+ * @param {type} p_profile
+ * @param {type} p_dep
+ * @returns {undefined}
+ */
+function display_sub_menu(p_dossier,p_profile,p_dep,p_level)
+{
+    waiting_box();
+    new Ajax.Request('ajax_misc.php',
+    {
+        method:'get',
+        parameters : { op:'display_submenu',
+                gDossier:p_dossier,
+                dep:p_dep,
+                p_profile:p_profile ,
+                p_level : p_level
+            },
+        onSuccess : function (req) {
+            try {
+                remove_waiting_box();
+                if ( $('menu_table').rows.length > p_level ) {
+                    $('menu_table').rows[1].remove();
+                }
+                var new_row = document.createElement('TR');
+                new_row.innerHTML = req.responseText;
+                $('menu_table').appendChild(new_row);
+            } catch (e) {
+                alert_box(e.message);
+            }
+        }
+    })
+}
+/**
+ * in CFGPRO, ask to confirm before removing a submenu and its children
+ * @param {type} p_dossier
+ * @param {type} profile_menu_id
+ * @returns {undefined}
+ */
+function remove_sub_menu(p_dossier,profile_menu_id)
+{
+    confirm_box(null,'Confirme ?', 
+    function () {
+        waiting_box();
+        new Ajax.Request('ajax_misc.php',
+        {                   
+            method:'get',
+            parameters: { op:'remove_submenu',gDossier:p_dossier,
+            p_profile_menu_id:profile_menu_id},
+            onSuccess:function (req) {
+                try {
+                    remove_waiting_box();
+                    $('sub'+profile_menu_id).remove();
+                     if ( $('menu_table').rows.length > 1 ) {
+                          $('menu_table').rows[1].remove();
+                     }
+                    
+                } catch(e)
+                {
+                    alert_box(e.message);
+                }
+            }
+        }
+       )
+    });
+       
+}
+/**
+ * @brief add a menu to a profile, propose only the available menu
+ * @param obj json object 
+ *   - dossier  : , 
+ *   - p_id : profile id , 
+ *   - type : Type of menu are "pr" for Printing "me" for plain menu 
+ *   - p_level : level of menu (0 -> module,1-> top menu, 2->submenu)
+ *   - dep : the parent menu id  (pm_id)
+ * 
+ */
 function add_menu(obj)
 {
     var pdossier = obj.dossier;
     var p_id = obj.p_id;
     var p_type = obj.type;
+    
     waiting_box();
     removeDiv('divdm' + p_id);
-    var qs = "op=add_menu&gDossier=" + pdossier + "&p_id=" + p_id + "&ctl=divdm" + p_id + "&type=" + p_type;
-    var pos = fixed_position(250, 150);
+    var pos = fixed_position(250, 150)+";width:50%;";
     var action = new Ajax.Request('ajax_misc.php',
             {
                 method: 'get',
-                parameters: qs,
+                parameters:  { op:'add_menu',
+                            'gDossier':pdossier , 
+                            'p_id' :p_id ,
+                            'ctl' : 'divdm' + p_id ,
+                            'type' : p_type,
+                            'dep':obj.dep,
+                            'p_level':obj.p_level},
                 onFailure: null,
                 onSuccess: function (req) {
                     try {
                         remove_waiting_box();
-                        add_div({id: "divdm" + p_id, drag: 1, cssclass: "inner_box", style: pos});
+                        add_div({id: "divdm" + p_id, drag: 1, "cssclass": "inner_box", "style": pos});
                         $('divdm' + p_id).innerHTML = req.responseText;
                     } catch (e) {
-                        alert(e.message);
+                        alert_box(e.message);
                     }
                 }
             }
     );
 }
+/**
+ * @brief Display a box to enter data for adding a new plugin from
+ * the CFGMENU
+ * @param {type} p_dossier
+ * @returns {undefined}
+ */
 function add_plugin(p_dossier)
 {
     waiting_box();
@@ -1454,12 +1611,18 @@ function add_plugin(p_dossier)
                         add_div({id: "divplugin", drag: 1, cssclass: "inner_box", style: pos});
                         $('divplugin').innerHTML = req.responseText;
                     } catch (e) {
-                        alert(e.message);
+                        alert_box(e.message);
                     }
                 }
             }
     );
 }
+/**
+ * Modify a menu
+ * @param {type} p_dossier
+ * @param {type} me_code
+ * @returns {undefined}
+ */
 function mod_plugin(p_dossier, me_code)
 {
     waiting_box();
@@ -1479,7 +1642,7 @@ function mod_plugin(p_dossier, me_code)
                         $('divplugin').innerHTML = req.responseText;
 
                     } catch (e) {
-                        alert(e.message);
+                        alert_box(e.message);
                     }
                 }
             }
@@ -1508,7 +1671,7 @@ function create_menu(p_dossier)
                         });
                         $('divmenu').innerHTML = req.responseText;
                     } catch (e) {
-                        alert(e.message);
+                        alert_box(e.message);
                     }
                 }
             }
@@ -1538,7 +1701,7 @@ function modify_menu(p_dossier, me_code)
                         $('divmenu').innerHTML = req.responseText;
 
                     } catch (e) {
-                        alert(e.message);
+                        alert_box(e.message);
                     }
                 }
             }
@@ -1552,7 +1715,7 @@ function get_properties(obj)
     {
         a_array.push(m);
     }
-    alert(s_type + a_array.join(","));
+    alert_box(s_type + a_array.join(","));
 }
 /**
  * @brief add a line in the form for the report
@@ -1617,13 +1780,13 @@ function search_action(dossier, ctl_concern)
                             $('search_action_div').innerHTML = req.responseText;
                             req.responseText.evalScripts();
                         } catch (e) {
-                            alert(e.message);
+                            alert_box(e.message);
                         }
                     }
                 }
         );
     } catch (e) {
-        alert(e.message);
+        alert_box(e.message);
     }
 }
 
@@ -1643,7 +1806,7 @@ function result_search_action(obj)
                             $('search_action_div').innerHTML = req.responseText;
                             req.responseText.evalScripts();
                         } catch (e) {
-                            alert(e.message);
+                            alert_box(e.message);
                         }
                     }
                 }
@@ -1652,7 +1815,7 @@ function result_search_action(obj)
     }
     catch (e)
     {
-        alert("display_periode " + e.message);
+        alert_box("display_periode " + e.message);
     }
 
     return false;
@@ -1688,7 +1851,7 @@ function set_action_related(p_obj)
     }
     catch (e)
     {
-        alert(e.message);
+        alert_box(e.message);
         return false;
     }
 }
@@ -1767,7 +1930,7 @@ function show_fin_chdate(obj_id)
             }
         }
     } catch (e) {
-        alert(e.message);
+        alert_box(e.message);
     }
 }
 /**
@@ -1783,7 +1946,7 @@ function profile_show(p_div)
         $(p_div).show();
     } catch (e)
     {
-        alert(e.message)
+        alert_box(e.message)
     }
 }
 function detail_category_show(p_div, p_dossier, p_id)
@@ -1865,11 +2028,16 @@ function view_action(ag_id, dossier, modify)
                     try {
                         remove_waiting_box();
                         var answer = req.responseXML;
+                        var ctl = answer.getElementsByTagName('ctl');
+                        if ( ctl.length == 0) {
+                            throw 'ajax failed ctl view_action';
+                        }
+                        var ctl_txt=getNodeText(ctl[0]);
                         var html = answer.getElementsByTagName('code');
                         if (html.length === 0)
                         {
                             var rec = req.responseText;
-                            alert('erreur :' + rec);
+                            throw 'ajax failed  html view_action';
                         }
                         var code_html = getNodeText(html[0]);
                         code_html = unescape_xml(code_html);
@@ -1881,9 +2049,9 @@ function view_action(ag_id, dossier, modify)
                             style: pos
                         });
                         $(id).innerHTML = code_html;
-                        compute_all_ledger();
+                        if ( ctl_txt == 'ok') { compute_all_ledger();}
                     } catch (e) {
-                        alert('view_action' + e.message);
+                        alert_box('view_action' + e.message);
                     }
                 }
             }
@@ -2006,7 +2174,7 @@ function ask_navigator(p_dossier) {
                         }
                         catch (e)
                         {
-                            alert("answer_box Impossible executer script de la reponse\n" + e.message);
+                            alert_box("answer_box Impossible executer script de la reponse\n" + e.message);
                         }
 
                     }
@@ -2041,7 +2209,7 @@ function set_preference(p_dossier) {
                         }
                         catch (e)
                         {
-                            alert("answer_box Impossible executer script de la reponse\n" + e.message);
+                            alert_box("answer_box Impossible executer script de la reponse\n" + e.message);
                         }
 
                     }
@@ -2078,7 +2246,7 @@ function show_bookmark(p_dossier) {
                         }
                         catch (e)
                         {
-                            alert("answer_box Impossible executer script de la reponse\n" + e.message);
+                            alert_box("answer_box Impossible executer script de la reponse\n" + e.message);
                         }
 
                     }
@@ -2112,7 +2280,7 @@ function save_bookmark() {
                         }
                         catch (e)
                         {
-                            alert("answer_box Impossible executer script de la reponse\n" + e.message);
+                            alert_box("answer_box Impossible executer script de la reponse\n" + e.message);
                         }
 
                     }
@@ -2144,7 +2312,7 @@ function remove_bookmark() {
                         }
                         catch (e)
                         {
-                            alert("answer_box Impossible executer script de la reponse\n" + e.message);
+                            alert_box("answer_box Impossible executer script de la reponse\n" + e.message);
                         }
 
                     }
@@ -2184,7 +2352,7 @@ function show_tag(p_dossier, p_ac, p_tag_id, p_post)
                         if (html.length === 0)
                         {
                             var rec = req.responseText;
-                            alert('erreur :' + rec);
+                            alert_box('erreur :' + rec);
                         }
                         var code_html = getNodeText(html[0]);
                         code_html = unescape_xml(code_html);
@@ -2197,7 +2365,7 @@ function show_tag(p_dossier, p_ac, p_tag_id, p_post)
                         }
                         catch (e)
                         {
-                            alert("answer_box Impossible executer script de la reponse\n" + e.message);
+                            alert_box("answer_box Impossible executer script de la reponse\n" + e.message);
                         }
 
                     }
@@ -2492,14 +2660,17 @@ function action_hide_checkbox()
 function calendar_zoom(obj)
 {
     try {
-
-        var query = "";
-        query = "op=calendar_zoom&gDossier=" + obj.gDossier + "&in=" + $(obj.invalue).value + '&out=' + obj.outdiv;
         waiting_box();
+        var per_periode=null;
+        var notitle=0;
+        var from=0;
+        if ( $(obj.invalue) ) { per_periode=$(obj.invalue).value;}
+        if ( obj.notitle && obj.notitle==1 ) { notitle=1;}
         var action = new Ajax.Request(
                 "ajax_misc.php",
                 {
-                    method: 'get', parameters: query,
+                    method: 'get', 
+                    parameters: { "notitle":notitle,"op":'calendar_zoom','from':from,'gDossier':obj.gDossier,'in':per_periode ,'out' : obj.outdiv,'distype':obj.distype},
                     onFailure: ajax_misc_failure,
                     onSuccess: function (req, j) {
                         var answer = req.responseXML;
@@ -2519,7 +2690,7 @@ function calendar_zoom(obj)
                         }
                         if ($(obj.outdiv) == undefined) {
                             var str_style = fixed_position(0, 20);
-                            add_div({id: obj.outdiv, style: 'margin-left:3%;width:94%;height:94%;' + str_style, cssclass: "inner_box", drag: 1});
+                            add_div({id: obj.outdiv, style: 'margin-left:3%;width:94%;' + str_style, cssclass: "inner_box", drag: 1});
                         }
                         remove_waiting_box();
                         $(obj.outdiv).innerHTML = code_html;
@@ -2570,7 +2741,7 @@ function stock_add_row()
 
         new_tt.evalScripts();
     } catch (e) {
-        alert(e.message);
+        alert_box(e.message);
     }
 
 }
@@ -2617,7 +2788,7 @@ function show_tabs(a_tabs, p_display_tab)
         }
         $(p_display_tab).show();
     } catch (e) {
-        alert(e.message);
+        alert_box(e.message);
     }
 
 }
@@ -2652,4 +2823,110 @@ function logout()
     var tmp_last = tmp_b.length - 1
     var place_logout = tmp_place.replace(tmp_b[tmp_last], 'logout.php');
     window.location.href = place_logout;
-}
\ No newline at end of file
+}
+/**
+ * Create a div which can be used in a anchor
+ * @returns {undefined}
+ */
+function create_anchor_up()
+{
+    if ( $('up_top')) return;
+    
+    var newElt = new Element('div');
+    newElt.setAttribute('id', 'up_top');
+    newElt.innerHTML='<a id="up_top"></a>';
+    
+    var parent = $('info_div').parentNode;
+    parent.insertBefore(newElt, $('info_div'));
+    
+}
+/**
+ * Initialize the window to show the button "UP" if the window is scrolled
+ * vertically
+ * @returns {undefined}
+ */
+function init_scroll()
+{
+    var up=new Element('div',{"class":"inner_box",
+            "style":"padding:10px;left:auto;width:30px;height: auto;display:none;position:fixed;top:25px;right:20px;text-align:center",
+            id:"go_up"
+        });
+        up.innerHTML=' <a class="button" href="#up_top" >&#8679;</a>';
+        document.body.appendChild(up);
+         window.onscroll=function () {
+         if ( document.viewport.getScrollOffsets().top> 0) {
+             if ($('go_up').visible() == false) {
+                $('go_up').setOpacity(0.85); 
+                $('go_up').show();
+            }
+        } else {
+            $('go_up').hide();
+        }
+     }
+}
+/**
+ * Confirm a form thanks a modal dialog Box, it returns true if we agree otherwise
+ * false
+ * @code
+<form onsubmit="return confirm_box(this,'message')">
+</form>
+ * @endcode
+ * @param p_obj form element (object) or element id (string)
+ * @param p_message message to display
+ * @returns true or false
+ */
+function confirm_box(p_obj, p_message,p_callback_true)
+{
+    waiting_box();
+    try {
+        // Find id of the end
+        var name="";
+        if ( p_obj != null )
+        {
+            if ( typeof (p_obj) === "object") {
+                name=p_obj.id;
+            } else {
+                name=p_obj;
+            }
+        }
+       
+       // execute the callback function or submit the form
+       if ( p_callback_true == undefined || p_callback_true==null)
+        {
+            smoke.confirm(p_message,function (e) {
+                if ( e ) {
+                    $(name).submit();
+                }
+            });
+        } else {
+            smoke.confirm(p_message,function (e) 
+            {
+                if ( e ) { p_callback_true.apply();}
+            });
+        }
+    } catch (e) {
+        alert_box(e.getMessage);
+    }
+    remove_waiting_box();
+    return false;
+}
+/**
+ * Alert box in CSS and HTML to replace the common javascript alert
+ * @param p_message message to display
+ * @returns void
+ */
+function alert_box(p_message)
+{
+    smoke.alert(p_message,false , {ok:'ok',classname:"inner_box"});
+}
+
+/**
+ * All the onload must be here otherwise the other will overwritten
+ * @returns {undefined}
+ */
+window.onload=function ()
+{
+    create_anchor_up();
+    init_scroll();
+    sorttable.init
+}
