@@ -17,16 +17,18 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-require_once('../include/ac_common.php');
-require_once('function_javascript.php');
-require_once('class_html_input.php');
-require_once('class_dossier.php');
-require_once('class_database.php');
-require_once('class_user.php');
-require_once('class_periode.php');
-echo '<div style="float:left;">'.HtmlInput::print_window();
+require_once '../include/constant.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/function_javascript.php';
+require_once NOALYSS_INCLUDE.'/class_html_input.php';
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_user.php';
+require_once NOALYSS_INCLUDE.'/class_periode.php';
+
 
 html_page_start($_SESSION['g_theme']);
+echo '<div style="float:left;">';
 global $g_user;
 if ( basename($_GET['ajax']) == 'ajax_history.php' )
   {
@@ -67,10 +69,13 @@ if ( basename($_GET['ajax']) == 'ajax_history.php' )
 	$href_csv="export.php?".$href.'&f_id='.$_GET['f_id'].'&ople=0&type=poste&'.$from_periode.'&'.$to_periode."&act=CSV:fichedetail";
 	$href_pdf="export.php?".$href.'&f_id='.$_GET['f_id'].'&ople=0&type=poste&'.$from_periode.'&'.$to_periode."&act=PDF:fichedetail";
       }
-
+    echo HtmlInput::print_window();
     echo '<a class="smallbutton"  href="'.$href_csv.'">'._("Export CSV").'</a>';
     echo '<a class="smallbutton"  href="'.$href_pdf.'">'._("Export PDF").'</a>';
   }
+  else {
+      echo HtmlInput::print_window();
+  }
 echo '</div>';
 echo HtmlInput::hidden('inpopup',1);
 load_all_script();
