@@ -22,13 +22,14 @@
 
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
 require_once '../include/constant.php';
-include_once ("ac_common.php");
-require_once('class_database.php');
-require_once('class_itext.php');
-require_once 'function_javascript.php';
+include_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_itext.php';
+require_once NOALYSS_INCLUDE.'/function_javascript.php';
+
 @html_page_start($_SESSION['g_theme']);
 $rep=new Database();
-include_once ("class_user.php");
+include_once NOALYSS_INCLUDE.'/class_user.php';
 $User=new User($rep);
 
 $User->Check();
@@ -85,10 +86,13 @@ if ( $User->Admin()  == 1)
 	if (SITE_UPDATE !="") {
 	 $update=@file_get_contents(SITE_UPDATE);
 	 if ($update > $version_noalyss ) {
-		 echo '<div class="inner_box" style="margin-left:0px;margin-top:3px;left:3px">';
+		 echo '<div id="version_div" class="inner_box" style="width:25%;margin-left:10%;margin-top:3px;">';
 		 echo '<p class="notice">';
 		 echo "Mise à jour disponible de NOALYSS version actuelle : $update votre version $version_noalyss";
 		 echo '</p>';
+                 echo '<p style="text-align:center"> <a class="button" onclick="document.body.removeChild(document.getElementById(\'version_div\'))">'.
+                         _('Fermer').
+                         "</a></p>";
 		 echo '</div>';
 	 }
 	}
@@ -110,6 +114,8 @@ if ( isset ($_POST['set_preference'])) {
     $User->save_global_preference('LANG', $lang);
     $_SESSION['g_theme']=$style_user;
     $_SESSION['g_lang']=$lang;
+    $User->load();
+    $User->save_email($p_email);
 }
 echo '<div class="welcome"> ';
 /**
@@ -154,18 +160,16 @@ $result.='<TD  class="tool" ><A class="cell" HREF="logout.php" >'._('Deconnexion
 $result.="</TR>";
 $result.="</table>";
 
-echo '<h2 class="info">'._('Bienvenue')."  ".$User->first_name.'  '.$User->name.'   '._("dans NOALYSS")."</h2>";
 echo '<div id="module">'.$result.'</div>';
 echo '</div>';
 ?>
 <div class="foldercontent">
-<?php echo '<h2 >'._('Choisissez un dossier').'</h2>';?>
-	<span style="display:block;margin:2.5%">
+	<span style="display:block;margin:2%">
  <?php
                         echo _('Filtre').HtmlInput::infobulle(23);
 ?>
 <?php
-	echo HtmlInput::filter_table("folder", '1,2',0);
+	echo HtmlInput::filter_table("folder", '1,2',1);
 ?>
 </span>
 <?php
@@ -177,6 +181,7 @@ echo $res;
 <P>
 
 </P>
+</div>
 <?php
 html_page_stop();
 ?>
