@@ -25,11 +25,13 @@
  * @brief common utilities for a lot of procedure, classe
  */
 
-include_once("constant.php");
-require_once('class_database.php');
-require_once('class_periode.php');
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_periode.php';
+require_once NOALYSS_INCLUDE.'/class_html_input.php';
+require_once NOALYSS_INCLUDE.'/function_javascript.php';
 
-/**\brief to protect again bad characters which can lead to a cross scripting attack
+/**
+ * \brief to protect again bad characters which can lead to a cross scripting attack
   the string to be diplayed must be protected
  */
 
@@ -88,8 +90,9 @@ function tr($p_string, $p_extra='')
     return '<tr  ' . $p_extra . '>' . $p_string . '</tr>';
 }
 
-/**\brief escape correctly php string to javascript */
-
+/**
+ * @brief escape correctly php string to javascript 
+ */
 function j($p_string)
 {
     $a = preg_replace("/\r?\n/", "\\n", addslashes($p_string));
@@ -256,7 +259,6 @@ function isDate($p_date)
 
 function html_page_start($p_theme="", $p_script="", $p_script2="")
 {
-    require_once 'class_html_input.php';
     // check not called twiced
     static  $already_call=0;
     if ( $already_call==1)return;
@@ -293,31 +295,37 @@ function html_page_start($p_theme="", $p_script="", $p_script2="")
     $is_msie=is_msie();
     
     if ($is_msie == 0 ) 
+    {
         echo '<!doctype html>';
-    else
-         echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 FINAL//EN" >';
-    
+        printf("\n");
+        echo '<meta name="viewport" content="width=device-width, initial-scale=1.0">';
+        printf("\n");
+    }
+    else {
+        echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 FINAL//EN" >';
+        printf("\n");
+    }
     echo "<HTML>";
 
     if ($p_script2 != "")
-	$p_script2 = '<script src="' . $p_script2 . '" type="text/javascript"></script>';
+	$p_script2 = '<script src="' . $p_script2 . '?version='.SVNINFO.'" type="text/javascript"></script>';
     $style=trim($style);
-    $DIR=dirname(__FILE__);
     echo "<HEAD>";
     if ( $is_msie == 1 )echo '      <meta http-equiv="x-ua-compatible" content="IE=edge"/>';
     echo "
     <TITLE>$title</TITLE>
 	<link rel=\"icon\" type=\"image/ico\" href=\"favicon.ico\" />
     <META http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\">
-    <LINK REL=\"stylesheet\" type=\"text/css\" href=\"./$style\" media=\"screen\">
-    <link rel=\"stylesheet\" type=\"text/css\" href=\"style-print.css\" media=\"print\">" .
+    <LINK REL=\"stylesheet\" type=\"text/css\" href=\"".$style."?version=".SVNINFO."\" media=\"screen\"/>
+    <link rel=\"stylesheet\" type=\"text/css\" href=\"./style-print.css?version=".SVNINFO."\" media=\"print\"/>" .
     $p_script2 . "
     ";
     echo '<script language="javascript" src="js/calendar.js"></script>
     <script type="text/javascript" src="js/lang/calendar-en.js"></script>
     <script language="javascript" src="js/calendar-setup.js"></script>
-    <LINK REL="stylesheet" type="text/css" href="calendar-blue.css" media="screen">';
-
+    <LINK REL="stylesheet" type="text/css" href="./calendar-blue.css" media="screen">
+    ';
+    echo load_all_script();
     echo '    </HEAD>    ';
 
     echo "<BODY $p_script>";
@@ -381,7 +389,9 @@ function html_min_page_start($p_theme="", $p_script="", $p_script2="")
     <LINK REL=\"stylesheet\" type=\"text/css\" href=\"$style\" media=\"screen\">
     <link rel=\"stylesheet\" type=\"text/css\" href=\"style-print.css\" media=\"print\">" .
     $p_script2 . "
-    <script src=\"js/scripts.js\" type=\"text/javascript\"></script>";
+    <script src=\"js/scripts.js\" type=\"text/javascript\"></script>
+    <script src=\"js/acc_ledger.js\" type=\"text/javascript\"></script>
+    <script src=\"js/smoke.js\" type=\"text/javascript\"></script>";
     echo '</HEAD>
     ';
 
@@ -642,7 +652,7 @@ function sql_filter_per($p_cn, $p_from, $p_to, $p_form='p_id', $p_field='jr_tech
 function alert($p_msg, $buffer=false)
 {
     $r = '<script>';
-    $r.= 'alert(\'' . j($p_msg) . '\')';
+    $r.= 'alert_box(\'' . j($p_msg) . '\')';
     $r.= '</script>';
 
     if ($buffer)
@@ -774,7 +784,8 @@ function format_date($p_date, $p_from_format = 'YYYY-MM-DD',$p_to_format='DD.MM.
 
 
 /**
- * Should a dialog box that you are disconnected for ajax
+ * Should a dialog box when you are disconnected from an ajax call
+ * propose to reload or to connect in another tab
  */
 function ajax_disconnected($div)
 {
@@ -783,16 +794,27 @@ function ajax_disconnected($div)
      */
     if (!isset($_SESSION['g_user']))
     {
-	$script = 'var a=$("' . $div . '");a.style.height="70%";a.style.width="70%";';
+	$script = 'var a=$("' . $div . '");a.style.height="70%";a.style.width="60%";';
 	$script.='a.style.top=posY-20+offsetY;a.style.left=posX+offsetX;';
 	$script = create_script($script);
 	$html = $script;
 	$html.=HtmlInput::anchor_close($div);
 	$html.='<div>';
 	$html.=h2(_('Données non disponibles'), 'class="title" style="width:auto"');
-	$html.=h2(_('Veuillez vous reconnecter'), 'class="error"');
-	$html.=alert(_("Déconnecté"), true);
-        $html.="<script>logout();</script>";
+	$html.=h2(_('Veuillez vous reconnecter soit dans une autre fenêtre soit '
+                . ' en cliquant sur le lien'), 'class="error"');
+        // Reload button
+        $reload=new IButton("reload");
+        $reload->value=_("Se reconnecter pour revenir ici");
+        $reload->class="button";
+        $reload->javascript='window.location.reload()';
+        // Link to log in another tab
+        $html.='<p style="text-align:center">';
+        $html.='<a href="index.php" class="button" target="_blank">'.
+                _('Cliquez ici pour vous reconnecter dans une autre page').
+                '</a>';
+        $html.=$reload->input();
+        $html.='</p>';
 	$html = escape_xml($html);
 	header('Content-type: text/xml; charset=UTF-8');
 	echo <<<EOF
@@ -807,8 +829,8 @@ EOF;
 }
 
 /**
- *
- * @param int $selected module selected
+ *Show the modules
+ * @param int $selected module selected profile_menu.pm_id
  */
 function show_module($selected)
 {
@@ -818,15 +840,17 @@ function show_module($selected)
 	me_code,me_menu,me_url,me_javascript,p_order,me_type,me_description
 	from v_all_menu
 	where
-	user_name=$1
+	p_id=$1
 	and p_type_display='M'
-	order by p_order", array($g_user->login));
+	order by p_order", array($g_user->get_profile()));
 
     if ($selected != -1)
     {
-	require_once('template/module.php');
+        $selected_module=$cn->get_value('select me_code from profile_menu where'
+                . ' pm_id = $1 ', array($selected));
+	require_once NOALYSS_INCLUDE.'/template/module.php';
 	$file = $cn->get_array("select me_file,me_parameter,me_javascript,me_type,me_description from v_all_menu
-	    where me_code=$1 and user_name=$2", array($selected,$g_user->login));
+	    where pm_id=$1 and p_id=$2", array($selected,$g_user->get_profile()));
 	if ( count($file ) == 0 )
 	{
 		echo '</div>';
@@ -914,8 +938,17 @@ function find_default_module()
 			*/
 			if (empty ($default_module))
 			{
-				echo_warning(_("Utilisateur n'a pas de profile, votre administrateur doit en configurer un dans CFGSEC"));
-				exit();
+                            /* 
+                             * If administrateur, then we insert a default profile (1)
+                             * for him
+                             */
+                            if ( $g_user->admin == 1 )
+                            {
+                                $cn->exec_sql('insert into profile_user(user_name,p_id) values ($1,1) ',array($g_user->login));
+                                return find_default_module();
+                            }
+                            echo_warning(_("Utilisateur n'a pas de profil, votre administrateur doit en configurer un dans CFGSEC"));
+                            exit();
 			}
 		}
 		return $default_module[0]['me_code'];
@@ -938,34 +971,65 @@ function find_default_module()
  * @param $module the $_REQUEST['ac'] exploded into an array
  * @param  $idx the index of the array : the AD code is splitted into an array thanks the slash
  */
-function show_menu($module, $idx)
+function show_menu($module)
 {
+    if ($module == 0)return;
+    static $level=0;
     global $g_user;
+    
     $cn = Dossier::connect();
-    $amenu = $cn->get_array("select
-	me_menu,me_code,me_url,me_javascript,me_type,me_description
-	from v_all_menu
-	where
-	me_code_dep=$1 and user_name=$2 order by p_order", array($module[$idx], $g_user->login));
-
+    /**
+     * Show the submenus
+     */
+    $amenu = $cn->get_array("
+        select 
+            pm_id,
+            me_code,
+            pm_id_dep,
+            me_file,
+            me_javascript,
+            me_url,
+            me_menu,
+            me_description,
+            me_description_etendue
+            from profile_menu 
+            join menu_ref using (me_code) 
+            where pm_id_dep=$1 and p_id=$2
+	 order by p_order", array($module, $g_user->get_profile()));
+    
+    // There are submenuS, so show them
     if (!empty($amenu) && count($amenu) > 1)
     {
         $a_style_menu=array('topmenu','menu2','menu3');
-        if ( $idx > count($a_style_menu))
+        if ( $level > count($a_style_menu))
             $style_menu='menu3';
         else {
-            $style_menu=$a_style_menu[$idx];
+            $style_menu=$a_style_menu[$level];
         }
 		require 'template/menu.php';
-    }
+    } // there is only one submenu so we include the code or javascript 
+      // or we show the submenu
     elseif (count($amenu) == 1)
     {
+        if ( trim($amenu[0]['me_url']) != "" ||
+             trim ($amenu[0]['me_file']) != "" ||
+             trim ($amenu[0]['me_javascript']) != "" )
+        {
 		echo '<div class="topmenu">';
-		echo h2info($amenu[0]['me_menu']);
+		echo h2info(_($amenu[0]['me_menu']));
 		echo '</div>';
-		$module[$idx] = $amenu[0]['me_code'];
+		$module = $amenu[0]['pm_id'];
+        } else {
+           $url=$_REQUEST['ac'].'/'.$amenu[0]['me_code'];
+           echo '<a href="do.php?gDossier='.Dossier::id().'&ac='.$url.'">';
+           echo _($amenu[0]['me_menu']);
+           echo '</a>';
+           $level++;
+           return;
+        }
     }
-
+    
+    // There is no submenu or only one
     if (empty($amenu) || count($amenu) == 1)
     {
 		$file = $cn->get_array("select me_file,me_parameter,me_javascript,me_type
@@ -973,15 +1037,14 @@ function show_menu($module, $idx)
 		join profile_menu using (me_code)
 		join profile_user using (p_id)
 		where
-		me_code=$1 and
+		pm_id=$1 and
 		user_name=$2 and
 		(me_file is not null or trim(me_file) <>'' or
-		me_javascript is not null or trim (me_javascript) <> '')", array($module[$idx],$g_user->login));
+		me_javascript is not null or trim (me_javascript) <> '')", array($module,$g_user->login));
 
 		if (count($file)==0)
 		{
-			echo "Configuration incorrecte pour ce module ".$module[$idx];
-			exit;
+                        return;
 		}
 
 		if ($file[0]['me_file'] != "")
@@ -992,6 +1055,7 @@ function show_menu($module, $idx)
 				$array=compute_variable($file[0]['me_parameter']);
 				put_global($array);
 			}
+                        if ( DEBUG ) echo  $file[0]['me_file']," param : ",$file[0]['me_parameter'] ;
                         /*
                          * Log the file we input to put in the folder test-noalyss for replaying it
                          */
@@ -1016,6 +1080,7 @@ function show_menu($module, $idx)
                     echo create_script($js);
 		}
     }
+    $level++;
 }
 /**
  * Put in superglobal (get,post,request) the value contained in
@@ -1066,10 +1131,16 @@ function ajax_xml_error($p_code,$p_string)
 </data>
 EOF;
 }
+/**
+ * @brief Display a box with the contains
+ * @param type $p_array Data to display
+ * @param type $p_title Title of the box
+ * @param type $p_div id of the box
+ */
 function display_dashboard_operation($p_array,$p_title,$p_div)
 {
 	?>
-<div id="<?php echo $p_div;?>" class="inner_box" style="display:none;top:250;left:25%;width: 50%;min-height:50%;overflow:auto;">
+<div id="<?php echo $p_div;?>" class="inner_box" style="display:none;position:fixed;top:250px;left:12%;width: 75%;min-height:50%;overflow:auto;">
 	<?php
 	echo HtmlInput::title_box($p_title, $p_div, "hide");
 	?>
@@ -1078,6 +1149,7 @@ function display_dashboard_operation($p_array,$p_title,$p_div)
 		<tr>
 			<th><?php echo _('Date')?></th>
 			<th><?php echo _('Code Interne')?></th>
+			<th><?php echo _('Pièce')?></th>
 			<th><?php echo _('Description')?></th>
 			<th>
 				<?php echo _('Montant')?>
@@ -1094,6 +1166,9 @@ function display_dashboard_operation($p_array,$p_title,$p_div)
 			<td>
 				<?php echo HtmlInput::detail_op($p_array[$i]['jr_id'], $p_array[$i]['jr_internal']) ?>
 			</td>
+                        <td>
+                            <?php echo h($p_array[$i]['jr_pj_number'])?>
+                        </td>
 			<td>
 				<?php echo h($p_array[$i]['jr_comment']) ?>
 			</td>
@@ -1176,4 +1251,4 @@ function is_msie()
         $is_msie=0;
     return $is_msie;
 }
-?>
+?>
\ No newline at end of file
