@@ -97,7 +97,7 @@ if (isset($_POST['generate']))
 	$sub_action = 'detail';
 }
 /* for delete  */
-if (isset($_POST['delete']))
+if (isset($_POST['delete']) && $_POST['delete'] == "1")
 	$sub_action = 'delete';
 if ($sub_action == "")
 	$sub_action = "list";
@@ -196,15 +196,16 @@ if ($sub_action == 'detail')
         
 	if ($g_user->can_write_action($ag_id)  == true)
 	{
-		echo '<form  enctype="multipart/form-data"  class="print" action="do.php"  method="post"   >';
+		echo '<form  enctype="multipart/form-data"  id="action_common_frm" class="print" action="do.php"  method="post"   >';
 		echo $supl_hidden;
 		echo HtmlInput::hidden('ac', $_REQUEST['ac']);
 		echo dossier::hidden();
 		echo $act->Display('UPD', false, $base, $retour);
 		echo '<input type="hidden" name="sa" value="update">';
-		echo HtmlInput::submit("save", "Sauve");
-		echo HtmlInput::submit("add_action_here", _("Ajoute une action à celle-ci"));
-		echo HtmlInput::submit("delete", _("Efface cette action"), ' onclick="return confirm(\'' . _("Vous confirmez l\'effacement") . '\')" ');
+		echo '<input type="hidden" id="delete" name="delete" value="0">';
+		echo HtmlInput::submit("save", "Sauve",' onclick="$(\'delete\').value=0"');
+		echo HtmlInput::submit("add_action_here", _("Ajoute un événement à celui-ci"),' onclick="$(\'delete\').value=0"');
+		echo HtmlInput::submit("delete_bt", _("Efface cet événement "), ' onclick="$(\'delete\').value=1;return confirm_box(\'action_common_frm\',\''. _("Vous confirmez l\'effacement") . '\')" ');
 		echo $retour;
 		echo '</form>';
 	}
@@ -269,11 +270,11 @@ if ($sub_action == "save_action_st2")
 	// insert into action_gestion
 	echo $act->save();
 	$url = "?$base&sa=detail&ag_id=" . $act->ag_id . '&' . dossier::get();
-	echo '<p><a class="mtitle" href="' . $url . '">' . hb(_('Action Sauvée').'  : ' . $act->ag_ref) . '</a></p>';
+	echo '<p><a class="mtitle" href="' . $url . '">' . hb(_('Evènement Sauvée').'  : ' . $act->ag_ref) . '</a></p>';
 
 	Follow_Up::show_action_list($cn,$base);
 	$url = "?$base&sa=detail&ag_id=" . $act->ag_id . '&' . dossier::get();
-	echo '<p><a class="mtitle" href="' . $url . '">' . hb(_('Action Sauvée').'  : ' . $act->ag_ref) . '</a></p>';
+	echo '<p><a class="mtitle" href="' . $url . '">' . hb(_('Evènement Sauvée').'  : ' . $act->ag_ref) . '</a></p>';
     } catch (Exception $e)
     {
         echo '<span class="notice">';
