@@ -21,16 +21,13 @@
  * the customer category
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_iselect.php");
-require_once("class_ihidden.php");
-require_once("class_customer.php");
-require_once("class_ibutton.php");
-require_once('class_iaction.php');
-require_once('class_fiche_def.php');
-require_once('class_iaction.php');
-require_once('class_fiche_def.php');
-require_once('class_ipopup.php');
-require_once('class_admin.php');
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_customer.php';
+require_once NOALYSS_INCLUDE.'/class_ibutton.php';
+require_once NOALYSS_INCLUDE.'/class_fiche_def.php';
+require_once NOALYSS_INCLUDE.'/class_fiche_def.php';
+require_once NOALYSS_INCLUDE.'/class_admin.php';
 
 global $g_user;
 
@@ -48,20 +45,23 @@ if ( $low_action  == "" )
 //-----------------------------------------------------
 // Remove a card
 //-----------------------------------------------------
-if ( isset($_POST['delete_card'] ) )
+if ( isset($_POST['action_fiche'] ) )
 {
-    if ( $g_user->check_action(FICADD) == 0 )
+    if ( $_POST['action_fiche'] == 'delete_card') 
     {
-        alert('Vous  ne pouvez pas enlever de fiche');
-        return;
+        if ( $g_user->check_action(FICADD) == 0 )
+        {
+            alert(_('Vous  ne pouvez pas enlever de fiche'));
+            return;
+        }
+
+        $f_id=$_REQUEST['f_id'];
+
+        $fiche=new Admin($cn,$f_id);
+        $fiche->remove();
+        $low_action="list";
     }
 
-    $f_id=$_REQUEST['f_id'];
-
-    $fiche=new Admin($cn,$f_id);
-    $fiche->remove();
-    $low_action="list";
-
 }
 
 //-----------------------------------------------------
@@ -77,17 +77,27 @@ if ( $low_action == "list" )
 	<?php
 	echo '<h2>' . "Exercice " . $g_user->get_exercice() . '</h2>';
 	echo dossier::hidden();
-    $a=(isset($_GET['query']))?$_GET['query']:"";
-    printf (_('Recherche').' <input class="input_text" type="text" name="query" value="%s">',
-            $a);
-	echo HtmlInput::request_to_hidden(array('ac'));
-    $sel_card=new ISelect('cat');
-    $sel_card->value=$cn->make_array('select fd_id, fd_label from fiche_def '.
-                                     ' where  frd_id=$1 '.
-                                     ' order by fd_label ',1,array(FICHE_TYPE_ADM_TAX));
-    $sel_card->selected=(isset($_GET['cat']))?$_GET['cat']:-1;
-    $sel_card->javascript=' onchange="submit(this);"';
-    echo _('Catégorie :').$sel_card->input();
+        $a=(isset($_GET['query']))?$_GET['query']:"";
+        printf (_('Recherche').' <input class="input_text" type="text" name="query" value="%s">',
+                $a);
+        echo HtmlInput::request_to_hidden(array('ac'));
+        $choice_cat=HtmlInput::default_value_request("choice_cat", 1);
+        if ( $choice_cat == 1 )
+        {
+            $sel_card=new ISelect('cat');
+            $sel_card->value=$cn->make_array('select fd_id, fd_label from fiche_def '.
+                                             ' where  frd_id=$1 '.
+                                             ' order by fd_label ',1,array(FICHE_TYPE_ADM_TAX));
+            $sel_card->selected=(isset($_GET['cat']))?$_GET['cat']:-1;
+            $sel_card->javascript=' onchange="submit(this);"';
+            echo _('Catégorie :').$sel_card->input();
+        } else
+        {
+            $cat=HtmlInput::default_value_request('cat', '');
+            echo HtmlInput::hidden("cat",$cat);
+            echo HtmlInput::hidden('choice_cat', 0);
+        }
+            echo Dossier::hidden();
 
     ?>
     <input type="submit" class="button" name="submit_query" value="<?php echo _('recherche')?>">
@@ -141,7 +151,7 @@ if ( $low_action == "list" )
 if ( $low_action == 'detail')
 {
     /* Menu */
-    require_once('category_card.inc.php');
+    require_once NOALYSS_INCLUDE.'/category_card.inc.php';
 return;
 }
 
