@@ -3,8 +3,8 @@
 //see licence.txt
 
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once ("class_database.php");
-require_once 'class_user.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_user.php';
 $cn=new Database($_GET['gDossier']);
 
 
