@@ -18,12 +18,17 @@
  */
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
 if ( !defined ('ALLOWED') )  die('Appel direct ne sont pas permis');
-require_once 'class_calendar.php';
+require_once NOALYSS_INCLUDE.'/class_calendar.php';
 ob_start();
-echo HtmlInput::title_box(_("Calendrier"), "calendar_zoom_div");
+if ( $notitle== 0 ) echo HtmlInput::title_box(_("Calendrier"), "calendar_zoom_div");
 $cal=new Calendar();
-$cal->set_periode($_GET['in']);
-echo $cal->zoom();
+$in=HtmlInput::default_value_get('in',"");
+$notitle=HtmlInput::default_value_get('notitle',"0");
+if ( $in == "") {
+    $in=$cal->get_preference();
+}
+$cal->set_periode($in);
+echo $cal->zoom($distype,$notitle);
 $response=  ob_get_clean();
 
 $html=escape_xml($response);
