@@ -27,18 +27,25 @@
  *
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once 'class_profile_sql.php';
-require_once 'class_profile_menu.php';
+
+// Security 
+if ( $g_user->check_module('CFGPRO') == 0 ) die();
+
+require_once NOALYSS_INCLUDE.'/class_profile_sql.php';
+require_once NOALYSS_INCLUDE.'/class_profile_menu.php';
+require_once NOALYSS_INCLUDE.'/class_html_input.php';
+$p_id=HtmlInput::default_value_request('p_id', -1);
 $profile=new Profile_sql($cn,$p_id);
 $gDossier=Dossier::id();
-$add_menu=HtmlInput::button("add", "Ajout Menu","onclick=\"add_menu({dossier:$gDossier,p_id:$p_id,type:'me'})\"");
-$add_impression=HtmlInput::button("add", "Ajout Menu","onclick=\"add_menu({dossier:$gDossier,p_id:$p_id,type:'pr'})\"");
+$add_impression=HtmlInput::button("add", _("Ajout Menu"),"onclick=\"add_menu({dossier:$gDossier,p_id:$p_id,type:'pr'})\"");
 $call_tab=HtmlInput::default_value_post('tab', 'none');
 $a_tab=array('profile_gen_div'=>'tabs','profile_menu_div'=>'tabs','profile_print_div'=>'tabs','profile_gestion_div'=>'tabs','profile_repo_div'=>'tabs');
 $a_tab[$call_tab]='tabs_selected';
 ?>
-<hr>
 <h1>Profil <?php echo $profile->p_name?></h1>
+<?php
+    echo HtmlInput::anchor(_('Retour'), "", " onclick = \" $('detail_profile').hide();$('list_profile').show(); \" ", 'class="line"');
+?>
 <?php if ($p_id > 0 ) : ?>
 <ul class="tabs">
     
@@ -69,49 +76,52 @@ else
 {
 	echo '<div  class="myfieldset" id="profile_gen_div">';
 }
-echo '<form method="POST" onsubmit="return confirm (\'vous confirmez\')">';
+echo '<form method="POST" id="profile_save_name_frm" onsubmit="return confirm_box(this,\'vous confirmez\')">';
 echo HtmlInput::hidden('tab','profile_gen_div');
 echo HtmlInput::hidden('p_id',$profile->p_id);
+echo HtmlInput::hidden('save_name',1);
 require_once("template/profile.php");
-echo HtmlInput::submit("save_name",_("Modifier"));
+echo HtmlInput::submit("save_namebt",_("Modifier"));
 echo '</form>';
 if ($profile->p_id > 0)
 {
-	echo '<form method="POST" onsubmit="return confirm (\''._("vous confirmez").'\')">';
+	echo '<form method="POST" id="profile_clone_frm" onsubmit="return confirm_box(this,\''._("vous confirmez").'\')">';
 
-	echo 'Vous pouvez aussi copier ce profil et puis le corriger';
+	echo _('Vous pouvez aussi copier ce profil et puis le corriger');
 
 	echo HtmlInput::hidden('p_id', $profile->p_id);
-	echo HtmlInput::submit("clone", "Copier");
+	echo HtmlInput::hidden('clone', 1);
+	echo HtmlInput::submit("clonebt", "Copier");
 	echo '</form>';
 
-	echo '<form method="POST" onsubmit="return confirm (\''._("vous confirmez").'\')">';
+	echo '<form method="POST" id="delete_profile_frm" onsubmit="return confirm_box(this,\''._("vous confirmez").'\')">';
 
 	echo _('Effacer ce profil');
 
 	echo HtmlInput::hidden('p_id', $profile->p_id);
+	echo HtmlInput::hidden('delete_profil', 1);
 	echo HtmlInput::submit("delete_profil", _("Effacer ce profil"));
 	echo '</form>';
         echo '</div>';
         echo '<div class="myfieldset"  style="display:none" id="profile_menu_div">';
 	//Menu / Module /plugin in this profile
-	echo "<h1 class=\"legend\">"."Menu"."</h2>";
-	echo $add_menu;
+	echo "<h1 class=\"legend\">"._("Menu")."</h2>";
 	$profile_menu = new Profile_Menu($cn);
-	$profile_menu->listing_profile($p_id);
+        $profile_menu->p_id=$p_id;
+	$profile_menu->display_profile_menu_detail();
         echo '</div>';
         echo '<div class="myfieldset"  style="display:none" id="profile_print_div">';
 	echo "<h1 class=\"legend\">"._("Impression")."</h1>";
-	$profile_menu->printing($p_id);
+	$profile_menu->printing();
 	echo $add_impression;
         echo '</div>';
         echo '<div class="myfieldset"  style="display:none" id="profile_gestion_div">';
-	echo "<h1 class=\"legend\">Action gestion accessible</h1>";
-	$profile_menu->available_profile($p_id);
+	echo "<h1 class=\"legend\">".('Groupe gestion')."</h1>";
+	$profile_menu->available_profile();
         echo '</div>';
         echo '<div class="myfieldset"  style="display:none" id="profile_repo_div">';
-	echo "<h1 class=\"legend\">"."Dépôt de stock accessible"."</h1>";
-	$profile_menu->available_repository($p_id);
+	echo "<h1 class=\"legend\">"._("Dépôt de stock accessible")."</h1>";
+	$profile_menu->available_repository();
         echo '</div>';
         if ( isset ($_POST['tab']))
         {
