@@ -26,8 +26,8 @@
  *
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once('class_user.php');
-require_once('class_dossier.php');
+require_once NOALYSS_INCLUDE.'/class_user.php';
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
 extract($_GET);
 /* check the parameters */
 foreach ( array('j','ctl') as $a )
