@@ -20,7 +20,7 @@
 
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once('class_periode.php');
+require_once NOALYSS_INCLUDE.'/class_periode.php';
 
 /**\file
  * \brief display or save a periode
@@ -57,7 +57,7 @@ switch ($op)
         $html.=tr(td(_(' Exercice : ')) . td($p_exercice->input()));
         $html.='</table>';
         $html.=HtmlInput::submit('sauver', _('sauver'));
-        $html.=HtmlInput::button('close', _('Fermer'), 'onclick="removeDiv(\'mod_periode\')"');
+        $html.=HtmlInput::button('close', _('fermer'), 'onclick="removeDiv(\'mod_periode\')"');
         $html.=HtmlInput::hidden('p_id', $_GET['p_id']);
         $html.='</form>';
         break;
@@ -75,7 +75,7 @@ switch ($op)
             $html.='<h2 class="info">'._('Modifier les dates de début et fin de période').'</h2>';
             $html.="<div class=\"error\">"._('Erreur date invalide')."</div>";
 
-            $html.=HtmlInput::button('close', _('Fermer'), 'onclick="removeDiv(\'mod_periode\')"');
+            $html.=HtmlInput::button('close', _('fermer'), 'onclick="removeDiv(\'mod_periode\')"');
         }
         else
         {
