@@ -25,7 +25,7 @@
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
 ob_start();
-require_once 'class_pre_operation.php';
+require_once NOALYSS_INCLUDE.'/class_pre_operation.php';
 $op=new Pre_Operation($cn,$_GET['id']);
 $array=$op->load();
 echo HtmlInput::anchor_close('mod_predf_op');
