@@ -20,9 +20,9 @@
 
 // Copyright Author Dany De Bontridder dany@alchimerys.be
 if ( ! defined ('ALLOWED')) die('Appel direct ne sont pas permis');
-echo HtmlInput::title_box("Navigateur", "navi_div");
+echo HtmlInput::title_box(_("Navigateur"), "navi_div");
 $sql="
-    select code, me_code,me_description,coalesce(me_description_etendue,me_description) as me_description_etendue,v1menu,v2menu,v3menu,p_type_display,
+    select distinct code, me_code,me_description,coalesce(me_description_etendue,me_description) as me_description_etendue,v1menu,v2menu,v3menu,p_type_display,
     javascript
     from 
     v_menu_description
@@ -103,7 +103,7 @@ for ($i=0;$i<$nMax;$i++):
                 echo $a_menu[$i]['me_description_etendue']; ?>
             </td>
             <td>
-                <a class="mtitle" style='text-decoration: underline' href="http://wiki.phpcompta.eu/doku.php?id=MENU:<?php echo $a_menu[$i]['me_code']; ?>" target='_blank'><?php echo _("sur le wiki")?> : <?php echo $a_menu[$i]['me_code']; ?></a>
+                <a class="mtitle" style='text-decoration: underline' href="http://wiki.noalyss.eu/doku.php?id=MENU:<?php echo $a_menu[$i]['me_code']; ?>" target='_blank'><?php echo _("sur le wiki")?> : <?php echo $a_menu[$i]['me_code']; ?></a>
             </td>
         </tr>
 <?php endfor; ?>        
