@@ -27,29 +27,32 @@
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
 ob_start();
-require_once 'class_follow_up.php';
-require_once 'class_default_menu.php';
+require_once NOALYSS_INCLUDE.'/class_follow_up.php';
+require_once NOALYSS_INCLUDE.'/class_default_menu.php';
 
 echo HtmlInput::title_box(_("Détail action"), $div);
 $act = new Follow_Up($cn);
 $act->ag_id = $ag_id;
 $act->get();
+$code='nok';
 if ($g_user->can_write_action($ag_id) == true || $g_user->can_read_action($ag_id) == true || $act->ag_dest == -1)
 {   
         $menu=new Default_Menu();
 	echo $act->Display('READ', false, "ajax", "");
 	//$action=HtmlInput::array_to_string(array("gDossier","ag_id"), $_GET)."&ac=FOLLOW&sa=detail";
         $action=  "do.php?".http_build_query(array("gDossier"=>Dossier::id(),"ag_id"=>$ag_id,"ac"=>$menu->get('code_follow'),"sa"=>"detail"));
+        $code='ok';
 	if ( $_GET['mod']== 1) :
             $forbidden=_("Accès interdit : vous n'avez pas accès à cette information, contactez votre responsable");
 	?>
 <a href="<?php echo $action?>" target="_blank" class="smallbutton"><?php echo _("Modifier")?> </a>
     <?php 
+        $code='nok';
 	endif;
 }
 else
 {
-	echo h2(_("Ce document n'est pas accessible"),"error");
+	$forbidden = _("Ce document n'est pas accessible");
 	?>
 	<div style="margin:0px;padding:0px;background-color:red;text-align:center;">
         <h2 class="error"><?php echo $forbidden ?></h2>;
@@ -63,7 +66,7 @@ header('Content-type: text/xml; charset=UTF-8');
 echo <<<EOF
 <?xml version="1.0" encoding="UTF-8"?>
 <data>
-<ctl></ctl>
+<ctl>$code</ctl>
 <code>$html</code>
 </data>
 EOF;
