@@ -3,7 +3,7 @@
 //see licence.txt
 
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once ('class_anc_balance_double.php');
+require_once NOALYSS_INCLUDE.'/class_anc_balance_double.php';
 $bc = new Anc_Balance_Double($cn);
 $bc->get_request();
 echo '<form method="get">';
