@@ -26,12 +26,13 @@
  *
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_ihidden.php");
-require_once("class_iselect.php");
-require_once("class_anc_account.php");
-require_once ("class_anc_operation.php");
-require_once ("class_anc_plan.php");
-require_once ("class_anc_group_operation.php");
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_anc_account.php';
+require_once  NOALYSS_INCLUDE.'/class_anc_operation.php';
+require_once  NOALYSS_INCLUDE.'/class_anc_plan.php';
+require_once  NOALYSS_INCLUDE.'/class_anc_group_operation.php';
+
 global $g_user;
 
 $str_dossier=Dossier::get();
@@ -143,7 +144,7 @@ if ( isset($_GET['new']))
     echo dossier::hidden();
     echo $wSubmit->input();
     echo $a->form();
-    echo HtmlInput::submit("save","Sauver");
+    echo HtmlInput::submit("save",_("Sauver"));
     echo '</form>';
     echo '<div class="info">';
     echo _('Débit').' = <span id="totalDeb"></span>';
