@@ -21,22 +21,21 @@
  * the supplier category
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_iselect.php");
-require_once("class_ihidden.php");
-require_once("class_bank.php");
-require_once("class_ibutton.php");
-require_once('class_iaction.php');
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_bank.php';
+require_once NOALYSS_INCLUDE.'/class_ibutton.php';
 global $g_user;
 
-$low_action=(isset($_REQUEST['sb']))?$_REQUEST['sb']:"list";
+$low_action=(isset($_REQUEST['sb']))?$_REQUEST['sb']:'list';
 /*! \file
- * \brief Called from the module "Gestion" to manage the supplier
+ * \brief Called from the module 'Gestion' to manage the supplier
  */
 $href=basename($_SERVER['PHP_SELF']);
 
 // by default open liste
-if ( $low_action  == "" )
-    $low_action="list";
+if ( $low_action  == '' )
+    $low_action='list';
 
 
 //-----------------------------------------------------
@@ -74,13 +73,24 @@ if ( $low_action == "list" )
     $a=(isset($_GET['query']))?$_GET['query']:"";
     printf (_('Recherche').' <input class="input_text" type="text" name="query" value="%s">',
             $a);
-    $sel_card=new ISelect('cat');
-    $sel_card->value=$cn->make_array('select fd_id, fd_label from fiche_def '.
-                                     ' where  frd_id=$1'.
-                                     ' order by fd_label ',1,array(FICHE_TYPE_FIN));
-    $sel_card->selected=(isset($_GET['cat']))?$_GET['cat']:-1;
-    $sel_card->javascript=' onchange="submit(this);"';
-    echo _('Catégorie :').$sel_card->input();
+     $choice_cat=HtmlInput::default_value_request("choice_cat", 1);
+
+    if ( $choice_cat == 1 )
+    {
+        $sel_card=new ISelect('cat');
+        $sel_card->value=$cn->make_array('select fd_id, fd_label from fiche_def '.
+                                         ' where  frd_id=$1'.
+                                         ' order by fd_label ',1,array(FICHE_TYPE_FIN));
+        $sel_card->selected=(isset($_GET['cat']))?$_GET['cat']:-1;
+        $sel_card->javascript=' onchange="submit(this);"';
+        echo _('Catégorie :').$sel_card->input();
+    }
+    else
+    {
+        $cat=HtmlInput::default_value_request('cat', '');
+        echo HtmlInput::hidden("cat", $cat);
+        echo HtmlInput::hidden('choice_cat', 0);
+    }
     $nooperation=new ICheckBox('noop');
     $nooperation->selected=(isset($_GET['noop']))?true:false;
     echo _('Inclure les banques sans opération :').$nooperation->input();
