@@ -26,7 +26,7 @@
  * the customer category
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once('class_contact.php');
+require_once NOALYSS_INCLUDE.'/class_contact.php';
 
 $str_dossier=Dossier::get();
 /* $sub_action = sb = detail */
@@ -48,11 +48,14 @@ case 'op':
     $def=4;
     break;
 case 'let':
-    $def=6;
+    $def=7;
     break;
 case 'bal':
   $def=5;
   break;
+case 'balag':
+    $def=6;
+    break;
 default:
     $def=1;
     $ss_action='dc';
@@ -66,14 +69,15 @@ $menu = array(
                   array('href'=>$root.'&sc=sv','label'=>_('Suivi'),'alt'=>_('Suivi Fournisseur, client, banque, devis, bon de commande, courrier')),
                   array('href'=>$root.'&sc=cn','label'=>_('Contact'),'alt'=>_('Liste de contacts')),
                   array('href'=>$root.'&sc=op','label'=>_('Opérations'),'alt'=>_('Toutes les opérations')),
-                  array('href'=>$root.'&sc=bal','label'=>_('Balance'),'alt'=>_('Balance du fournisseur')),
+                  array('href'=>$root.'&sc=bal','label'=>_('Balance'),'alt'=>_('Balance du tiers')),
+                  array('href'=>$root.'&sc=balag','label'=>_('Balance âgée'),'alt'=>_('Balance âgée du tiers')),
                   array('href'=>$root.'&sc=let','label'=>_('Lettrage'),'alt'=>_('Opérations & Lettrages'))
                   );
 echo '<ul class="tabs">';
 for ($i=0;$i<count($menu);$i++) {
     $style=($def==($i+1))?"tabs_selected":"tabs";
     echo '<li class="'.$style.'">';
-    echo '<a href="'.$menu[$i]['href'].'" alt="'.$menu[$i]['alt'].'">';
+    echo '<a href="'.$menu[$i]['href'].'" title="'.$menu[$i]['alt'].'">';
     echo h($menu[$i]['label']);
     echo '</a>';
     echo '</li>';
@@ -88,14 +92,14 @@ echo '<div class="myfieldset">';
 //---------------------------------------------------------------------------
 if ( $ss_action == 'dc' )
 {
-    require_once('category_detail.inc.php');
+    require_once NOALYSS_INCLUDE.'/category_detail.inc.php';
 }
 //---------------------------------------------------------------------------
 // Follow up : mail, bons de commande, livraison, rendez-vous...
 //---------------------------------------------------------------------------
 if ( $ss_action == 'sv' )
 {
-    require_once('category_followup.inc.php');
+    require_once NOALYSS_INCLUDE.'/category_followup.inc.php';
 }
 /*----------------------------------------------------------------------
  * Operation all the operation of this customer
@@ -103,14 +107,21 @@ if ( $ss_action == 'sv' )
  * ----------------------------------------------------------------------*/
 if ( $ss_action == 'op')
 {
-    require_once('category_operation.inc.php');
+    require_once NOALYSS_INCLUDE.'/category_operation.inc.php';
 }
 /*-------------------------------------------------------------------------
  * Balance of the card
  *-------------------------------------------------------------------------*/
 if ( $ss_action=='bal')
   {
-    require_once('balance_card.inc.php');
+    require_once NOALYSS_INCLUDE.'/balance_card.inc.php';
+  }
+/*-------------------------------------------------------------------------
+ * Ageing Balance of the card
+ *-------------------------------------------------------------------------*/
+if ( $ss_action=='balag')
+  {
+    require_once NOALYSS_INCLUDE.'/balance_card_ageing.inc.php';
   }
 /*----------------------------------------------------------------------
  * All the contact
@@ -131,7 +142,10 @@ if ( $ss_action == 'cn')
     if ( empty ($filter))
     {
         echo '<span class="notice">';
+        $url="do.php?".http_build_query(array('gDossier'=>Dossier::id(),'ac'=>'CFGCARD'));
+        echo '<a class="line" href="'.$url.'" targer="_blank">';
         echo _("Vous devez aller dans fiche et créer une catégorie pour les contacts");
+        echo '</a>';
         echo '</span>';
        return;
     }
@@ -148,8 +162,8 @@ if ( $ss_action == 'cn')
 /*----------------------------------------------------------------------------
  * Lettering
  *----------------------------------------------------------------------------*/
-if ( $def==6 )
+if ( $def==7 )
 {
-    require_once('lettering.gestion.inc.php');
+    require_once NOALYSS_INCLUDE.'/lettering.gestion.inc.php';
 }
 echo '</div>';
\ No newline at end of file
