@@ -29,7 +29,7 @@
  * - $ss_action
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once('class_acc_ledger.php');
+require_once NOALYSS_INCLUDE.'/class_acc_ledger.php';
 $f=new Fiche($cn,$_REQUEST['f_id']);
 $qcode=$f->get_quick_code();
 $_GET['qcode']=$qcode;
@@ -37,5 +37,5 @@ $_REQUEST['qcode']=$qcode;
 $var_array=compute_variable('ledger_type=ALL');
 put_global($var_array);
 
-require_once ('history_operation.inc.php');
+require_once NOALYSS_INCLUDE.'/history_operation.inc.php';
 
