@@ -23,9 +23,9 @@
 /*!
  * \brief Manage the account from the table jrn, jrnx or tmp_pcmn
  */
-require_once("class_ihidden.php");
-require_once ('class_database.php');
-require_once ('class_dossier.php');
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
 
 class Acc_Account_Ledger
 {
@@ -372,7 +372,7 @@ class Acc_Account_Ledger
 		  {
 		    $progress=bcsub($sum_deb,$sum_cred);
 			$side="&nbsp;".$this->get_amount_side($progress);
-		    echo "<TR style=\"font-weight:bold\">".
+		    echo "<TR class=\"highlight\">".
 		      "<TD>$old_exercice</TD>".
 		      td('').
 		      "<TD></TD>".
@@ -412,7 +412,7 @@ class Acc_Account_Ledger
         $solde_type=($sum_deb>$sum_cred)?"solde débiteur":"solde créditeur";
         $diff=bcsub($sum_deb,$sum_cred);
 		$side="&nbsp;".$this->get_amount_side($diff);
-        echo "<TR style=\"font-weight:bold\">".
+        echo "<TR class=\"highlight\">".
         "<TD >Totaux</TD><td></td>".
         "<TD ></TD>".
         "<TD></TD>".
