@@ -24,17 +24,17 @@
  * \brief the class Acc_Ledger_Fin inherits from Acc_Ledger, this
  * object permit to manage the financial ledger
  */
-require_once("class_idate.php");
-require_once("class_icard.php");
-require_once("class_ispan.php");
-require_once("class_itext.php");
-require_once("class_iconcerned.php");
-require_once("class_ifile.php");
-require_once("class_ihidden.php");
-require_once("class_iselect.php");
-require_once('class_acc_ledger.php');
-require_once('ac_common.php');
-require_once('class_acc_reconciliation.php');
+require_once NOALYSS_INCLUDE.'/class_idate.php';
+require_once NOALYSS_INCLUDE.'/class_icard.php';
+require_once NOALYSS_INCLUDE.'/class_ispan.php';
+require_once NOALYSS_INCLUDE.'/class_itext.php';
+require_once NOALYSS_INCLUDE.'/class_iconcerned.php';
+require_once NOALYSS_INCLUDE.'/class_ifile.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/class_acc_reconciliation.php';
 
 class Acc_Ledger_Fin extends Acc_Ledger
 {
@@ -292,7 +292,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 			{
 				if ($e->getCode() == 1)
 				{
-					throw  Exception(_("Aucune période ouverte"));
+					throw  new Exception(_("Aucune période ouverte"));
 					
 				}
 			}
@@ -312,7 +312,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 		$add_js = 'onchange="'.$onchange.'"';
 		$wLedger = $this->select_ledger('FIN', 2);
 		if ($wLedger == null)
-			throw  Exception(_('Pas de journal disponible'));
+			throw  new Exception(_('Pas de journal disponible'));
 
 		$wLedger->javascript = $add_js;
 
@@ -440,7 +440,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 		}
 
 		ob_start();
-		require_once('template/form_ledger_fin.php');
+		require_once NOALYSS_INCLUDE.'/template/form_ledger_fin.php';
 		$r.=ob_get_contents();
 		ob_end_clean();
 		$r.= create_script("$('".$Date->id."').focus()");
@@ -947,8 +947,9 @@ class Acc_Ledger_Fin extends Acc_Ledger
 				{
 					if ($oid != 0)
 					{
-						$this->db->exec_sql("update jrn set jr_pj=" . $oid . ", jr_pj_name='" . $_FILES['pj']['name'] . "', " .
-								"jr_pj_type='" . $_FILES['pj']['type'] . "'  where jr_grpt_id=$seq");
+                                            $this->db->exec_sql("update jrn set jr_pj=$1 , jr_pj_name=$2,
+                                            jr_pj_type=$3  where jr_grpt_id=$4",
+                                                array($oid,$_FILES['pj']['name'] ,$_FILES['pj']['type'],$seq));
 					}
 				}
 			} // for nbitem
@@ -966,7 +967,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 			__FILE__ . ':' . __LINE__ . ' ' .
 			$e->getMessage();
 			$this->db->rollback();
-			throw  Exception($r);
+			throw new Exception($r);
 		}
 		$this->db->commit();
 		$r = "";
@@ -1011,7 +1012,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 		$wLedger = $this->select_ledger('fin', 3);
 
 		if ($wLedger == null)
-			throw  Exception(_('Pas de journal disponible'));
+			throw  new Exception(_('Pas de journal disponible'));
 
 		if (count($wLedger->value) > 1)
 		{
