@@ -18,9 +18,9 @@
  */
 
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
-require_once ('class_dossier.php');
-require_once ('class_database.php');
-require_once('ac_common.php');
+require_once  NOALYSS_INCLUDE.'/class_dossier.php';
+require_once  NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
 
 /*!\file
  * \brief Manage additional info for Accountancy
@@ -51,7 +51,7 @@ class Acc_Ledger_Info
         {
             echo 'Appel incorrecte '.__FILE__.__LINE__;
             var_dump($this);
-            throw  Exception(_('appel incorrect'));
+            throw new Exception(_('appel incorrect'));
         }
         try
         {
@@ -75,7 +75,7 @@ class Acc_Ledger_Info
         {
             echo 'Appel incorrecte '.__FILE__.__LINE__;
             var_dump($this);
-            throw  Exception('appel incorrect');
+            throw  new Exception('appel incorrect');
         }
         try
         {
@@ -136,7 +136,7 @@ class Acc_Ledger_Info
         if ( ! isset ($this->jr_id) )
         {
             echo "jr_id is not set ".__FILE__.__LINE__;
-            throw  Exception('Error : jr_id not set');
+            throw new Exception('Error : jr_id not set');
         }
 
         $sql="select ji_id from jrn_info where jr_id=".$this->jr_id;
