@@ -22,25 +22,25 @@
 /*!\file
  * \brief class for the purchase, herits from acc_ledger
  */
-require_once("class_iselect.php");
-require_once("class_icard.php");
-require_once("class_ispan.php");
-require_once("class_ihidden.php");
-require_once("class_iperiod.php");
-require_once("class_idate.php");
-require_once("class_itext.php");
-require_once("class_ifile.php");
-require_once('class_acc_ledger.php');
-require_once('class_acc_compute.php');
-require_once('class_anc_operation.php');
-require_once('user_common.php');
-require_once('class_acc_parm_code.php');
-require_once('class_acc_payment.php');
-require_once('ac_common.php');
-require_once('class_itva_popup.php');
-require_once('class_acc_ledger_info.php');
-require_once('class_acc_ledger_fin.php');
-require_once 'class_stock_goods.php';
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_icard.php';
+require_once NOALYSS_INCLUDE.'/class_ispan.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_iperiod.php';
+require_once NOALYSS_INCLUDE.'/class_idate.php';
+require_once NOALYSS_INCLUDE.'/class_itext.php';
+require_once NOALYSS_INCLUDE.'/class_ifile.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger.php';
+require_once NOALYSS_INCLUDE.'/class_acc_compute.php';
+require_once NOALYSS_INCLUDE.'/class_anc_operation.php';
+require_once NOALYSS_INCLUDE.'/user_common.php';
+require_once NOALYSS_INCLUDE.'/class_acc_parm_code.php';
+require_once NOALYSS_INCLUDE.'/class_acc_payment.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/class_itva_popup.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger_info.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger_fin.php';
+require_once NOALYSS_INCLUDE.'/class_stock_goods.php';
 
 /*!\brief Handle the ledger of purchase,
  *
@@ -379,7 +379,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             /* save op. */
             $p_acc_operation->type = 'd';
             $p_acc_operation->qcode = '';
-            if (!$p_fiche->empty_attribute(ATTR_DEF_ACCOUNT_ND_TVA_ND) && $p_tva_both == 0)
+            if (!$p_fiche->empty_attribute(ATTR_DEF_ACCOUNT_ND_TVA_ND) )
             {
                 $dna = $p_fiche->strAttribut(ATTR_DEF_ACCOUNT_ND_TVA_ND);
             } else
@@ -412,7 +412,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
         {
             $dna_default = new Acc_Parm_Code($this->db, 'TVA_DED_IMPOT');
             /* save op. */
-            if (!$p_fiche->empty_attribute(ATTR_DEF_ACCOUNT_ND_TVA) && $p_tva_both == 0)
+            if (!$p_fiche->empty_attribute(ATTR_DEF_ACCOUNT_ND_TVA) )
             {
                 $dna = $p_fiche->strAttribut(ATTR_DEF_ACCOUNT_ND_TVA);
             } else
@@ -559,7 +559,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 
                 
                 /* We have to compute all the amount thanks Acc_Compute */
-                $amount=bcmul(${'e_march'.$i.'_price'},${'e_quant'.$i});
+                $amount=round(bcmul(${'e_march'.$i.'_price'},${'e_quant'.$i}),2);
                 
                 $acc_amount=new Acc_Compute();
                 $acc_amount->check=false;
@@ -593,7 +593,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 
 
               
-                $tot_amount=bcadd($tot_amount,$amount);
+                $tot_amount=round(bcadd($tot_amount,$amount),2);
 
                 /* get the account and explode if necessary */
                 $sposte=$fiche->strAttribut(ATTR_DEF_ACCOUNT);
@@ -1017,7 +1017,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             {
                 if ($e->getCode() == 1 )
                 {
-                    throw  Exception( _("Aucune période ouverte"));
+                    throw new Exception( _("Aucune période ouverte"));
                 }
             }
 
@@ -1042,7 +1042,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
 		$add_js.='update_row("sold_item");';
 
 		$wLedger=$this->select_ledger('ACH',2);
-        if ($wLedger == null) throw  Exception(_('Pas de journal disponible'));
+        if ($wLedger == null) throw  new Exception(_('Pas de journal disponible'));
         $wLedger->javascript="onChange='update_predef(\"ach\",\"f\",\"".$_REQUEST['ac']."\");$add_js'";
         $wLedger->table=1;
         $f_jrn=$wLedger->input();
@@ -1055,7 +1055,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
         $Commentaire->size=60;
         $Commentaire->tabindex=3;
         $label=HtmlInput::infobulle(1) ;
-        $f_desc=$Commentaire->input("e_comm",h($e_comm)).$label;
+        $f_desc=$Commentaire->input("e_comm",h($e_comm));
 
         // PJ
         //--
@@ -1272,7 +1272,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
         $f_type=_('Fournisseur');
 
         ob_start();
-        require_once('template/form_ledger_detail.php');
+        require_once NOALYSS_INCLUDE.'/template/form_ledger_detail.php';
         $r.=ob_get_contents();
         ob_end_clean();
 
@@ -1429,7 +1429,6 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 $fiche_name=h(${"e_march".$i."_label"});
             else
                 $fiche_name=$fiche->strAttribut (ATTR_DEF_NAME);
-
             $amount=bcmul(${"e_march".$i."_price"},${'e_quant'.$i});
             if ( $g_parameter->MY_TVA_USE=='Y')
             {
@@ -1452,7 +1451,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                     $tva_item=round(${'e_march'.$i.'_tva_amount'},2);
 
                 if (isset($tva[$idx_tva] ) )
-                    $tva[$idx_tva]+=$tva_item;
+                    $tva[$idx_tva]=bcadd($tva_item,$tva[$idx_tva]);
                 else
                     $tva[$idx_tva]=$tva_item;
                
@@ -1460,7 +1459,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 
             }
             $tot_amount=round(bcadd($tot_amount,$amount),2);
-			$tot_row=bcadd($tot_row,$amount);
+            $tot_row=round(bcadd($tot_row,$amount),2);
             $r.='<tr>';
             $r.='<td>';
             $r.=${"e_march".$i};
@@ -1487,7 +1486,6 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 $r.='</td>';
                 /* warning if tva_computed and given are not the
                    same */
-		bcscale(2);
                 $css_void_tva=($both_side == 1)?'style="text-decoration:line-through"':'';
                 if ( bcsub($tva_item,$tva_computed) != 0 && ! ($tva_item == 0 && $both_side == 1))
                 {
@@ -1502,7 +1500,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                         $r.=nbm($tva_item);
                 }
                 $r.='</td>';
-                $r.='<td class="num">';
+                $r.='<td class="num"> ';
                 $r.=nbm(round($amount,2));
                 $r.='</td>';
             }
