@@ -23,24 +23,24 @@
 /* !\file
  * \brief class for the sold, herits from acc_ledger
  */
-require_once("class_iselect.php");
-require_once("class_icard.php");
-require_once("class_ispan.php");
-require_once("class_ihidden.php");
-require_once("class_idate.php");
-require_once("class_itext.php");
-require_once("class_ifile.php");
-require_once('class_acc_ledger.php');
-require_once('class_acc_compute.php');
-require_once('class_anc_operation.php');
-require_once('user_common.php');
-require_once('class_acc_payment.php');
-require_once('ac_common.php');
-require_once('class_own.php');
-require_once('class_itva_popup.php');
-require_once('class_acc_ledger_fin.php');
-require_once 'class_stock_goods.php';
-require_once 'class_acc_ledger.php';
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_icard.php';
+require_once NOALYSS_INCLUDE.'/class_ispan.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_idate.php';
+require_once NOALYSS_INCLUDE.'/class_itext.php';
+require_once NOALYSS_INCLUDE.'/class_ifile.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger.php';
+require_once NOALYSS_INCLUDE.'/class_acc_compute.php';
+require_once NOALYSS_INCLUDE.'/class_anc_operation.php';
+require_once NOALYSS_INCLUDE.'/user_common.php';
+require_once NOALYSS_INCLUDE.'/class_acc_payment.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/class_own.php';
+require_once NOALYSS_INCLUDE.'/class_itva_popup.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger_fin.php';
+require_once NOALYSS_INCLUDE.'/class_stock_goods.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger.php';
 
 /* !\brief Handle the ledger of sold,
  *
@@ -277,7 +277,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
                 $fiche = new Fiche($this->db);
                 $fiche->get_by_qcode(${"e_march" . $i});
                 $amount = bcmul(${'e_march' . $i . '_price'}, ${'e_quant' . $i});
-                $tot_amount = bcadd($tot_amount, $amount);
+                $tot_amount = round(bcadd($tot_amount, $amount),2);
                 $acc_operation = new Acc_Operation($this->db);
                 $acc_operation->date = $e_date;
                 $sposte = $fiche->strAttribut(ATTR_DEF_ACCOUNT);
@@ -846,7 +846,7 @@ EOF;
             $r.='<tr>'.td(_('Total TVAC')).td(hb($tot),'class="num"');
             $r.='</table>';
         } else {
-            $r.='<br>Total '.hb(nbm($tot));
+            $r.='<br>Total '.hb($tot);
         }
         $r.='</div>';
         /*  Add hidden */
@@ -1057,7 +1057,7 @@ EOF;
                 $l_form_per = $period->input();
             } catch (Exception $e) {
                 if ($e->getCode() == 1) {
-                    throw  Exception( _("Aucune période ouverte") );
+                    throw new Exception( _("Aucune période ouverte") );
                 }
             }
             $label = HtmlInput::infobulle(3);
@@ -1077,7 +1077,7 @@ EOF;
 
         $wLedger = $this->select_ledger('VEN', 2);
         if ($wLedger == null)
-            throw  Exception(_('Pas de journal disponible'));
+            throw new Exception(_('Pas de journal disponible'));
         $wLedger->table = 1;
         $wLedger->javascript = "onChange='update_predef(\"ven\",\"f\",\"".$_REQUEST['ac']."\");$add_js'";
         $wLedger->label = " Journal " . HtmlInput::infobulle(2);
@@ -1092,7 +1092,7 @@ EOF;
 
         $label = HtmlInput::infobulle(1);
 
-        $f_desc = $Commentaire->input("e_comm", h($e_comm)) . $label;
+        $f_desc = $Commentaire->input("e_comm", h($e_comm)) ;
         // PJ
         //--
         /* suggest PJ ? */
@@ -1284,7 +1284,7 @@ EOF;
 
 
         ob_start();
-        require_once('template/form_ledger_detail.php');
+        require_once NOALYSS_INCLUDE.'/template/form_ledger_detail.php';
         $r.=ob_get_contents();
         ob_end_clean();
 
