@@ -27,16 +27,16 @@
  *
  *
  */
-require_once("class_idate.php");
-require_once("class_itext.php");
-require_once("class_ihidden.php");
-require_once("class_iselect.php");
-require_once("class_ibutton.php");
-require_once('class_database.php');
-require_once('constant.php');
-require_once('class_dossier.php');
-require_once ('class_anc_plan.php');
-require_once 'class_ianccard.php';
+require_once NOALYSS_INCLUDE.'/class_idate.php';
+require_once NOALYSS_INCLUDE.'/class_itext.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_ibutton.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/constant.php';
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
+require_once  NOALYSS_INCLUDE.'/class_anc_plan.php';
+require_once NOALYSS_INCLUDE.'/class_ianccard.php';
 class Anc_Print
 {
     var $db;						/*!< $db database connection */
@@ -169,7 +169,9 @@ class Anc_Print
     
 </table>
 <span style="padding:5px;margin:5px;display:block;">
-    <?php echo _( "Plan Analytique :").$plan_id->input(); ?>
+    <?php echo _( "Plan Analytique :").$plan_id->input(); 
+        echo HtmlInput::infobulle(42);
+    ?>
 </span>
 
 <?php
@@ -178,7 +180,6 @@ class Anc_Print
         $r.=$choose_from->input();
         $r.=_(" et l'activité ").$to_poste->input();
         $r.=$choose_to->input();
-        $r.='<span class="notice" style="display:block">'._('Selectionnez le plan qui vous intéresse avant de cliquer sur Recherche').'</span>';
 
         $r.='</span>';
         return $r;
