@@ -22,7 +22,7 @@
 /*!\file
  * \brief object to show a table: link between accountancy and analytic
  */
-require_once('class_anc_acc_link.php');
+require_once NOALYSS_INCLUDE.'/class_anc_acc_link.php';
 
 class Anc_Table extends Anc_Acc_Link
 {
@@ -174,7 +174,7 @@ class Anc_Table extends Anc_Acc_Link
 	  {
 	    echo td(nbm($tot_col[$i]),' class="num"');
 	  }
-	echo td(nbm($tot_global),' class="num" style="font-size:1.3em;text-weight:bold;border:solid 1px blue"');
+	echo td(nbm($tot_global),' class="num input_text notice" ');
 	echo '</tr>';
 	echo '</table>';
       }
@@ -229,7 +229,7 @@ class Anc_Table extends Anc_Acc_Link
 	  {
 	    echo td(nbm($tot_col[$i]),' class="num"');
 	  }
-	echo td(nbm($tot_global),' class="num" style="font-size:1.3em;text-weight:bold;border:solid 1px blue"');
+	echo td(nbm($tot_global),' class="num input_text notice" ');
 	echo '</tr>';
 	echo '</table>';
 
