@@ -23,8 +23,8 @@
 /**\file
  * \brief contains the class for connecting to a postgresql database
  */
-require_once('constant.php');
-require_once('ac_common.php');
+require_once NOALYSS_INCLUDE.'/constant.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
 
 /**\brief
  * This class allow you to connect to the postgresql database, execute sql, retrieve data
@@ -36,7 +36,7 @@ class Database
 
     private $db;    /**< database connection */
     private $ret;   /**< return value  */
-
+    private $is_open;                   /*!< true is connected */
     /**\brief constructor
      * \param $p_database_id is the id of the dossier, or the modele following the
      * p_type if = 0 then connect to the repository
@@ -108,8 +108,9 @@ class Database
             }
         }
         $this->db=$a;
+        $this->is_open=TRUE;
         if ($this->exist_schema('comptaproc'))
-            pg_exec($this->db, 'set search_path to public,comptaproc;');
+        pg_exec($this->db, 'set search_path to public,comptaproc;');
         pg_exec($this->db, 'set DateStyle to ISO, MDY;');
         ob_end_clean();
     }
@@ -136,7 +137,7 @@ class Database
     {
         try
         {
-
+            if ( ! $this->is_open ) throw new Exception(' Database is closed');
             $this->sql=$p_string;
             $this->array=$p_array;
 
@@ -176,6 +177,8 @@ class Database
                 echo $a->getTraceAsString();
                 echo pg_last_error($this->db);
             }
+            $this->rollback();
+            
             throw ($a);
         }
 
@@ -228,6 +231,7 @@ class Database
      */
     function commit()
     {
+        if ( ! $this->is_open) return;
         $Res=$this->exec_sql("commit");
     }
 
@@ -236,6 +240,7 @@ class Database
      */
     function rollback()
     {
+        if ( ! $this->is_open) return;
         $Res=$this->exec_sql("rollback");
     }
 
@@ -363,7 +368,9 @@ class Database
         return pg_fetch_array($this->ret, $p_indice);
     }
 
-    /**@brief return the number of rows found by the last query, or the number
+    /**
+     * 
+     * @brief return the number of rows found by the last query, or the number
      * of rows from $p_ret
      * @param $p_ret is the result of a query, the default value is null, in that case
      * it is related to the last query
@@ -378,14 +385,17 @@ class Database
             return pg_NumRows($p_ret);
     }
 
-    /**@brief       synomym for size() */
+    /**
+     * @brief       synomym for size() 
+     */
 
     function count($p_ret=null)
     {
         return $this->size($p_ret);
     }
 
-    /**\brief loop to apply all the path to a folder or
+    /**
+     * \brief loop to apply all the path to a folder or
      *         a template
      * \param $p_name database name
      * \param $from_setup == 1 if called from setup.php
@@ -394,6 +404,10 @@ class Database
 
     function apply_patch($p_name, $from_setup=1)
     {
+        if ( ! $this->exist_table('version')) {
+            echo _('Base de donnée vide');
+            return;
+        }
         $MaxVersion=DBVERSION-1;
         $succeed="<span style=\"font-size:18px;color:green\">&#x2713;</span>";
         echo '<ul style="list-type-style:square">';
@@ -507,7 +521,9 @@ class Database
         echo '</ul>';
     }
 
-    /**\brief return the value of the sql, the sql will return only one value
+    /**
+     * 
+     * \brief return the value of the sql, the sql will return only one value
      *        with the value
      * \param $p_sql the sql stmt example :select s_value from
       document_state where s_id=2
@@ -533,8 +549,16 @@ class Database
         $r=pg_fetch_row($this->ret, 0);
         return $r[0];
     }
+    /**
+     * @brief return the number of rows affected by the previous query
+     */
+    function get_affected()
+    {
+        return Database::num_row($this->ret);
+    }
 
-    /**\brief  purpose return the result of a sql statment
+    /**
+     * \brief  purpose return the result of a sql statment
      * in a array
      * \param $p_sql sql query
      * \param $p_array if not null we use ExecSqlParam
@@ -559,7 +583,8 @@ class Database
         $this->exec_sql($sql);
     }
 
-    /**\brief test if a sequence exist */
+    /**
+     * \brief test if a sequence exist */
     /* \return true if the seq. exist otherwise false
      */
 
@@ -818,8 +843,9 @@ class Database
                         pg_lo_unlink($cn, $old_oid);
                 }
                 // Load new document
-                $this->exec_sql("update jrn set jr_pj=".$oid.", jr_pj_name='".$_FILES['pj']['name']."', ".
-                        "jr_pj_type='".$_FILES['pj']['type']."'  where jr_grpt_id=$seq");
+               $this->exec_sql("update jrn set jr_pj=$1 , jr_pj_name=$2,
+                                        jr_pj_type=$3  where jr_grpt_id=$4",
+                                        array($oid,$_FILES['pj']['name'] ,$_FILES['pj']['type'],$seq));
                 return $oid;
             }
             else
@@ -956,7 +982,8 @@ class Database
 
     function close()
     {
-        pg_close($this->db);
+        if ( $this->is_open ) pg_close($this->db);
+        $this->is_open=FALSE;
     }
 
     /**\brief
