@@ -33,8 +33,8 @@
 				 "desc"=>"dos_description");
  *
  */
-require_once('class_database.php');
-require_once('ac_common.php');
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
 
 class Dossier
 {
@@ -53,52 +53,70 @@ class Dossier
         return $_REQUEST['gDossier'];
     }
 
-    /*!
-     * \param  p_type string : all for all dossiers lim for only the
-     *             dossier where we've got rights
+    /**
+     * @brief Show the folder where user have access. 
+     * @param  p_type string   
+       - A for all dossiers 
+       - R for accessible folders
+       - X forbidden folders
+     * @param p_login is the user name
+     * @param p_text is a part of the name where are looking for
+     * @return     nothing
      *
-     * Show the folder where user have access. Return    : nothing
-     ++*/
-    function show_dossier($p_type,$p_first=0,$p_max=0,$p_Num=0)
+     */
+    static function show_dossier($p_type,$p_login="",$p_text="",$limit=0)
     {
-        $l_user=$_SESSION['g_user'];
-        if ( $p_max == 0 )
+        $cn=new Database();
+        $str_limit=($limit==0)?'':' limit '.$limit;
+        if ( $p_type == "A")
         {
-            $l_step="";
+            $l_sql="select *, 'W' as priv_priv from ac_dossier where dos_name ~* $2 or dos_description ~* $2 ORDER BY dos_name $str_limit  ";
+            $a_row=$cn->get_array($l_sql,$p_text);
+            return $a_row;
         }
-        else
-        {
-            $l_step="LIMIT $p_max OFFSET $p_first";
-        }
-
-        if ( $p_type == "all")
-        {
-            $l_sql="select *, 'W' as priv_priv from ac_dossier ORDER BY dos_name  ";
-            $p_Num=$this->cn->count_sql($l_sql);
-        }
-        else
+        else if ($p_type == "R")
         {
             $l_sql="select * from jnt_use_dos
                    natural join ac_dossier
                    natural join ac_users
-                   inner join priv_user on priv_jnt=jnt_id where
-                   use_login='".$l_user."' and priv_priv !='NO'
-                   order by dos_name ";
-            $p_Num=$this->cn->count_sql($l_sql);
-        }
-        $l_sql=$l_sql.$l_step;
-        $p_res=$this->cn->exec_sql($l_sql);
+                   where
+                   use_login=$1
+                   and ( dos_name ~* $2 or dos_description ~* $2)
+                   
+                   order by dos_name 
+                   $str_limit
+                   ";
+            
+            $a_row=$cn->get_array($l_sql,array($p_login,$p_text));
+            return $a_row;
 
-
-        $Max=$this->cn->size();
-        if ( $Max == 0 ) return null;
-        for ( $i=0;$i<$Max; $i++)
+        } 
+        else  if ($p_type == 'X')
         {
-	  $row[]=$this->cn->fetch($i);
-        }
-        return $row;
-    }
+            $l_sql=' select * from ac_dossier where dos_id not in 
+                  (select dos_id from jnt_use_dos where use_id=$1)
+                  and ( dos_name ~* $2 or dos_description ~* $2)
+                  order by dos_name '.$str_limit;
+            $a_row=$cn->get_array($l_sql,array($p_login,$p_text));
+            return $a_row;
 
+        }
+        else
+        {
+            throw new Exception (_("Erreur paramètre"));
+        } 
+        
+       
+    }
+    /**
+     * Count the number of folder in the repository
+     * @return integer
+     */
+    function count() 
+    {
+        $nb_folder=$this->cn->get_value('select count(*) from ac_dossier');
+        return $nb_folder;
+    }
     /*!
      * \brief Return all the users
      * as an array
@@ -120,9 +138,6 @@ class Dossier
             left join    (select array_to_string(array_agg(dos_name),',') as ag_dossier,jt.use_id as jt_use_id
                         from ac_dossier as ds
                         join  jnt_use_dos as jt on (jt.dos_id=ds.dos_id)
-                        join priv_user as pu on (pu.priv_jnt=jt.jnt_id)
-                        where
-                        pu.priv_priv != 'X'
                         group by jt.use_id) as dossier_name on (jt_use_id=ac.use_id)
             where
             use_login!='phpcompta'
