@@ -35,10 +35,10 @@
  *    - enable (extension.ex_enable)
  *    - filepath (extension.ex_file)
  */
-require_once 'class_menu_ref_sql.php';
-include_once 'class_profile_sql.php';
-require_once 'class_menu_ref.php';
-require_once 'class_profile_menu.php';
+require_once NOALYSS_INCLUDE.'/class_menu_ref_sql.php';
+require_once NOALYSS_INCLUDE.'/class_profile_sql.php';
+require_once NOALYSS_INCLUDE.'/class_menu_ref.php';
+require_once NOALYSS_INCLUDE.'/class_profile_menu.php';
 
 class Extension extends Menu_Ref_sql
 {
@@ -105,7 +105,7 @@ class Extension extends Menu_Ref_sql
      * @global type $cn
      * @param type $p_id profile.p_id
      * @param type $p_module menu_ref.me_code
-     * @throws Exception 10 : profile absent 20 module absent
+     * @throws Exception 10 : profile absent , 20 module absent , 30 No parent menu
      */
     function insert_profile_menu($p_id=1,$p_module='EXT')
     {
@@ -120,12 +120,23 @@ class Extension extends Menu_Ref_sql
         if ($module->me_code==null) {
                 throw new Exception(_('Module inexistant'),20);
         }
+        // Dependency
+        $dep_id=$cn->get_value('select pm_id from profile_menu 
+                where
+                p_id=$1
+                and me_code = $2 ',array($p_id,$p_module));
+        // throw an exception if there is no dependency
+        if ($dep_id=="") {
+                throw new Exception(_('Pas de menu ').$p_module,30);
+        }
         
         $profil_menu=new Profile_Menu($cn);
         $profil_menu->me_code=$this->me_code;
         $profil_menu->me_code_dep=$p_module;
         $profil_menu->p_type_display='S';
         $profil_menu->p_id=$p_id;
+        $profil_menu->pm_id_dep=$dep_id;
+        
         $cnt=$profil_menu->count(' where p_id=$1 and me_code = $2',array($p_id,$this->me_code));
         if ( $cnt==0) {
             $profil_menu->insert();
@@ -217,10 +228,14 @@ class Extension extends Menu_Ref_sql
                     $update = @file_get_contents(SITE_UPDATE_PLUGIN);
                     if ($update > $version_plugin)
                     {
-                        echo '<div class="inner_box" style="position:absolute;zindex:2;top:5px;left:360px">';
+                        echo '<div id="version_plugin_div_id" class="inner_box" style="position:absolute;zindex:2;top:5px;left:37.5%;width:25%">';
                         echo '<p class="notice">';
                         echo "Mise à jour disponible des plugins pour NOALYSS, version actuelle : $update votre version $version_plugin";
                         echo '</p>';
+                         echo '<p style="text-align:center">'.
+                               '<a id="version_plugin_button" class="button" onclick="$(\'version_plugin_div_id\').remove()">'.
+                         _('Fermer').
+                         "</a></p>";
                         echo '</div>';
                     }
                 }
@@ -281,10 +296,10 @@ class Extension extends Menu_Ref_sql
                 }
                 $extension->me_file=trim($xml->plugin[$i]->root).'/'.trim($xml->plugin[$i]->file);
                 $extension->me_code=trim($xml->plugin[$i]->code);
-                $extension->me_description=(isset ($xml->plugin[$i]->description))?$xml->plugin[$i]->description:"";
-                $extension->me_description_etendue=($xml->plugin[$i]->author)?$xml->plugin[$i]->author:"";
+                $extension->me_description=(isset ($xml->plugin[$i]->description))?trim($xml->plugin[$i]->description):"";
+                $extension->me_description_etendue=(trim($xml->plugin[$i]->author))?trim($xml->plugin[$i]->author):"";
                 $extension->me_type='PL';
-                $extension->me_menu=$xml->plugin[$i]->name;
+                $extension->me_menu=trim($xml->plugin[$i]->name);
                 $extension->me_parameter='plugin_code='.trim($xml->plugin[$i]->code);
                 $a_extension[]=clone $extension;
             }
