@@ -17,12 +17,12 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
-include_once("class_fiche_attr.php");
-require_once("class_itext.php");
-require_once('class_fiche_def_ref.php');
-require_once('class_fiche.php');
-require_once('user_common.php');
-require_once('class_iradio.php');
+require_once NOALYSS_INCLUDE.'/class_fiche_attr.php';
+require_once NOALYSS_INCLUDE.'/class_itext.php';
+require_once NOALYSS_INCLUDE.'/class_fiche_def_ref.php';
+require_once NOALYSS_INCLUDE.'/class_fiche.php';
+require_once NOALYSS_INCLUDE.'/user_common.php';
+require_once NOALYSS_INCLUDE.'/class_iradio.php';
 
 /*! \file
  * \brief define Class fiche and fiche def, those class are using
@@ -62,8 +62,8 @@ class Fiche_Def
 		$fd_description=new ITextarea('fd_description');
 		$fd_description->width=80;
 		$fd_description->heigh=4;
-		$fd_description->style='style="vertical-align:text-top"';
-        require_once ('template/fiche_def_input.php');
+		$fd_description->style='class="itextarea" style="margin-left:0px;vertical-align:text-top"';
+        require_once  NOALYSS_INCLUDE.'/template/fiche_def_input.php';
         return;
     }
 
@@ -182,7 +182,7 @@ frd_text , fd_description FROM fiche_def join fiche_def_ref on (fiche_def.frd_id
 $order
 ");
 
-		require_once 'template/fiche_def_list.php';
+		require_once NOALYSS_INCLUDE.'/template/fiche_def_list.php';
 	}
     /*!\brief Add a fiche category thanks the element from the array
      * you cannot add twice the same cat. name
@@ -193,12 +193,22 @@ $order
      *        index FICHE_REF
      *              nom_mod
      *              class_base
+     *              fd_description
      */
     function Add($array)
     {
-        foreach ( $array as $key=>$element )
-        {
-            ${"p_$key"}=$element;
+        /** 
+         * Check needed info
+         */
+        $p_nom_mod = HtmlInput::default_value('nom_mod', "", $array);
+        $p_fd_description = HtmlInput::default_value('fd_description', "", $array);
+        $p_class_base= HtmlInput::default_value('class_base', "", $array);
+        $p_fiche_def= HtmlInput::default_value('FICHE_REF', "", $array);
+        $p_create= HtmlInput::default_value('create', "off", $array);
+        
+        // If there is no description then add a empty one
+        if ( ! isset ($p_fd_description)) {
+            $p_fd_description="";
         }
         // Format correctly the name of the cat. of card
         $p_nom_mod=sql_string($p_nom_mod);
@@ -206,28 +216,17 @@ $order
 
         // Name can't be empty
         if ( strlen(trim($p_nom_mod)) == 0 )
-		{
-			alert (_('Le nom de la catégorie ne peut pas être vide'));
+	{
+            alert (_('Le nom de la catégorie ne peut pas être vide'));
             return 1;
-		}
-        /**!! (== fiche_def_ref.frd_id
-        if (! isset ($p_FICHE_REF) || strlen($p_FICHE_REF) == 0 )
-        {
-            echo alert (_('Vous devez choisir une categorie'));
+	}
+        // $p_fiche_def can't be empty
+        if ( strlen(trim($p_fiche_def)) == 0 )
+	{
+            alert (_('Un modéle de catégorie est obligatoire'));
             return 1;
-        }
-        $fiche_Def_ref=new Fiche_Def_Ref($this->cn,$p_FICHE_REF);
-        $fiche_Def_ref->Get();
-
-        // build the sql request for fiche_def
-        // and insert into fiche_def
-        // if p_class_base is null get the default class base from
-        // fiche_def_ref
-        if ( sql_string($p_class_base) == null )
-        { // p_class is null
-            // So we take the default one
-            $p_class_base=$fiche_Def_ref->frd_class_base;
-        }
+	}
+        
         /* check if the cat. name already exists */
         $sql="select count(*) from fiche_Def where upper(fd_label)=upper($1)";
         $count=$this->cn->get_value($sql,array(trim($p_nom_mod)));
@@ -238,7 +237,7 @@ $order
 		}
         // Set the value of fiche_def.fd_create_account
         // automatic creation for 'poste comptable'
-        if ( isset($p_create) && strlen(trim($p_class_base)) != 0)
+        if ( $p_create == "on" && strlen(trim($p_class_base)) != 0)
             $p_create='true';
         else
             $p_create='false';
@@ -250,7 +249,7 @@ $order
             $sql="insert into fiche_def(fd_label,fd_class_base,frd_id,fd_create_account,fd_description)
                  values ($1,$2,$3,$4,$5) returning fd_id";
 
-            $fd_id=$this->cn->get_value($sql,array($p_nom_mod,$p_class_base,$p_FICHE_REF,$p_create,$p_fd_description));
+            $fd_id=$this->cn->get_value($sql,array($p_nom_mod,$p_class_base,$p_fiche_def,$p_create,$p_fd_description));
 
             // p_class must be added to tmp_pcmn if it is a single accounting
             if ( strpos(',',$p_class_base) ==0)
@@ -272,7 +271,7 @@ $order
             $sql="insert into fiche_def(fd_label,frd_id,fd_create_account,fd_description) values ($1,$2,$3,$4) returning fd_id";
 
 
-            $this->id=$this->cn->get_value($sql,array($p_nom_mod,$p_FICHE_REF,$p_create,$p_fd_description));
+            $this->id=$this->cn->get_value($sql,array($p_nom_mod,$p_fiche_def,$p_create,$p_fd_description));
 
             // Get the fd_id
             $fd_id=$this->cn->get_current_seq('s_fdef');
@@ -280,7 +279,7 @@ $order
         }
 
         // Get the default attr_def from attr_min
-        $def_attr=$this->get_attr_min($p_FICHE_REF);
+        $def_attr=$this->get_attr_min($p_fiche_def);
 
         //if defaut attr not null
         // build the sql insert for the table attr_def
@@ -459,10 +458,11 @@ $order
         $class_base->set_attribute('ipopup','ipop_account');
         $class_base->set_attribute('account','class_base');
         $class_base->set_attribute('label','acc_label');
-		$fd_description=new ITextarea('fd_description',$this->fd_description);
-		$fd_description->width=80;
-		$fd_description->heigh=4;
-		$fd_description->style='style="vertical-align:text-top"';
+        $fd_description=new ITextarea('fd_description',$this->fd_description);
+        $fd_description->width=80;
+        $fd_description->heigh=4;
+        $fd_description->style='class="itextarea" style="margin-left:0px;vertical-align:text-top"';
+
         $r.=_('Poste Comptable de base').' : ';
         $r.=$class_base->input();
         $r.='<span id="acc_label"></span><br>';
@@ -626,8 +626,6 @@ $order
         $sql=sprintf("insert into jnt_fic_attr (fd_id,ad_id,jnt_order) values (%d,%d,%d)",
                      $this->id,$p_ad_id,$max);
         $Res=$this->cn->exec_sql($sql);
-        // update all the existing card
-
     }
     /*!\brief remove an attribut for this fiche_def
      * \param array of ad_id to remove
@@ -779,17 +777,22 @@ $order
 		/* attributes */
 		$r.='<fieldset><legend>'._('Détails').'</legend>';
 
-		$r.= '<FORM  method="POST">';
+		$r.= '<FORM  id="input_detail_frm" method="POST">';
 		$r.=dossier::hidden();
 		$r.=HtmlInput::hidden("fd_id", $this->id);
+		$r.=HtmlInput::hidden("action", "");
 		$r.= $this->DisplayAttribut("remove");
-		$r.= HtmlInput::submit('add_line', _('Ajoutez cet élément'));
-		$r.= HtmlInput::submit("save_line", _("Sauvez"));
-		$r.=HtmlInput::submit('remove_cat', _('Effacer cette catégorie'), 'onclick="return confirm(\'' . _('Vous confirmez ?') . '\')"');
+		$r.= HtmlInput::submit('add_line_bt', _('Ajoutez cet élément'),
+                        'onclick="$(\'action\').value=\'add_line\'"');
+		$r.= HtmlInput::submit("save_line_bt", _("Sauvez"),
+                        'onclick="$(\'action\').value=\'save_line\'"');
+                        
+		$r.=HtmlInput::submit('remove_cat_bt', _('Effacer cette catégorie'), 'onclick="$(\'action\').value=\'remove_cat\';return confirm_box(\'input_detail_frm\',\'' . _('Vous confirmez ?') . '\')"');
 		// if there is nothing to remove then hide the button
 		if (strpos($r, "chk_remove") != 0)
 		{
-			$r.=HtmlInput::submit('remove_line', _("Enleve les éléments cochés"), "onclick=\"return confirm('Vous confirmez?')\"");
+                    $r.=HtmlInput::submit('remove_line_bt', _("Enleve les éléments cochés"), 
+                            'onclick="$(\'action\').value=\'remove_line\';return confirm_box(\'input_detail_frm\',\'' . _('Vous confirmez ?') . '\')"');
 		}
 		$r.= "</form>";
 		$r.=" <p class=\"notice\"> " . _("Attention : il n'y aura pas de demande de confirmation pour enlever les
