@@ -16,8 +16,8 @@
  *   along with NOALYSS; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
-require_once ('class_fiche.php');
-require_once ('class_database.php');
+require_once  NOALYSS_INCLUDE.'/class_fiche.php';
+require_once  NOALYSS_INCLUDE.'/class_database.php';
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
 
 /*!\file
