@@ -107,7 +107,7 @@ class HtmlInput
      */
     public function get_js_attr()
     {
-        require_once('function_javascript.php');
+        require_once NOALYSS_INCLUDE.'/function_javascript.php';
         $attr="";
         if ( count($this->attribute) == 0) return "";
 
@@ -320,14 +320,18 @@ class HtmlInput
         echo '<div style="padding:5px">';
         echo '<form method="GET" id="'.$div.'search_frm" onsubmit="return hide_ledger_choice(\''.$div.'search_frm\')">';
         echo HtmlInput::hidden('nb_jrn', count($p_array));
-        echo _('Filtre ').HtmlInput::filter_table($div.'tb_jrn', '0,1,2', 1);
+        echo _('Filtre ').HtmlInput::filter_table($div.'tb_jrn', '0,1,2', 2);
         echo '<table class="result" id="'.$div.'tb_jrn">';
         echo '<tr>';
         echo th(_('Nom'));
         echo th(_('Description'));
         echo th(_('Type'));
         echo '</tr>';
-        
+        echo '<tr>';
+        echo '<td>';
+        echo HtmlInput::button('sel_'.$div,_('Inverser la sélection'),' onclick = "toggle_checkbox(\''."{$div}search_frm".'\')"');
+        echo '</td>';
+        echo '</tr>';
         for ($e=0;$e<count($p_array);$e++)
         {
             $row=$p_array[$e];
@@ -388,7 +392,7 @@ class HtmlInput
 
         }
         echo '</ul>';
-        $hide=new IButton('l');
+        $hide=new IButton('l2');
         $hide->label=_("Valider");
         $hide->javascript=" hide_cat_choice() ";
         echo $hide->input();
@@ -412,7 +416,7 @@ class HtmlInput
      */
     static function button_close($div_name)
     {
-      $a=new IButton('Fermer',_('Fermer'));
+      $a=new IButton('Fermer');
       $a->label=_("Fermer");
       $a->javascript="removeDiv('".$div_name."')";
       $html=$a->input();
@@ -424,11 +428,11 @@ class HtmlInput
      * Return a html string with an anchor which close the inside popup. (top-right corner)
      *@param name of the DIV to close
      */
-    static function anchor_close($div)
+    static function anchor_close($div,$p_js="")
     {
 	$r='';
 	$r.='<div style="position:absolute;right:2px;margin:2px;padding:0px;">';
-	$r.= '<A id="close_div" class="input_text" onclick="removeDiv(\''.$div.'\');">'._('Fermer').'</A>';
+	$r.= '<A id="close_div" class="input_text" onclick="removeDiv(\''.$div.'\');'.$p_js.'">&#10761;</A>';
 	$r.='</div>';
 	return $r;
     }
@@ -702,21 +706,46 @@ class HtmlInput
 		return $_REQUEST[$ind];
 	}
         /**
-         * Title for boxes
+         * Title for boxes, you can customize the symbol thanks symbol with
+         * the mode "custom"
          * @param type $name Title
-         * @param type $div element id
-         * @param type $mod hide or close
-         * @param type $p_js if $mod is hide then you can add a javascript
+         * @param type $div element id, except for mode none or custom
+         * @param type $mod hide , close , zoom , custom or none, with
+         * custom , the $name contains all the code
+         * @param type $p_js contains the javascript with "custom" contains button + code 
          * @return type
          */
 	static function title_box($name,$div,$mod="close",$p_js="")
 	{
-		if ($mod=='close')		$r=HtmlInput::anchor_close($div);
-		if ($mod=='hide')		$r=HtmlInput::anchor_hide(_('Fermer'),"$('$div').hide();$p_js");
-                if ( $mod == 'none')    $r="";
+		if ($mod=='close')	{$r=HtmlInput::anchor_close($div,$p_js); }else
+		if ($mod=='hide')	{$r=HtmlInput::anchor_hide("&#10761;","$('$div').hide();$p_js");} else
+		if ($mod=='zoom')	{$r='<span  id="span_'.$div.'" style="float:right;margin-right:5px">'.HtmlInput::anchor("&#11036;","",$p_js,' name="small'.$div.'" id="close_div" class="input_text"  ').'</span>'; } else
+                if ( $mod == 'custom')  {$r='<span  id="span_'.$div.'" style="float:right;margin-right:5px">'.$p_js."</span>";} else
+                if ( $mod == 'none')    {$r="" ; }
+                    else 
+                            die (__FILE__.":".__LINE__._('Paramètre invaide'));
 		$r.=h2($name,' class="title" ');
 		return $r;
 	}
+        /**
+         * @brief let you create only a link and set an id on it.
+         * After create a javascript for getting the event 
+         * onclick = function() {...}
+         * @param type $p_text Text to display
+         * @param type $p_id id of the link
+         * @param type $type title of the link
+         * @code
+         * echo HtmlInput::anchor_empty('go','go_id');
+         * <script>$("go_id").onclick=function (e) { ...}</script>
+         * @endcode
+         */
+        static  function anchor_empty($p_text,$p_id,$p_title="")
+        {
+            $p_url="javascript:void(0)";
+            $str=sprintf('<a id="%s" href="javascript:void(0)" class="line" title="%s">%s</a>',
+            $p_id,$p_title,$p_text);
+            return $str;
+        }
         /**
          *Return a simple anchor with a url or a javascript
          * if $p_js is not null then p_url will be javascript:void(0)
@@ -876,10 +905,10 @@ class HtmlInput
          */
         static function  button_action_remove_operation($p_operation) 
         {
-            $rmOperation=sprintf("javascript:if ( confirm('"._('Voulez-vous effacer cette relation ')."')==true ) {remove_operation('%s','%s');}",
+            $rmOperation=sprintf("javascript:confirm_box(null,'"._('Voulez-vous effacer cette relation ')."',function ()  {remove_operation('%s','%s');});",
 							dossier::id(),
 							$p_operation);
-            $js= '<a class="tinybutton" id="acop'.$p_operation.'" href="'.$rmOperation.'">'."&#x2D5D;".'</a>';
+            $js= '<a class="tinybutton" id="acop'.$p_operation.'" href="javascript:void(0)" onclick="'.$rmOperation.'">'.SMALLX.'</a>';
             return $js;
         }
         static function button_action_add_concerned_card($p_agid)
@@ -888,7 +917,13 @@ class HtmlInput
             $javascript= <<<EOF
                     obj={dossier:$dossier,ag_id:$p_agid};action_add_concerned_card(obj);
 EOF;
-            $js=HtmlInput::button_action(_('Ajout autres'), $javascript);
+            $js=HtmlInput::button_action(_('Ajout autres'), $javascript,'xx','smallbutton');
+            return $js;
+        }
+        static function button_action_add()
+        {
+            $dossier=Dossier::id();
+            $js=HtmlInput::button_action(_('Nouvel événement'),'action_add('.$dossier.')','xx','smallbutton');
             return $js;
         }
 }
