@@ -22,7 +22,7 @@
 /*!\file
  * \brief Html Input
  */
-require_once('class_html_input.php');
+require_once NOALYSS_INCLUDE.'/class_html_input.php';
 class IHidden extends HtmlInput
 {
     /*!\brief show the html  input of the widget*/
