@@ -23,7 +23,7 @@
  * \brief Html Input
  *  - name is the name and id of the input
  */
-require_once('class_html_input.php');
+require_once NOALYSS_INCLUDE.'/class_html_input.php';
 class IRelated_Action extends HtmlInput
 {
 
