@@ -25,8 +25,8 @@
 /*!
  * \brief For the periode tables parm_periode and jrn_periode
  */
-require_once ('ac_common.php');
-require_once ('class_database.php');
+require_once  NOALYSS_INCLUDE.'/ac_common.php';
+require_once  NOALYSS_INCLUDE.'/class_database.php';
 class Periode
 {
     var $cn;			/*!< database connection */
@@ -201,7 +201,7 @@ class Periode
                                      from parm_periode
                                      order by p_start,p_end");
             $Max=Database::num_row($Res);
-            echo '<form id="periode_frm" method="POST" onsubmit="confirm(\'Confirmez-vous la fermeture des périodes choisies ?\')" >';
+            echo '<form id="periode_frm" method="POST" onsubmit="return confirm_box(this,\'Confirmez-vous la fermeture des périodes choisies ?\')" >';
             echo HtmlInput::array_to_hidden(array('ac','gDossier','jrn_def_id','choose'), $_REQUEST);
             echo '<TABLE ALIGN="CENTER">';
             echo "</TR>";
@@ -239,7 +239,8 @@ class Periode
                     $change='<TD></TD>';
 		    $remove=sprintf(_('Nombre opérations %d'),$l_line['count_op']);
                     $remove=td($remove,' class="mtitle" ');
-                    $change=td ('<A class="mtitle" HREF="?ac='.$_REQUEST['ac'].'&action=reopen&p_per='.$l_line['p_id'].'&'.$str_dossier.'" onclick="return confirm(\''._('Confirmez Réouverture').' ?\')"> Réouverture</A>',' class="mtitle"');
+                    $change=td ('<A class="mtitle" HREF="javascript:void(0)"'
+                            . ' onclick="return confirm_box(null,\''._('Confirmez Réouverture').' ?\',function() {window.location=\'do.php?ac='.$_REQUEST['ac'].'&action=reopen&p_per='.$l_line['p_id'].'&'.$str_dossier.'\';} )"> Réouverture</A>',' class="mtitle"');
 
                 }
                 else
@@ -261,8 +262,14 @@ class Periode
 
                     if ($l_line['count_op'] == 0 )
                     {
-                        $remove.='<A class="mtitle" HREF="?ac='.$_REQUEST['ac'].'&action=delete_per&p_per='.
-                                 $l_line['p_id']."&$str_dossier\" onclick=\"return confirm('"._('Confirmez effacement ?')."')\" > Efface</A>";
+                        $go='do.php?'.http_build_query(array('ac'=>$_REQUEST['ac'],
+                            'action'=>'delete_per',
+                            'p_per'=>$l_line['p_id'],
+                            'gDossier'=>Dossier::id()));
+                        
+                        $remove.='<A class="mtitle" HREF="javascript:void(0)" '
+                                . 'onclick="return confirm_box (null,\''._('Confirmez effacement ?').'\',function() { window.location=\''.$go.'\'});" >'
+                                . ' Efface</A>';
                     }
                     else
                     {
@@ -279,7 +286,8 @@ class Periode
             }
             echo '</table>';
             echo '<p style="text-align:center">';
-            echo HtmlInput::submit('close_per','Fermeture des périodes sélectionnées');
+            echo HtmlInput::hidden("close_per", 1);
+            echo HtmlInput::submit('close_per_bt','Fermeture des périodes sélectionnées');
             echo '</p>';
             echo '</form>';
             $but=new IButton('show_per_add','Ajout d\'une période');
@@ -326,7 +334,7 @@ class Periode
                                    $this->jrn_def_id);
             $jrn_name=Database::fetch_result($r,0,0);
             echo '<h2> Journal '.$jrn_name.'</h2>';
-            echo '<form id="periode_frm" method="POST" onsubmit="confirm(\'Confirmez-vous la fermeture des périodes choisies ?\')" >';
+            echo '<form id="periode_frm" method="POST" onsubmit="return confirm_box(this,\'Confirmez-vous la fermeture des périodes choisies ?\')" >';
             echo HtmlInput::array_to_hidden(array('ac','gDossier','jrn_def_id','choose'), $_REQUEST);
 
             echo '<TABLE ALIGN="CENTER">';
@@ -357,8 +365,14 @@ class Periode
                 $closed="";
                 if ( $l_line['status'] != 'OP' )
                 {
-		  $closed=td ('<A class="mtitle" HREF="?ac='.$_REQUEST['ac'].'&action=reopen&p_per='.$l_line['p_id'].'&'.$str_dossier.'&jrn_def_id='.$this->jrn_def_id.'" onclick="return confirm(\''._('Confirmez Réouverture').' ?\')"> Réouverture</A>',' class="mtitle"');
-		  //                    $closed=($l_line['status']=='CE')?'<TD>Centralisee</TD>':'<TD>Ferm&eacute;e</TD>';
+                    $go='do.php?'.http_build_query(array('ac'=>$_REQUEST['ac'],
+                        'action'=>'reopen',
+                        'p_per'=>$l_line['p_id'],
+                        'gDossier'=>Dossier::id(),
+                        'jrn_def_id'=>$this->jrn_def_id));
+                    
+		  $closed=td ('<A class="mtitle" HREF="javascript:void(0)" '
+                          . 'onclick="return confirm_box(null,\''._('Confirmez Réouverture').' ?\',function() {window.location=\''.$go.'\';} );"> Réouverture</A>',' class="mtitle"');
                 }
                
                 echo "$closed";
