@@ -22,7 +22,7 @@
 /*!\file
  * \brief definition of the class Pre_Op_Advanced
  */
-require_once ('class_pre_operation.php');
+require_once  NOALYSS_INCLUDE.'/class_pre_operation.php';
 
 /*---------------------------------------------------------------------- */
 /*!\brief concerns the predefined operation for the operation from 'Ecriture direct'
@@ -157,7 +157,7 @@ class Pre_Op_Advanced extends Pre_operation_detail
        function display($p_array)
     {
         global $g_parameter, $g_user;
-        require_once 'class_acc_ledger.php';
+        require_once NOALYSS_INCLUDE.'/class_acc_ledger.php';
         $legder=new Acc_Ledger($this->db,$this->jrn_def_id);
         $legder->nb=$legder->get_min_row();
 
