@@ -26,7 +26,7 @@
  *
  *
  */
-require_once 'class_stock_sql.php';
+require_once NOALYSS_INCLUDE.'/class_stock_sql.php';
 
 class Stock extends Stock_Sql
 {
@@ -39,7 +39,7 @@ class Stock extends Stock_Sql
 	{
 
 		$sql = $this->create_query_histo($p_array);
-		require_once 'class_sort_table.php';
+		require_once NOALYSS_INCLUDE.'/class_sort_table.php';
 		$p_url = HtmlInput::get_to_string(array("gDossier", "ac", "wcard", "wdate_start", "wdate_end", "wrepo",
 					"wamount_start", "wamount_end", "wcode_stock", "wdirection"));
 
@@ -71,7 +71,7 @@ class Stock extends Stock_Sql
 
 		$this->search_box_button();
 		$this->search_box($p_array);
-		require_once 'template/stock_histo.php';
+		require_once NOALYSS_INCLUDE.'/template/stock_histo.php';
 		$this->export_stock_histo_form();
 		echo HtmlInput::print_window();
 	}
@@ -150,7 +150,7 @@ class Stock extends Stock_Sql
 		);
 		$wdirection->selected = HtmlInput::default_value("wdirection", "-1", $p_array);
 
-		require_once 'template/stock_histo_search.php';
+		require_once NOALYSS_INCLUDE.'/template/stock_histo_search.php';
 	}
 
 	function create_query_histo($p_array)
@@ -245,11 +245,11 @@ class Stock extends Stock_Sql
 		}
 		if ($present == 'T')
 		{
-			require_once 'template/stock_summary_table.php';
+			require_once NOALYSS_INCLUDE.'/template/stock_summary_table.php';
 		}
 		if ($present == 'L')
 		{
-			require_once 'template/stock_summary_list.php';
+			require_once NOALYSS_INCLUDE.'/template/stock_summary_list.php';
 			$this->export_stock_summary_list_form();
 
 		}
