@@ -1,7 +1,7 @@
 <?php
-require_once('class_database.php');
-require_once('ac_common.php');
-require_once 'class_noalyss_sql.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/class_noalyss_sql.php';
 /*
  *   This file is part of NOALYSS.
  *
