@@ -18,19 +18,20 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
-/** \file
- * \brief
- *   Data & function about connected users
- */
-/**
- * \brief
- *   Data & function about connected users
+/** 
+ * @file
+ * @brief Data & function about connected users
  */
 
-require_once("constant.php");
-require_once("user_common.php");
-require_once('class_dossier.php');
-require_once('ac_common.php');
+/**
+ * @brief Data & function about connected users
+ *   
+ */
+
+require_once NOALYSS_INCLUDE.'/constant.php';
+require_once NOALYSS_INCLUDE.'/user_common.php';
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
 
 class User
 {
@@ -40,7 +41,13 @@ class User
 	var $db;
 	var $admin;
 	var $valid;
-
+        var $first_name;
+        var $name;
+        var $active ;
+        var $login ;
+        var $password ;
+        var $email ;
+        
 	function User(&$p_cn, $p_id = -1)
 	{
 		// if p_id is not set then check the connected user
@@ -53,7 +60,7 @@ class User
 				exit();
 			}
 
-			$this->login = $_SESSION['g_user'];
+			$this->login =strtolower($_SESSION['g_user']);
 			$this->pass = $_SESSION['g_pass'];
 			$this->lang = (isset($_SESSION['g_lang'])) ? $_SESSION['g_lang'] : 'fr_FR.utf8';
 			$this->valid = (isset($_SESSION['isValid'])) ? 1 : 0;
@@ -90,7 +97,7 @@ class User
 		  the database thanks it login */
 		if ($this->id < 0)
 		{
-			$sql_cond = "   where use_login=$1";
+			$sql_cond = "   where lower(use_login)=lower($1)";
 			$sql_array = array($this->login);
 		}
 		else
@@ -99,13 +106,14 @@ class User
 			$sql_array = array($this->id);
 		}
 		$sql = "select use_id,
-             use_first_name,
-             use_name,
-             use_login,
-             use_active,
-             use_admin,
-			 use_pass
-             from ac_users ";
+                            use_first_name,
+                            use_name,
+                            use_login,
+                            use_active,
+                            use_admin,
+                            use_pass,
+                            use_email
+                        from ac_users ";
 		$cn = new Database();
 		$Res = $cn->exec_sql($sql . $sql_cond, $sql_array);
 		if (($Max = Database::num_row($Res)) == 0)
@@ -113,20 +121,33 @@ class User
 		$row = Database::fetch_array($Res, 0);
 		$this->id = $row['use_id'];
 		$this->first_name = $row['use_first_name'];
+		$this->last_name = $row['use_name'];
 		$this->name = $row['use_name'];
 		$this->active = $row['use_active'];
 		$this->login = $row['use_login'];
 		$this->admin = $row['use_admin'];
 		$this->password = $row['use_pass'];
+                $this->email=$row['use_email'];
 	}
 
 	function save()
 	{
 
 		$Sql = "update ac_users set use_first_name=$1, use_name=$2
-             ,use_active=$3,use_admin=$4,use_pass=$5 where use_id=$6";
+             ,use_active=$3,use_admin=$4,use_pass=$5 ,use_email = $7 where use_id=$6";
 		$cn = new Database();
-		$Res = $cn->exec_sql($Sql, array($this->first_name, $this->last_name, $this->active, $this->admin, $this->pass, $this->id));
+		$Res = $cn->exec_sql($Sql, array($this->first_name, $this->last_name, $this->active, $this->admin, $this->pass, $this->id,$this->email));
+	}
+        function insert()
+	{
+
+		$Sql = "INSERT INTO ac_users(
+                        use_first_name, use_name, use_login, use_active,  
+                        use_admin, use_pass, use_email)
+                            VALUES ($1, $2, $3, $4, $5, $6, $7) returning use_id";
+
+		$cn = new Database();
+		$this->id= $cn->get_value($Sql, array($this->first_name, $this->last_name, $this->login,1,0, $this->pass,$this->email));
 	}
 
 	/**
@@ -172,7 +193,7 @@ class User
 			$cn->exec_sql($sql, array($_SESSION['g_user'], $_SERVER["REMOTE_ADDR"], $from, $_SERVER['REQUEST_URI'], 'FAIL'));
 			if (!$silent)
 			{
-				alert(_('Utilisateur ou mot de passe incorrect'));
+				echo '<script> alert(\''._('Utilisateur ou mot de passe incorrect').'\')</script>';
 				redirect('index.html');
 			}
 			$this->valid = 0;
@@ -189,12 +210,13 @@ class User
 		return $ret;
 	}
 
-	/**\brief return  the access to a folder,
+	/**
+         * \brief return  the access to a folder,
 	 * \param $p_dossier id if it is == 0 then we take the value from $_SESSION
 	 * \return the priv_priv
 	 *          - X no access
 	 *          - R has access (normal user)
-	 *          - L Local Admin
+	 
 	 *
 	 */
 
@@ -203,41 +225,47 @@ class User
 
 		if ($p_dossier == 0)
 			$p_dossier = dossier::id();
-		if ($this->is_local_admin($p_dossier) == 1 || $this->admin == 1)
-			return 'L';
+		if ($this->admin == 1)		return 'R';
 		$cn = new Database();
 
-		$sql = "select priv_priv from priv_user join jnt_use_dos on (jnt_id=priv_jnt) join ac_users using (use_id)
-             where use_id=$1 and dos_id=$2";
+		$sql = "select 'R' from jnt_use_dos where use_id=$1 and dos_id=$2";
 
 		$res = $cn->get_value($sql, array($this->id, $p_dossier));
-		if ($res == '')
-			return 'X';
+                
+		if ($cn->get_affected()== 0) return 'X';
 		return $res;
 	}
 
-	/* \brief save the access of a folder
+	/**
+         * \brief save the access of a folder
 	 * \param $db_id the dossier id
-	 * \param $priv the priv. to set
+	 * \param $priv boolean, true then it is granted, false it is removed
 	 */
 
 	function set_folder_access($db_id, $priv)
-	{
+        {
 
-		$cn = new Database();
-		$jnt = $cn->get_value("select jnt_id from jnt_use_dos where dos_id=$1 and use_id=$2", array($db_id, $this->id));
+            $cn=new Database();
+            if ($priv)
+            {
+                // the access is granted
+                $jnt=$cn->get_value("select jnt_id from jnt_use_dos where dos_id=$1 and use_id=$2", array($db_id, $this->id));
 
-		if ($cn->size() == 0)
-		{
+                if ($cn->size()==0)
+                {
 
-			$Res = $cn->exec_sql("insert into jnt_use_dos(dos_id,use_id) values($1,$2)", array($db_id, $this->id));
-			$jnt = $cn->get_value("select jnt_id from jnt_use_dos where dos_id=$1 and use_id=$2", array($db_id, $this->id));
-			$Res = $cn->exec_sql("insert into priv_user (priv_priv,priv_jnt) values($1,$2)", array($priv, $jnt));
-		}
-		$Res = $cn->exec_sql("update priv_user set priv_priv=$1 where priv_jnt=$2", array($priv, $jnt));
-	}
+                    $Res=$cn->exec_sql("insert into jnt_use_dos(dos_id,use_id) values($1,$2)", array($db_id, $this->id));
+                }
+            } 
+            else 
+            {
+                // Access is revoked
+                $cn->exec_sql('delete from jnt_use_dos where use_id  = $1 and dos_id = $2 ', array($this->id, $db_id));
+            }
+        }
 
-	/**\brief check that a user is valid and the access to the folder
+    /**
+         * \brief check that a user is valid and the access to the folder
 	 * \param $p_ledger the ledger to check
 	 * \return the priv_priv
 	 * - O only predefined operation
@@ -325,7 +353,8 @@ class User
 		return $array;
 	}
 
-	/**\brief return an sql condition for filtering the permitted ledger
+	/**
+         * \brief return an sql condition for filtering the permitted ledger
 	 * \param $p_type = ALL or the type of the ledger (ACH,VEN,FIN,ODS)
 	 * \param $p_access =3 for READ or WRITE, 2 READ and write, 1 for readonly
 	 *
@@ -434,7 +463,9 @@ class User
 		return $array['PERIODE'];
 	}
 
-	/**\brief return the mini rapport to display on the welcome page
+	/**
+         * 
+         * \brief return the mini rapport to display on the welcome page
 	 * \return 0 if nothing if found or the report to display (formdef.fr_id)
 	 */
 
@@ -463,6 +494,12 @@ class User
 			$Res = $this->db->exec_sql($sql, array($this->id, $p_id));
 		}
 	}
+        /**
+         * Save the preference , the scope is global, the settings are saved
+         * into account_repository
+         * @param $key THEME,  LANG , PAGESIZE
+         * @param $value value of the key
+         */
 
 	function save_global_preference($key, $value)
 	{
@@ -508,12 +545,13 @@ class User
 	/**
 	 * Check if an user can access a module, return 1 if yes, otherwise 0
 	 * record in audit log
+         * This function works only if user is connected to a Folder
 	 * @param string $p_module menu_ref.me_code
 	 */
 	function check_module($p_module)
 	{
-		$acc = $this->db->get_value("select count(*) from v_all_menu where user_name = $1
-                and me_code=$2", array($this->login, $p_module));
+		$acc = $this->db->get_value("select count(*) from v_all_menu where p_id = $1
+                and me_code=$2", array($this->get_profile(), $p_module));
 		if ($acc == 0)
 		{
 			$this->audit("FAIL", $p_module);
@@ -709,10 +747,10 @@ class User
 	}
 
 	/**
-	 *  !\brief Check if the user can print (in menu_ref p_type_display=p)
+	 *@brief Check if the user can print (in menu_ref p_type_display=p)
 	 * 	otherwise warn and exit
-	 * \param $p_action requested action
-	 * \return nothing the program exits automatically
+	 * @param $p_action requested action
+	 * @return nothing the program exits automatically
 	 */
 	function check_print($p_action)
 	{
@@ -720,8 +758,7 @@ class User
 		$this->audit('AUDIT', $p_action);
 		if ($this->Admin() == 1)
 			return 1;
-		if ($this->is_local_admin(dossier::id()) == 1)
-			return 1;
+		
 		$res = $cn->get_value("select count(*) from profile_menu
 			join profile_user using (p_id)
 			where user_name=$1 and me_code=$2 ", array($this->login, $p_action));
@@ -757,6 +794,7 @@ class User
 
 	/**
 	 * \brief  Check if an user is an local administrator
+         * @deprecated since version 6.7
 	 *
 	 *
 	 * \param $p_dossier : dossier_id
@@ -769,24 +807,20 @@ class User
 
 	function is_local_admin($p_dossier = -1)
 	{
-		if ($p_dossier == -1)
-		{
-			$p_dossier = dossier::id();
-		}
+            if ($p_dossier==-1)
+            {
+                $p_dossier=dossier::id();
+            }
 
-		if ($this->login == 'admin')
-			return 1;
-		$sql = 'select priv_priv from ac_users join jnt_use_dos using (use_id) join priv_user ' .
-				' on ( jnt_use_dos.jnt_id = priv_user.priv_jnt) ' .
-				" where priv_priv='L' and use_login='" . $this->login . "' and dos_id=$p_dossier";
-
-		$cn = new Database();
-
-		$isAdmin = $cn->count_sql($sql);
-
-
-		return $isAdmin;
-	}
+            if ($this->login=='admin')
+            {
+                return 1;
+            }
+            else
+            {
+                return 0;
+            }
+        }
 	/**
 	 *@brief return array of available repository
 	 *
@@ -822,8 +856,9 @@ class User
 		return $r;
 	}
 	/**
-	 * \brief return an array with all the users who can access $p_dossier including the global admin. The user
-	 * must be activated
+	 * \brief return an array with all the active users who can access 
+         *  $p_dossier including the global admin. 
+         *  The user must be activated
 	 *
 	 * \param $p_dossier dossier
 	 * \return an array of user's  object
@@ -840,9 +875,9 @@ class User
 	{
 		$sql = "select distinct use_id,use_login,use_first_name,use_name from ac_users
              left outer join  jnt_use_dos using (use_id)
-	     left join priv_user on (priv_jnt=jnt_id)
-              where
-              (dos_id=$1 or  use_admin=1) and use_active=1 and (use_admin=1  or priv_priv <> 'X') order by use_login,use_name";
+             where
+              (dos_id=$1 and use_active=1) or (use_active=1 and use_admin=1)
+              order by use_login,use_name";
 
 
 		$repo = new Database();
@@ -869,14 +904,15 @@ class User
 		return $this->get_ledger_access($p_jrn);
 	}
 
-	/**\brief check if an user can access a folder, if he cannot display a dialog box
+	/**
+         * \brief check if an user can access a folder, if he cannot display a dialog box
 	 * and exit
 	 * \param the folder if
 	 * \param $silent false, echo an error message and exit, true : exit without warning
 	 * default is false
 	 * \return
 	 *  - L for administrator (local and global)
-	 *  - P for extension only
+	 *  - X no access
 	 *  - R regular user
 	 */
 
@@ -887,7 +923,7 @@ class User
 			return 'L';
 		$cn = new Database();
 
-		$dossier = $cn->get_value("select priv_priv from jnt_use_dos join priv_user on (priv_jnt=jnt_id) where dos_id=$1 and use_id=$2", array($p_dossier_id, $this->id));
+		$dossier = $cn->get_value("select 'R' from jnt_use_dos where dos_id=$1 and use_id=$2", array($p_dossier_id, $this->id));
 		$dossier = ($dossier == '') ? 'X' : $dossier;
 		if ($dossier == 'X')
 		{
@@ -931,10 +967,28 @@ class User
 		$p_array = $this->get_available_folder($p_filtre);
 
 		$result = "";
-		if ($p_array == 0)
-			return $result . " * Aucun dossier *";
-
-		$result.="<TABLE id=\"folder\" >";
+		
+		$result.="<TABLE id=\"folder\" class=\"result\">";
+                $result.="<tr>";
+                $result.="<th>";
+                $result.=_("Id");
+                $result.="</th>";
+                $result.="<th>";
+                $result.=_("Nom");
+                $result.="</th>";
+                $result.="<th>";
+                $result.=_("Description");
+                $result.="</th>";
+                $result.="</tr>";
+                if ($p_array == 0) {
+                    $result.="<tr>";
+                    $result.='<td style="width:auto" colspan=3>';
+                    $result.=_("Aucun dossier disponible");
+                    $result.='</td>';
+                    $result.="</tr>";
+                    return $result;
+                }
+                
 		for ($i = 0; $i < sizeof($p_array); $i++)
 		{
 
@@ -945,14 +999,7 @@ class User
 				$tr = "odd";
 			else
 				$tr = "even";
-			if ($this->check_dossier($id) != 'P')
-			{
-				$target = "do.php?gDossier=$id";
-			}
-			else
-			{
-				$target = "extension.php?gDossier=$id";
-			}
+    			$target = "do.php?gDossier=$id";
 
 			$result.="<TR class=\"$tr\">";
 
@@ -964,7 +1011,7 @@ class User
 			$result.="</TD>";
 			$desc = ($desc == "") ? "<i>Aucune description</i>" : h($desc);
 			$desc = "<A class=\"dossier\" HREF=\"$target\">$desc</A>";
-			$result.="<TD class=\"$tr\" style=\"padding-left:50px\">" . $desc;
+			$result.="<TD class=\"$tr\" >" . $desc;
 			$result.="</TD>";
 			$result.="</TR>";
 		}
@@ -993,21 +1040,22 @@ class User
 		{
 			// show only available folders
 			// if user is not an admin
-			$Res = $cn->exec_sql("select distinct dos_id,dos_name,dos_description from ac_users
-             natural join jnt_use_dos
-             natural join  ac_dossier
-             join  priv_user on ( priv_jnt=jnt_id)
-             where use_active=1
-             and use_login= $1
-             and priv_priv != 'X' and ( dos_name ~* $2 or dos_description ~* $2 )
-             order by dos_name", array($this->login, $p_filter));
+			$Res = $cn->exec_sql("select distinct dos_id,dos_name,dos_description 
+                            from ac_users
+                            natural join jnt_use_dos
+                            natural join  ac_dossier
+                            where
+                            use_login= $1
+                            and use_active = 1
+                            and ( dos_name ~* $2 or dos_description ~* $2 )
+                            order by dos_name", array($this->login, $p_filter));
 		}
 		else
 		{
 			$Res = $cn->exec_sql("select distinct dos_id,dos_name,dos_description from ac_dossier
              where   dos_name ~* $1 or dos_description ~* $1 order by dos_name", array($p_filter));
 		}
-		require_once('class_database.php');
+		require_once NOALYSS_INCLUDE.'/class_database.php';
 
 		$max = Database::num_row($Res);
 		if ($max == 0)
@@ -1063,9 +1111,28 @@ class User
 	function get_profile()
 	{
 		$profile = $this->db->get_value("select p_id from profile_user where
-				user_name=$1", array($this->login));
+				lower(user_name)=lower($1)", array($this->login));
 		return $profile;
 	}
+        /**
+         * Check if the current user can add an action in the profile given
+         * in parameter
+         * @param type $p_profile profile.p_id = action_gestion.ag_dest
+         * @return boolean
+         */
+        function can_add_action($p_profile)
+        {
+            $r=$this->db->get_value (' select count(*) 
+                from user_sec_action_profile
+                where p_granted=$1
+                and p_id=$2',
+                    array($this->get_profile(),$p_profile));
+            if ($r == 0 ) 
+            {
+                return false;
+            } 
+            return true;
+        }
         /**
          *Check if the profile of the user can write for this profile
          * @param  $dtoc action_gestion.ag_id
@@ -1073,8 +1140,9 @@ class User
          */
 	function can_write_action($dtoc)
 	{
+            if ( $this->Admin() == 1 ) return true;
 		$profile = $this->get_profile();
-		$r = $this->db->get_value(" select count(*) from action_gestion where ag_id=$1 and ag_dest in
+                    $r = $this->db->get_value(" select count(*) from action_gestion where ag_id=$1 and ag_dest in
 				(select p_granted from user_sec_action_profile where ua_right='W' and p_id=$2) ", array($dtoc, $profile));
 		if ($r == 0)
 			return false;
@@ -1088,6 +1156,7 @@ class User
          */
 	function can_read_action($dtoc)
 	{
+                if ( $this->Admin() == 1 ) return true;
 		$profile = $this->get_profile();
 		$r = $this->db->get_value(" select count(*) from action_gestion where ag_id=$1 and (ag_dest in
 				(select p_granted from user_sec_action_profile where p_id=$2) or ag_owner=$3)", array($dtoc, $profile, $this->login));
@@ -1102,6 +1171,7 @@ class User
          */
         function can_write_repo($p_repo)
         {
+            if ( $this->Admin() == 1 ) return true;
             $profile=$this->get_profile();
             $r=$this->db->get_value("select count(*)
                 from profile_sec_repository
@@ -1120,6 +1190,7 @@ class User
          */
         function can_read_repo($p_repo)
         {
+            if ( $this->Admin() == 1 ) return true;
             $profile=$this->get_profile();
             $r=$this->db->get_value("select count(*)
                 from profile_sec_repository
@@ -1141,7 +1212,15 @@ class User
             alert(_("Les mots de passe ne correspondent pas. Mot de passe inchangé"));
         }
     }
-
+    /**
+     * Save the password from PREFERENCE MODULE
+     * @param type $p_email
+     */
+    function save_email($p_email)
+    {
+        $repo=new Database();
+        $repo->exec_sql("update ac_users set use_email=$1 where use_login=$2", array($p_email, $_SESSION['g_user']));
+    }
 }
 
 ?>
