@@ -21,7 +21,7 @@
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
 global $g_user;
 echo '<div class="content">';
-require_once("class_own.php");
+require_once NOALYSS_INCLUDE.'/class_own.php';
 if (isset($_POST['record_company']))
 {
 	$m = new Own($cn);
