@@ -25,10 +25,10 @@
  * \brief file included to manage all the sold operation
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_icheckbox.php");
-require_once("class_acc_ledger_purchase.php");
-require_once ('class_pre_op_ach.php');
-require_once('class_ipopup.php');
+require_once NOALYSS_INCLUDE.'/class_icheckbox.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger_purchase.php';
+require_once  NOALYSS_INCLUDE.'/class_pre_op_ach.php';
+require_once NOALYSS_INCLUDE.'/class_ipopup.php';
 $gDossier = dossier::id();
 global $g_parameter;
 $cn = new Database(dossier::id());
@@ -78,10 +78,14 @@ if (isset($_POST['view_invoice']))
 		echo HtmlInput::hidden('ac', $_REQUEST['ac']);
                             ?>
 <div id="tab_id" >
+    <script>
+        var a_tab = ['modele_div_id','repo_div_id','facturation_div_id','reverse_div_id'];
+    </script>
 <ul class="tabs">
-    <li class="tabs_selected"><a href="javascript:void(0)" title="<?php echo _("Générer une facture ou charger un document")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';$('modele_div_id').hide();$('repo_div_id').hide();$('facturation_div_id').show();"><?php echo _('Facture')?></a></li>
-    <li class="tabs"> <a href="javascript:void(0)" title="<?php echo _("Choix du dépôt")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';$('modele_div_id').hide();$('facturation_div_id').hide();$('repo_div_id').show();"> <?php echo _('Dépôt')?> </a></li>
-    <li class="tabs"> <a href="javascript:void(0)" title="<?php echo _("Modèle à sauver")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';$('facturation_div_id').hide();$('repo_div_id').hide();$('modele_div_id').show()"> <?php echo _('Modèle')?> </a></li>
+    <li class="tabs_selected"><a href="javascript:void(0)" title="<?php echo _("Générer une facture ou charger un document")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';show_tabs(a_tab,'facturation_div_id')"><?php echo _('Facture')?></a></li>
+    <li class="tabs"> <a href="javascript:void(0)" title="<?php echo _("Choix du dépôt")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';show_tabs(a_tab,'repo_div_id')"> <?php echo _('Dépôt')?> </a></li>
+    <li class="tabs"> <a href="javascript:void(0)" title="<?php echo _("Modèle à sauver")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';show_tabs(a_tab,'modele_div_id')"> <?php echo _('Modèle')?> </a></li>
+    <li class="tabs"> <a href="javascript:void(0)" title="<?php echo _("Extourne")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';show_tabs(a_tab,'reverse_div_id')"> <?php echo _('Extourne')?> </a></li>
 </ul>
 <?php
 		echo $Ledger->select_depot(false, -1);
@@ -91,15 +95,24 @@ if (isset($_POST['view_invoice']))
                 echo Pre_operation::save_propose();
                 echo '</div>';
 
-                echo HtmlInput::submit("record", _("Enregistrement"), 'onClick="return verify_ca(\'\');"');
+               
+                echo '<div id="reverse_div_id" style="display:none;height:185px;height:10rem">';
+                $reverse_date=new IDate('reverse_date');
+                $reverse_ck=new ICheckBox('reverse_ck');
+                echo _('Extourne opération')." ".$reverse_ck->input()." ";
+                echo $reverse_date->input();
+                echo '</div>';
+                
+                 echo HtmlInput::submit("record", _("Enregistrement"), 'onClick="return verify_ca(\'\');"');
 		echo HtmlInput::submit('correct', _("Corriger"));
 		echo '</form>';
 		echo '</div>'; /* tab_id */
 		echo '</div>';
                 ?>
 <script>
-    $('repo_div_id').hide();
+     $('repo_div_id').hide();
     $('modele_div_id').hide();
+show_tab(a_tab,'facturation_div_id');
 </script>
 <?php
             echo '</div>';
@@ -157,6 +170,33 @@ if (isset($_POST['record']))
                      echo '<h2>'._('Document').'</h2>';
                      echo $Ledger->doc;
 		}
+                // extourne
+                if (isset($_POST['reverse_ck']))
+                {
+                    $p_date=HtmlInput::default_value_post('reverse_date', '');
+                    if (isDate($p_date)==$p_date)
+                    {
+                        // reverse the operation
+                        try
+                        {
+                            $Ledger->reverse($p_date);
+                            echo '<p>';
+                            echo _('Extourné au ').$p_date;
+                            echo '</p>';
+                        }
+                        catch (Exception $e)
+                        {
+                            echo '<p class="notice">'._('Opération non extournée').
+                                $e->getMessage().
+                                '</p>';
+                        }
+                    }
+                    else
+                    {
+                        // warning because date is invalid
+                        echo '<p class="notice">'._('Date invalide, opération non extournée').'</p>';
+                    }
+                }
                 echo $Ledger->button_new_operation();
 		echo '</div>';
 		return;
@@ -209,44 +249,52 @@ else
     echo '<div class="content">';
 
 echo '<p class="notice">'.$p_msg.'</p>';
-echo "<FORM class=\"print\"NAME=\"form_detail\" METHOD=\"POST\" >";
-/* request for a predefined operation */
-if ( isset($_REQUEST['pre_def']) && !isset($_POST['correct']))
+try
 {
-	// used a predefined operation
-	//
-        $op = new Pre_op_ach($cn);
-	$op->set_od_id($_REQUEST['pre_def']);
-	$p_post = $op->compute_array();
-	$Ledger->id = $_REQUEST ['p_jrn_predef'];
-	$p_post['p_jrn'] = $Ledger->id;
-	echo $Ledger->input($p_post);
-	echo '<div class="content">';
-	echo $Ledger->input_paid();
-	echo '</div>';
-	echo '<script>';
-	echo 'compute_all_ledger();';
-	echo '</script>';
+    echo "<FORM class=\"print\"NAME=\"form_detail\" METHOD=\"POST\" >";
+    /* request for a predefined operation */
+    if (isset($_REQUEST['pre_def'])&&!isset($_POST['correct']))
+    {
+        // used a predefined operation
+        //
+        $op=new Pre_op_ach($cn);
+        $op->set_od_id($_REQUEST['pre_def']);
+        $p_post=$op->compute_array();
+        $Ledger->id=$_REQUEST ['p_jrn_predef'];
+        $p_post['p_jrn']=$Ledger->id;
+        echo $Ledger->input($p_post);
+        echo '<div class="content">';
+        echo $Ledger->input_paid();
+        echo '</div>';
+        echo '<script>';
+        echo 'compute_all_ledger();';
+        echo '</script>';
+    }
+    else
+    {
+        echo $Ledger->input($array);
+        echo HtmlInput::hidden("p_action", "ach");
+        echo HtmlInput::hidden("sa", "p");
+        echo '<div class="content">';
+        echo $Ledger->input_paid();
+        echo '</div>';
+        echo '<script>';
+        echo 'compute_all_ledger();';
+        echo '</script>';
+    }
+    echo '<div class="content">';
+    echo HtmlInput::button('act', _('Actualiser'),
+            'onClick="compute_all_ledger();"');
+    echo HtmlInput::submit("view_invoice", _("Enregistrer"));
+    echo HtmlInput::reset(_('Effacer '));
+    echo '</div>';
+    echo "</FORM>";
 }
-else
+catch (Exception $e)
 {
-	echo $Ledger->input($array);
-	echo HtmlInput::hidden("p_action", "ach");
-	echo HtmlInput::hidden("sa", "p");
-	echo '<div class="content">';
-	echo $Ledger->input_paid();
-	echo '</div>';
-	echo '<script>';
-	echo 'compute_all_ledger();';
-	echo '</script>';
+    alert($e->getMessage());
+    return;
 }
-echo '<div class="content">';
-echo HtmlInput::button('act', _('Actualiser'), 'onClick="compute_all_ledger();"');
-echo HtmlInput::submit("view_invoice", _("Enregistrer"));
-echo HtmlInput::reset(_('Effacer '));
-echo '</div>';
-echo "</FORM>";
-
 if (!isset($_POST['e_date']) && $g_parameter->MY_DATE_SUGGEST=='Y')
 	echo create_script(" get_last_date()");
 echo create_script(" update_name()");
