@@ -28,7 +28,7 @@
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
 global $g_failed,$g_succeed;
-require_once 'class_acc_ledger_fin.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger_fin.php';
 bcscale(2);
 echo '<div class="content">';
 $Ledger = new Acc_Ledger_Fin($cn, 0);
