@@ -27,7 +27,7 @@
  *
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once ('class_acc_parm_code.php');
+require_once  NOALYSS_INCLUDE.'/class_acc_parm_code.php';
     echo '<div class="content">';
     $fiche=new Fiche($cn);
 
