@@ -27,13 +27,13 @@
  *
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_icheckbox.php");
-require_once ('class_acc_ledger.php');
-require_once ('class_acc_reconciliation.php');
-require_once('ac_common.php');
-require_once('class_periode.php');
-require_once('function_javascript.php');
-require_once('class_ipopup.php');
+require_once NOALYSS_INCLUDE.'/class_icheckbox.php';
+require_once  NOALYSS_INCLUDE.'/class_acc_ledger.php';
+require_once  NOALYSS_INCLUDE.'/class_acc_reconciliation.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/class_periode.php';
+require_once NOALYSS_INCLUDE.'/function_javascript.php';
+require_once NOALYSS_INCLUDE.'/class_ipopup.php';
 
 global $g_user;
 
@@ -71,7 +71,7 @@ elseif (isset($_POST['summary']))
 {
 	try {
 			$ledger->verify($_POST);
-			require_once 'operation_ods_confirm.inc.php';
+			require_once NOALYSS_INCLUDE.'/operation_ods_confirm.inc.php';
 	} catch (Exception $e)
 	{
 		echo alert($e->getMessage());
@@ -100,6 +100,35 @@ elseif (isset($_POST['save']))
 		// show feedback
 		echo '<div id="jrn_name_div">'; echo '<h2 id="jrn_name"  style="display:inline">' . $ledger->get_name() . '</h2>'; echo '</div>';
 		echo $ledger->confirm($_POST, true);
+                 // extourne
+                if (isset($_POST['reverse_ck']))
+                {
+                    $p_date=HtmlInput::default_value_post('reverse_date', '');
+                    if (isDate($p_date)==$p_date)
+                    {
+                        // reverse the operation
+                        try
+                        {
+                            $ledger->reverse($p_date);
+                            echo '<p>';
+                            echo _('Extourné au ').$p_date;
+                            echo '</p>';
+                        }
+                        catch (Exception $e)
+                        {
+                            echo '<p class="notice">'._('Opération non extournée').
+                                $e->getMessage().
+                                '</p>';
+                                
+                            }
+                    }
+                    else
+                    {
+                        // warning because date is invalid
+                        echo '<p class="notice">'._('Date invalide, opération non extournée').'</p>';
+                    }
+                }
+                
                 echo $ledger->button_new_operation();
 
 	}
