@@ -23,12 +23,12 @@
  * \brief file included to manage all the sold operation
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_icheckbox.php");
-require_once("class_acc_ledger_sold.php");
-require_once ('class_pre_op_ven.php');
-require_once ('class_document.php');
-require_once ('class_acc_ledger_info.php');
-require_once('class_ipopup.php');
+require_once NOALYSS_INCLUDE.'/class_icheckbox.php';
+require_once NOALYSS_INCLUDE.'/class_acc_ledger_sold.php';
+require_once  NOALYSS_INCLUDE.'/class_pre_op_ven.php';
+require_once  NOALYSS_INCLUDE.'/class_document.php';
+require_once  NOALYSS_INCLUDE.'/class_acc_ledger_info.php';
+require_once NOALYSS_INCLUDE.'/class_ipopup.php';
 
 $gDossier=dossier::id();
 $cn=new Database(dossier::id());
@@ -87,10 +87,14 @@ $p_msg="";
             echo HtmlInput::hidden('ac',$_REQUEST['ac']);
             ?>
 <div id="tab_id" >
+ <script>
+        var a_tab = ['modele_div_id','repo_div_id','facturation_div_id','reverse_div_id'];
+    </script>
 <ul class="tabs">
-    <li class="tabs_selected"><a href="javascript:void(0)" onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';$('modele_div_id').hide();$('repo_div_id').hide();$('facturation_div_id').show();"><?php echo _('Facture')?></a></li>
-    <li class="tabs"> <a href="javascript:void(0)" onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';$('modele_div_id').hide();$('facturation_div_id').hide();$('repo_div_id').show();"> <?php echo _('Dépôt')?> </a></li>
-    <li class="tabs"> <a href="javascript:void(0)" onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';$('facturation_div_id').hide();$('repo_div_id').hide();$('modele_div_id').show()"> <?php echo _('Modèle')?> </a></li>
+    <li class="tabs_selected"><a href="javascript:void(0)" title="<?php echo _("Générer une facture ou charger un document")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';show_tabs(a_tab,'facturation_div_id')"><?php echo _('Facture')?></a></li>
+    <li class="tabs"> <a href="javascript:void(0)" title="<?php echo _("Choix du dépôt")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';show_tabs(a_tab,'repo_div_id')"> <?php echo _('Dépôt')?> </a></li>
+    <li class="tabs"> <a href="javascript:void(0)" title="<?php echo _("Modèle à sauver")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';show_tabs(a_tab,'modele_div_id')"> <?php echo _('Modèle')?> </a></li>
+    <li class="tabs"> <a href="javascript:void(0)" title="<?php echo _("Extourne")?>"  onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';show_tabs(a_tab,'reverse_div_id')"> <?php echo _('Extourne')?> </a></li>
 </ul>
 <?php
             echo $Ledger->select_depot(false, -1);
@@ -99,6 +103,14 @@ $p_msg="";
             echo Pre_operation::save_propose();
 	    echo '</div>';
             
+                    
+            echo '<div id="reverse_div_id" style="display:none;height:185px;height:10rem">';
+            $reverse_date=new IDate('reverse_date');
+            $reverse_ck=new ICheckBox('reverse_ck');
+            echo _('Extourne opération')." ".$reverse_ck->input()." ";
+            echo $reverse_date->input();
+            echo '</div>';
+            
 	    echo HtmlInput::hidden('ac',$_REQUEST['ac']);
             echo HtmlInput::submit("record",_("Enregistrement"),'onClick="return verify_ca(\'\');"');
             echo HtmlInput::submit('correct',_("Corriger"));
@@ -107,8 +119,9 @@ $p_msg="";
             echo '</div>'; /* tab_id */
 ?>
 <script>
-    $('repo_div_id').hide();
+     $('repo_div_id').hide();
     $('modele_div_id').hide();
+show_tab(a_tab,'facturation_div_id');
 </script>
 <?php
             echo '</div>';
@@ -173,6 +186,34 @@ $p_msg="";
             /* Save the additional information into jrn_info */
             $obj=new Acc_Ledger_Info($cn);
             $obj->save_extra($Ledger->jr_id,$_POST);
+             // extourne
+            if (isset($_POST['reverse_ck']))
+            {
+                $p_date=HtmlInput::default_value_post('reverse_date', '');
+                if (isDate($p_date)==$p_date)
+                {
+                    // reverse the operation
+                    try
+                    {
+                        $Ledger->reverse($p_date);
+                        echo '<p>';
+                        echo _('Extourné au ').$p_date;
+                        echo '</p>';
+
+                    }
+                    catch (Exception $e)
+                    {
+                        echo '<p class="notice">'._('Opération non extournée').
+                            $e->getMessage().
+                            '</p>';
+                    }
+                }
+                else
+                {
+                    // warning because date is invalid
+                    echo '<p class="notice">'._('Date invalide, opération non extournée').'</p>';
+                }
+            }
 
             echo $Ledger->button_new_operation();
 
@@ -194,40 +235,43 @@ if ( is_msie() == 0 )
 else
     echo '<div class="content">';
 
-    if ( !isset($_REQUEST ['p_jrn']) )
+if (!isset($_REQUEST ['p_jrn']))
+{
+    $def_ledger=$Ledger->get_first('ven', 2);
+    if (empty($def_ledger))
     {
-        $def_ledger=$Ledger->get_first('ven',2);
-		if (empty($def_ledger))
-	{
-		exit('Pas de journal disponible');
-	}
-        $Ledger->id=$def_ledger['jrn_def_id'];
+        exit('Pas de journal disponible');
     }
-    else
-        $Ledger->id=$_REQUEST ['p_jrn'];
-	if (isset ($_REQUEST['p_jrn_predef'])){
-		$Ledger->id=$_REQUEST['p_jrn_predef'];
-	}
+    $Ledger->id=$def_ledger['jrn_def_id'];
+}
+else
+    $Ledger->id=$_REQUEST ['p_jrn'];
+if (isset($_REQUEST['p_jrn_predef']))
+{
+    $Ledger->id=$_REQUEST['p_jrn_predef'];
+}
 
-    echo '<div id="predef_form">';
-    echo HtmlInput::hidden('p_jrn_predef', $Ledger->id);
-    $op=new Pre_op_ven($cn);
-    $op->set('ledger',$Ledger->id);
-    $op->set('ledger_type',"VEN");
-    $op->set('direct','f');
-    $url=http_build_query(array('p_jrn_predef'=>$Ledger->id,'ac'=>$_REQUEST['ac'],'gDossier'=>dossier::id()));
-    echo $op->form_get('do.php?'.$url);
-    echo '</div>';
+echo '<div id="predef_form">';
+echo HtmlInput::hidden('p_jrn_predef', $Ledger->id);
+$op=new Pre_op_ven($cn);
+$op->set('ledger',$Ledger->id);
+$op->set('ledger_type',"VEN");
+$op->set('direct','f');
+$url=http_build_query(array('p_jrn_predef'=>$Ledger->id,'ac'=>$_REQUEST['ac'],'gDossier'=>dossier::id()));
+echo $op->form_get('do.php?'.$url);
+echo '</div>';
 
-   echo '<div class="content">';
-   echo '<p class="notice">'.$p_msg.'</p>';
- echo "<FORM class=\"print\" NAME=\"form_detail\" METHOD=\"POST\" >";
+echo '<div class="content">';
+echo '<p class="notice">'.$p_msg.'</p>';
+try
+{
+    echo "<FORM class=\"print\" NAME=\"form_detail\" METHOD=\"POST\" >";
     /* request for a predefined operation */
-    if (  isset($_REQUEST['pre_def']) && ! isset($_POST['correct']) )
+    if (isset($_REQUEST['pre_def'])&&!isset($_POST['correct']))
     {
         // used a predefined operation
         //
-        $op=new Pre_op_ven($cn);
+       $op=new Pre_op_ven($cn);
         $op->set_od_id($_REQUEST['pre_def']);
         $p_post=$op->compute_array();
         $Ledger->id=$_REQUEST ['p_jrn_predef'];
@@ -240,12 +284,12 @@ else
         echo 'compute_all_ledger();';
         echo '</script>';
     }
-    else if ( isset ($_GET['create_invoice']))
+    else if (isset($_GET['create_invoice']))
     {
         $array=$Ledger->convert_from_follow($_GET ['ag_id']);
-        echo HtmlInput::hidden("ledger_type","VEN");
-	echo HtmlInput::hidden("ac",$_REQUEST['ac']);
-        echo HtmlInput::hidden("sa","p");
+        echo HtmlInput::hidden("ledger_type", "VEN");
+        echo HtmlInput::hidden("ac", $_REQUEST['ac']);
+        echo HtmlInput::hidden("sa", "p");
         echo $Ledger->input($array);
         echo '<div class="content">';
         echo $Ledger->input_paid();
@@ -256,9 +300,10 @@ else
     }
     else
     {
-        echo HtmlInput::hidden("ledger_type","VEN");
-	  echo HtmlInput::hidden("ac",$_REQUEST['ac']);
-        echo HtmlInput::hidden("sa","p");
+        echo HtmlInput::hidden("ledger_type", "VEN");
+        echo HtmlInput::hidden("ac", $_REQUEST['ac']);
+        echo HtmlInput::hidden("sa", "p");
+
         echo $Ledger->input($array);
         echo '<div class="content">';
         echo $Ledger->input_paid();
@@ -267,7 +312,13 @@ else
         echo 'compute_all_ledger();';
         echo '</script>';
     }
-    echo '<div class="content">';
+}
+catch (Exception $e)
+{
+    alert($e->getMessage());
+    return;
+}
+echo '<div class="content">';
 
 
     echo HtmlInput::button('act',_('Actualiser'),'onClick="compute_all_ledger();"');
