@@ -22,8 +22,7 @@
  * \brief Contains all the variable + the javascript
  * and some parameter
  */
-require_once ('config.inc.php');
-require_once('constant.security.php');
+
 // SVNVERSION
 global $version_noalyss;
 /*
@@ -31,6 +30,22 @@ global $version_noalyss;
  */
 $inc_path=get_include_path();
 $dirname=dirname(__FILE__);
+
+/* Global variable of the include dir */
+global $g_include_dir,$g_ext_dir,$g_template_dir;
+$g_include_dir=$dirname;
+$g_ext_dir = $dirname."/ext";
+$g_template_dir = $dirname."/template";
+
+if (file_exists($dirname.'/config.inc.php')) require_once $dirname.'/config.inc.php';
+
+if ( !defined("NOALYSS_HOME")) define ("NOALYSS_HOME",dirname($dirname)."/html");
+if ( !defined("NOALYSS_PLUGIN")) define ("NOALYSS_PLUGIN",$g_ext_dir);
+if ( !defined("NOALYSS_INCLUDE")) define ("NOALYSS_INCLUDE",$g_include_dir);
+if ( !defined("NOALYSS_TEMPLATE")) define ("NOALYSS_TEMPLATE",$g_template_dir);
+
+require_once NOALYSS_INCLUDE.'/constant.security.php';
+
 if ( strpos($inc_path,";") != 0 ) {
   $new_path=$inc_path.';'.$dirname;
   $os=0;			/* $os is 0 for windoz */
@@ -53,38 +68,42 @@ ini_set ('default_charset',"UTF-8");
  */
 
 
-
 global $g_captcha,$g_failed,$g_succeed;
 $g_captcha=false;
 $g_failed="<span style=\"font-size:18px;color:red\">&#x2716;</span>";
 $g_succeed="<span style=\"font-size:18px;color:green\">&#x2713;</span>";
+define ('SMALLX','&#x2D5D;');
+define ('BUTTONADD',"&#10010;");
+
 /* uncomment for development */
 
-/*
- define ('SVNINFO',6800);
-define ("DEBUG",true);
-define ("LOGINPUT",true);
- */
+// define ('SVNINFO',6800);
+//define ("DEBUG",true);
+//define ("LOGINPUT",true);
 
 
 
-define ('SVNINFO',6800);
-define ("DEBUG",false);
-define ("LOGINPUT",false);
-
+define ('SVNINFO',6900);
+if ( ! defined  ('DEBUG')) {
+    define ("DEBUG",false);
+}
+if ( ! defined ('LOGINPUT')) {
+    define ("LOGINPUT",false);
+}
 
 $version_noalyss=SVNINFO;
+
 // If you don't want to be notified of the update
-// define ("SITE_UPDATE",'');
-define ("SITE_UPDATE",'http://www.noalyss.eu/last_version.txt');
-define ("SITE_UPDATE_PLUGIN",'http://www.noalyss.eu/plugin_last_version.txt');
+if ( !defined("SITE_UPDATE"))
+    define ("SITE_UPDATE",'http://www.noalyss.eu/last_version.txt');
+if ( !defined("SITE_UPDATE_PLUGIN"))
+    define ("SITE_UPDATE_PLUGIN",'http://www.noalyss.eu/plugin_last_version.txt');
 
 
-define ("DBVERSION",117);
+define ("DBVERSION",121);
 define ("MONO_DATABASE",25);
-define ("DBVERSIONREPO",15);
+define ("DBVERSIONREPO",16);
 define ('NOTFOUND','--not found--');
-
 define ("MAX_COMPTE",4);
 define ('MAX_ARTICLE',5);
 define ('MAX_ARTICLE_STOCK',20);
@@ -98,17 +117,24 @@ define ('COMPTA_MIN_YEAR',1900);
 define ('MAX_RECONCILE',25);
 define ('MAX_QCODE',4);
 define ('MAX_SEARCH_CARD',20);
+define ('MAX_FOLDER_TO_SHOW',20);
+define ('MAX_ACTION_SHOW',20);
 
 if ( DEBUG ) {
 	error_reporting(2147483647);
 	ini_set("display_errors",1);
+	ini_set("display_startup_errors",1);
 	ini_set("html_errors",1);
+        ini_set('log_errors',1);
+        ini_set('log_errors_max_len',0);
 }
-	else {
-	error_reporting(0);
-	ini_set("display_errors",1);
-	ini_set("html_errors",1);
-        
+else {
+        // Rapporte les erreurs d'exécution de script
+        error_reporting(E_ERROR | E_WARNING | E_PARSE|E_NOTICE);
+        ini_set("display_errors",0);
+	ini_set("html_errors",0);
+        ini_set('log_errors',1);
+        ini_set('log_errors_max_len',0);
 }
 // Erreur
 define ("NOERROR",0);
