@@ -21,8 +21,13 @@
 define ('FICADD',800);	 /* Ajout de fiche */
 define ("FIC",805);  //Création, modification et effacement de fiche
 define ("FICCAT",910);  //création, modification et effacement de catégorie de fiche
-define ('RMDOC',1020);   // Effacement de document pour follow up
+define ('RMDOC',1020);   // Effacement de document pour follow up & comptabilité
 define ('VIEWDOC',1010);   // Voir document pour follow up
 define ('PARCATDOC',1050);   // modifier type document pour follow up
+define ('RMRECEIPT',1110);   // Effacer un document d'une pièce comptable
+define ('RMOPER',1120);   // Effacer une opération comptable
+define ('SHARENOTE',1210); // Can share a note
+define ('SHARENOTEPUBLIC',1230); // Can create public note
+define ('SHARENOTEREMOVE',1240); // Can drop drop of other
 global $audit; $audit=false;
 ?>
