@@ -21,11 +21,11 @@
  * the contact category
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_iselect.php");
-require_once("class_ihidden.php");
-require_once("class_contact.php");
-require_once("class_ibutton.php");
-require_once('class_fiche_def.php');
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_contact.php';
+require_once NOALYSS_INCLUDE.'/class_ibutton.php';
+require_once NOALYSS_INCLUDE.'/class_fiche_def.php';
 
 
 
@@ -43,19 +43,23 @@ if ($low_action == "")
 //-----------------------------------------------------
 // Remove a card
 //-----------------------------------------------------
-if (isset($_POST['delete_card']))
+if (isset($_POST['action_fiche']))
 {
-    if ($g_user->check_action(FICADD) == 0)
+    
+    if ( $_POST['action_fiche'] == 'delete_card') 
     {
-	alert(j(_('Vous  ne pouvez pas enlever de fiche')));
-	return;
+        if ( $g_user->check_action(FICADD) == 0 )
+        {
+            alert(_('Vous  ne pouvez pas enlever de fiche'));
+            return;
+        }
+
+        $f_id = $_REQUEST['f_id'];
+
+        $fiche = new Contact($cn, $f_id);
+        $fiche->remove();
+        $low_action = "list";
     }
-
-    $f_id = $_REQUEST['f_id'];
-
-    $fiche = new Contact($cn, $f_id);
-    $fiche->remove();
-    $low_action = "list";
 }
 
 //-----------------------------------------------------
@@ -146,7 +150,7 @@ if ($low_action == "list")
 if ( $low_action == 'detail')
 {
     /* Menu */
-    require_once('category_card.inc.php');
+    require_once NOALYSS_INCLUDE.'/category_card.inc.php';
     return;
 }
 
