@@ -22,11 +22,11 @@
  * the customer category
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_iselect.php");
-require_once("class_ihidden.php");
-require_once("class_customer.php");
-require_once("class_ibutton.php");
-require_once('class_fiche_def.php');
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_customer.php';
+require_once NOALYSS_INCLUDE.'/class_ibutton.php';
+require_once NOALYSS_INCLUDE.'/class_fiche_def.php';
 
 
 
@@ -44,19 +44,22 @@ if ($low_action == "")
 //-----------------------------------------------------
 // Remove a card
 //-----------------------------------------------------
-if (isset($_POST['delete_card']))
+if (isset($_POST['action_fiche']))
 {
-    if ($g_user->check_action(FICADD) == 0)
+     if ( $_POST['action_fiche'] == 'delete_card') 
     {
-	alert(j(_('Vous  ne pouvez pas enlever de fiche')));
-	return;
+        if ($g_user->check_action(FICADD) == 0)
+        {
+            alert(j(_('Vous  ne pouvez pas enlever de fiche')));
+            return;
+        }
+
+        $f_id = $_REQUEST['f_id'];
+
+        $fiche = new Customer($cn, $f_id);
+        $fiche->remove();
+        $low_action = "list";
     }
-
-    $f_id = $_REQUEST['f_id'];
-
-    $fiche = new Customer($cn, $f_id);
-    $fiche->remove();
-    $low_action = "list";
 }
 
 //-----------------------------------------------------
@@ -68,23 +71,34 @@ if ($low_action == "list")
     <div class="content">
         <div>
     	<form method="get" action="<?php echo $href;?>">
-		<?php
-		echo '<h2>' . "Exercice " . $g_user->get_exercice() . '</h2>';
-		echo dossier::hidden();
-		$a = (isset($_GET['query'])) ? $_GET['query'] : "";
-		printf(_('Recherche') . ' <input class="input_text" type="text" name="query" value="%s">', $a);
-		$sel_card = new ISelect('cat');
-		$sel_card->value = $cn->make_array('select fd_id, fd_label from fiche_def ' .
-			' where  frd_id=' . FICHE_TYPE_CLIENT .
-			' order by fd_label ', 1);
-		$sel_card->selected = (isset($_GET['cat'])) ? $_GET['cat'] : -1;
-		$sel_card->javascript = ' onchange="submit(this);"';
-		echo _('Catégorie :') . $sel_card->input();
-		$nooperation = new ICheckBox('noop');
-		$nooperation->selected = (isset($_GET['noop'])) ? true : false;
+            <?php
+            echo '<h2>' . "Exercice " . $g_user->get_exercice() . '</h2>';
+            $a=(isset($_GET['query']))?$_GET['query']:"";
+            printf (_('Recherche').' <input class="input_text" type="text" name="query" value="%s">',
+             $a);
+            $choice_cat=HtmlInput::default_value_request("choice_cat", 1);
 
-		echo _('Inclure les clients sans opération :') . $nooperation->input();
-		?>
+            if ( $choice_cat == 1 )
+            {
+                $sel_card=new ISelect('cat');
+                $sel_card->value=$cn->make_array('select fd_id, fd_label from fiche_def '.
+                                                 ' where  frd_id='.FICHE_TYPE_CLIENT.
+                                                 ' order by fd_label ',1);
+                $sel_card->selected=(isset($_GET['cat']))?$_GET['cat']:-1;
+                $sel_card->javascript=' onchange="submit(this);"';
+                echo _('Catégorie :').$sel_card->input();
+            } else 
+            {
+                $cat=HtmlInput::default_value_request('cat', '');
+                echo HtmlInput::hidden("cat",$cat);
+                echo HtmlInput::hidden('choice_cat', 0);
+            }
+            $nooperation = new ICheckBox('noop');
+            $nooperation->selected = (isset($_GET['noop'])) ? true : false;
+            echo Dossier::hidden();
+
+            echo _('Inclure les clients sans opération :') . $nooperation->input();
+            ?>
     	    <input type="submit" class="button" name="submit_query" value="<?php echo  _('recherche')?>">
     	    <input type="hidden" name="ac" value="<?php echo  $_REQUEST['ac']?>">
     	</form>
@@ -100,7 +114,7 @@ if ($low_action == "list")
 	}
 	$noop = (isset($_GET['noop'])) ? false : true;
 	echo '<div class="content">';
-	echo $client->Summary($search, 'client', $sql, $noop);
+	echo $client->Summary($search, 'customer', $sql, $noop);
 
 
 	echo '<br>';
@@ -136,7 +150,7 @@ if ($low_action == "list")
 if ( $low_action == 'detail')
 {
     /* Menu */
-    require_once('category_card.inc.php');
+    require_once NOALYSS_INCLUDE.'/category_card.inc.php';
     return;
 }
 
