@@ -27,7 +27,7 @@ if (!defined('ALLOWED'))
 /**
  * export all the selected documents for Ana Accountancy in PDF
  */
-require_once 'class_document_export.php';
+require_once NOALYSS_INCLUDE.'/class_document_export.php';
 
 $ck = HtmlInput::default_value_get('ck', 0);
 if ($ck == 0)
