@@ -21,15 +21,15 @@
  * \brief Send the poste list in csv
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-include_once("ac_common.php");
-require_once('class_database.php');
-require_once("class_acc_account_ledger.php");
-require_once ('class_acc_operation.php');
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_acc_account_ledger.php';
+require_once  NOALYSS_INCLUDE.'/class_acc_operation.php';
 $fDate=date('dmy-Hi');
 header('Pragma: public');
 header('Content-type: application/csv');
 header('Content-Disposition: attachment;filename="poste-'.$fDate.'-'.$_REQUEST['poste_id'].'.csv"',FALSE);
-require_once('class_dossier.php');
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
 $gDossier=dossier::id();
 
 /* Admin. Dossier */
