@@ -3,16 +3,16 @@
 //see licence.txt
 
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once('class_database.php');
-require_once('class_dossier.php');
-require_once("ac_common.php");
-require_once("constant.php");
-require_once('function_javascript.php');
-require_once('class_extension.php');
-require_once ('class_html_input.php');
-require_once('class_iselect.php');
-require_once ('constant.security.php');
-require_once ('class_user.php');
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/constant.php';
+require_once NOALYSS_INCLUDE.'/function_javascript.php';
+require_once NOALYSS_INCLUDE.'/class_extension.php';
+require_once  NOALYSS_INCLUDE.'/class_html_input.php';
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once  NOALYSS_INCLUDE.'/constant.security.php';
+require_once  NOALYSS_INCLUDE.'/class_user.php';
 echo '<div class="topmenu">';
 @html_page_start($_SESSION['g_theme']);
 
@@ -56,5 +56,5 @@ echo '</div>';
 }*/
 
 //if ( isset($_REQUEST['plugin_code']))
-//	require_once 'extension_get.inc.php';
+//	require_once NOALYSS_INCLUDE.'/extension_get.inc.php';
 ?>
