@@ -22,9 +22,9 @@
  * \brief printing of category of card  : balance, historic
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-include_once('class_database.php');
-include_once('class_fiche.php');
-require_once('class_lettering.php');
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_fiche.php';
+require_once NOALYSS_INCLUDE.'/class_lettering.php';
 
 $gDossier = dossier::id();
 $cn = new Database($gDossier);
@@ -67,6 +67,8 @@ $histo->value = array(
 	array('value' => 2, 'label' => _('Historique non Lettré')),
 	array('value' => 3, 'label' => _('Résumé')),
 	array('value' => 4, 'label' => _('Balance')),
+	array('value' => 6, 'label' => _('Balance âgée')),
+	array('value' => 7, 'label' => _('Balance âgée en-cours')),
 	array('value' => 5, 'label' => _('Balance non soldée'))
 );
 $histo->javascript = 'onchange="if (this.value==3 || this.value==-1) {
@@ -79,7 +81,7 @@ echo '<div class="content">';
 echo '<FORM method="GET">';
 echo dossier::hidden();
 echo HtmlInput::hidden('ac', $_GET['ac']);
-require_once('template/impress_cat_card.php');
+require_once NOALYSS_INCLUDE.'/template/impress_cat_card.php';
 echo HtmlInput::submit('cat_display', _('Recherche'));
 echo '</FORM>';
 $search_card=new IText('card_search');
@@ -133,6 +135,7 @@ if ( $allcard == 0 ){
 	echo h1($fiche_def->label,"");
 	echo h2($fiche_def->fd_description,"");
 }
+echo '<div class="content">';
 /* * *********************************************************************************************************************************
  * Liste
  *
@@ -151,7 +154,7 @@ if ($_GET['histo'] == -1)
 			/**
 			 * Move
 			 */
-			if (isset($_POST['move']))
+			if (isset($_POST['move'])&& $_POST['move'] == 1)
 			{
 				for ($i = 0; $i < count($ack); $i++)
 				{
@@ -162,7 +165,7 @@ if ($_GET['histo'] == -1)
 			/**
 			 * Delete
 			 */
-			if (isset($_POST['delete']))
+			if (isset($_POST['delete'])&& $_POST['delete']==1)
 			{
 				$msg="";
 				for ($i = 0; $i < count($ack); $i++)
@@ -215,8 +218,7 @@ if ($_GET['histo'] == -1)
 	");
 	$nb_line = Database::num_row($res);
 	if ($write != 1 || $allcard != 0 )  $str_add_card="";
-
-	require_once 'template/fiche_list.php';
+	require_once NOALYSS_INCLUDE.'/template/fiche_list.php';
 	echo '<hr>'.$bar;
 	return;
 }
@@ -230,7 +232,7 @@ if ($_GET['histo'] == 3)
 	$cat_card->id = $_GET['cat'];
 	$aHeading = $cat_card->getAttribut();
 	if ( $allcard == 0) echo $str_add_card;
-	require_once('template/result_cat_card_summary.php');
+	require_once NOALYSS_INCLUDE.'/template/result_cat_card_summary.php';
 
 	$hid = new IHidden();
 	echo '<form method="GET" ACTION="export.php">' . dossier::hidden() .
@@ -266,19 +268,93 @@ $export_csv.=HtmlInput::request_to_hidden(array('allcard'));
 $export_csv.=dossier::hidden();
 $export_csv.=HtmlInput::submit('CSV', 'Export en CSV');
 $export_csv.='</FORM>';
-
+/*
+ * Date is important is requested balance
+ */
+if (isDate($_REQUEST['start']) == null || isDate($_REQUEST['end']) == null)
+{
+	echo h2('Date invalide !', 'class="error"');
+	alert('Date invalide !');
+	return;
+}
+/*************************************************************************************************************************
+ * Balance agée tous
+/*************************************************************************************************************************/
+if ( $_GET['histo'] == 6)
+{
+    require_once NOALYSS_INCLUDE.'/class_balance_age.php';
+    $bal=new Balance_Age($cn);
+    $export_csv = '<FORM METHOD="get" ACTION="export.php" style="display:inline">';
+    $export_csv .=HtmlInput::request_to_hidden(array('gDossier','ac','p_let','p_date_start'));
+    $export_csv.=HtmlInput::hidden('p_date_start', $_GET['start']);
+    $export_csv .= HtmlInput::hidden('act','CSV:balance_age');
+    $export_csv .= HtmlInput::hidden('p_let','let');
+    $export_csv .= HtmlInput::hidden('p_type','X');
+    $export_csv .= HtmlInput::hidden('cat',$_GET['cat']);
+    $export_csv .= HtmlInput::hidden('all',$allcard);
+    $export_csv .= HtmlInput::submit('csv',_('Export CSV'));
+    $export_csv.='</FORM><p></p>';
+    if ( $allcard == 0 )
+    {
+        echo $export_csv;
+        $bal->display_category($_GET['start'],$_GET['cat'],'let');
+        echo $export_csv;
+    }    
+    else
+    {
+        echo $export_csv;
+        $a_cat = $cn->get_array("select fd_id from vw_fiche_def where ad_id=" . ATTR_DEF_ACCOUNT . " order by fd_label asc");
+        $nb_cat=count($a_cat);
+        for ($i=0;$i < $nb_cat;$i++)
+        {
+             $bal->display_category($_GET['start'],$a_cat[$i]['fd_id'],'let');
+        }
+        echo $export_csv;
+    }
+    return;
+}
+/*************************************************************************************************************************
+ * Balance en-cours
+/*************************************************************************************************************************/
+if ( $_GET['histo'] == 7)
+{
+    require_once NOALYSS_INCLUDE.'/class_balance_age.php';
+    $bal=new Balance_Age($cn);
+       $export_csv = '<FORM METHOD="get" ACTION="export.php" style="display:inline">';
+    $export_csv .=HtmlInput::request_to_hidden(array('gDossier','ac','p_let','p_date_start'));
+    $export_csv.=HtmlInput::hidden('p_date_start', $_GET['start']);
+    $export_csv .= HtmlInput::hidden('act','CSV:balance_age');
+    $export_csv .= HtmlInput::hidden('p_let','unlet');
+    $export_csv .= HtmlInput::hidden('p_type','X');
+    $export_csv .= HtmlInput::hidden('cat',$_GET['cat']);
+    $export_csv .= HtmlInput::hidden('all',$allcard);
+    $export_csv .= HtmlInput::submit('csv',_('Export CSV'));
+    $export_csv.='</FORM><p></p>';
+    if ( $allcard == 0 )
+    {
+        echo $export_csv;
+        $bal->display_category($_GET['start'],$_GET['cat'],'unlet');
+        echo $export_csv;
+    }
+      else
+    {
+        echo $export_csv;
+        $a_cat = $cn->get_array("select fd_id from vw_fiche_def where ad_id=" . ATTR_DEF_ACCOUNT . " order by fd_label asc");
+        $nb_cat=count($a_cat);
+        for ($i=0;$i < $nb_cat;$i++)
+        {
+             $bal->display_category($_GET['start'],$a_cat[$i]['fd_id'],'unlet');
+        }
+        echo $export_csv;
+    }
+    return;
+}
 /********************************************************************************************************************************
  * Balance
  *
  **********************************************************************************************************************************/
 if ($_GET['histo'] == 4 || $_GET['histo'] == 5)
 {
-	if (isDate($_REQUEST['start']) == null || isDate($_REQUEST['end']) == null)
-	{
-		echo h2(_('Date invalide !'), 'class="error"');
-		alert(_('Date invalide !'));
-		return;
-	}
 	if ( $allcard == 0 ) echo $str_add_card;
 	echo $export_pdf;
 	echo $export_csv;
@@ -350,7 +426,7 @@ if ($_GET['histo'] == 4 || $_GET['histo'] == 5)
 					td(nbm($solde['debit']), 'class="sorttable_numeric" sorttable_customkey="'.$solde['debit'].'" style="text-align:right"') .
 					td(nbm($solde['credit']), 'class="sorttable_numeric" sorttable_customkey="'.$solde['debit'].'" style="text-align:right"') .
 					td(nbm(abs($solde['solde'])), 'class="sorttable_numeric" sorttable_customkey="'.$solde['solde'].'" style="text-align:right"') .
-					td((($solde['debit'] < $solde['credit']) ? 'CRED' : 'DEB'), 'style="text-align:right"'), $class
+					td((($solde['debit'] < $solde['credit']) ? 'C' : 'D'), 'style="text-align:right"'), $class
 			);
 
 
@@ -364,7 +440,7 @@ if ($_GET['histo'] == 4 || $_GET['histo'] == 5)
                                 td(nbm($sum_deb), 'style="text-align:right"').
                                 td(nbm($sum_cred), 'style="text-align:right"').
                                 td(nbm(abs($sum_solde)), 'style="text-align:right"').
-                                td((($sum_deb < $sum_cred) ? 'CRED' : 'DEB'), 'style="text-align:right"'),' class="highlight"');
+                                td((($sum_deb < $sum_cred) ? 'C' : 'D'), 'style="text-align:right"'),' class="highlight"');
                 echo '</tfoot>';
 		echo '</table>';
 	}
@@ -375,12 +451,7 @@ if ($_GET['histo'] == 4 || $_GET['histo'] == 5)
 
 	return;
 }
-if (isDate($_REQUEST['start']) == null || isDate($_REQUEST['end']) == null)
-{
-	echo h2('Date invalide !', 'class="error"');
-	alert('Date invalide !');
-	return;
-}
+
 /***********************************************************************************************************************************
  * Lettering
  *
@@ -506,13 +577,18 @@ for ($e = 0; $e < count($afiche); $e++)
 		echo td(_('Credit'));
 		echo td(nbm($amount_cred), ' style="font-weight:bold;text-align:right"');
 		echo '</tr>';
-		echo '<tr>';
-		if ($amount_deb > $amount_cred)
+		echo '<tr class="highlight">';
+                $solde=abs(round($amount_cred - $amount_deb, 2));
+                if ( $solde == 0)
+                {
+                    $s='solde';
+                }
+                else if ($amount_deb > $amount_cred)
 			$s = 'solde débiteur';
 		else
 			$s = 'solde crediteur';
 		echo td($s);
-		echo td(nbm(abs(round($amount_cred - $amount_deb, 2))), ' style="font-weight:bold;text-align:right"');
+		echo td(nbm($solde), ' style="font-weight:bold;text-align:right"');
 		echo '</tr>';
 		echo '</table>';
 	}
