@@ -24,7 +24,7 @@ function js_include($p_string)
 
     if ( !  file_exists('js/'.$p_string))
         alert("Erreur js/$p_string n existe pas");
-    $script='<script type="text/javascript" charset="utf-8" language="javascript" src="js/'.$p_string.'"></script>';
+    $script='<script type="text/javascript" charset="utf-8" language="javascript" src="js/'.$p_string.'?version='.SVNINFO.'"></script>';
     // debug
 
     return $script;
@@ -2746,7 +2746,8 @@ function unescape_xml($p_xml)
     return $xml;
 }
 /**
- *load all the javascript in once
+ *load all the javascript only one time
+ * 
  */
 function load_all_script()
 {
@@ -2756,23 +2757,23 @@ function load_all_script()
     $already_call=1;
 
     echo JS_INFOBULLE;
+    echo js_include('smoke.js');
     echo js_include('prototype.js');
     echo js_include('scriptaculous.js');
     echo js_include('scripts.js');
-    echo js_include('effects.js');
-    echo js_include('dragdrop.js');
-    echo js_include('controls.js');
-    echo js_include('slider.js');
+   // echo js_include('effects.js');
+   // echo js_include('dragdrop.js');
+   // echo js_include('controls.js');
+   // echo js_include('slider.js');
     echo js_include('acc_ledger.js');
     echo js_include('accounting_item.js');
     echo js_include('ajax_fiche.js');
     echo js_include('anc_script.js');
-    echo js_include('builder.js');
+   // echo js_include('builder.js');
     echo js_include('calc.js');
     echo js_include('card.js');
     echo js_include('compute_direct.js');
     echo js_include('compute.js');
-    echo js_include('confirm.js');
     echo js_include('forecast.js');
     echo js_include('gestion.js');
     echo js_include('todo_list.js');
