@@ -17,8 +17,8 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once ('class_acc_bilan.php');
-require_once('class_exercice.php');
+require_once  NOALYSS_INCLUDE.'/class_acc_bilan.php';
+require_once NOALYSS_INCLUDE.'/class_exercice.php';
 
 //ini_set("memory_limit","150M");
 /*! \file
@@ -31,7 +31,7 @@ require_once('class_exercice.php');
 //-----------------------------------------------------
 // Show the jrn and date
 //-----------------------------------------------------
-require_once('class_database.php');
+require_once NOALYSS_INCLUDE.'/class_database.php';
 global $g_user;
 //-----------------------------------------------------
 // Form
@@ -84,7 +84,7 @@ if ( isset($_GET['verif']))
     $bilan->get_request_get();
     $bilan->verify();
     $url_verify=http_build_query(array('ac'=>'VERIFBIL','gDossier'=>dossier::id()));
-    echo _('Pour une vérification complète, allez dans ').'<a class="line" href="?'.$url_verify.'"> VERIFBIL</a>';
+    echo _('Pour une vérification complète, allez dans ').'<a class="line" TARGET="_blank" href="?'.$url_verify.'"> VERIFBIL</a>';
     echo '<FORM METHOD="GET" ACTION="export.php">';
     echo dossier::hidden();
     echo HtmlInput::get_to_hidden(array('exercice'));
