@@ -18,11 +18,11 @@
 */
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_ispan.php");
-require_once("class_icard.php");
-require_once("class_iselect.php");
-require_once("class_icheckbox.php");
-require_once('class_acc_operation.php');
+require_once NOALYSS_INCLUDE.'/class_ispan.php';
+require_once NOALYSS_INCLUDE.'/class_icard.php';
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_icheckbox.php';
+require_once NOALYSS_INCLUDE.'/class_acc_operation.php';
 /*! \file
  * \brief Print account (html or pdf)
  *        file included from user_impress
@@ -33,17 +33,10 @@ require_once('class_acc_operation.php');
 //-----------------------------------------------------
 // Show the jrn and date
 //-----------------------------------------------------
-require_once('class_database.php');
-require_once('class_ipopup.php');
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_ipopup.php';
 global $g_user;
 
-echo IPoste::ipopup('ipop_account');
-echo ICard::ipopup('ipopcard');
-$search_card=new IPopup('ipop_card');
-$search_card->title=_('Recherche de fiche');
-$search_card->value='';
-echo $search_card->input();
-
 //-----------------------------------------------------
 // Form
 //-----------------------------------------------------
@@ -133,10 +126,10 @@ if ( isset( $_REQUEST['bt_html'] ) )
 {
     if ( isDate($_REQUEST['from_periode'])==null || isDate($_REQUEST['to_periode'])==null)
     {
-        echo alert('Date malformée, désolée');
+        echo alert(_('Date malformée, désolée'));
         return;
     }
-    require_once("class_acc_account_ledger.php");
+    require_once NOALYSS_INCLUDE.'/class_acc_account_ledger.php';
     $go=0;
 // we ask a poste_id
     if ( isset($_GET['poste_id']) && strlen(trim($_GET['poste_id'])) != 0 )
@@ -156,7 +149,7 @@ if ( isset( $_REQUEST['bt_html'] ) )
     }
     if ( strlen(trim($_GET['f_id'])) != 0 )
     {
-        require_once("class_fiche.php");
+        require_once NOALYSS_INCLUDE.'/class_fiche.php';
         // thanks the qcode we found the poste account
         $fiche=new Fiche($cn);
         $qcode=$fiche->get_by_qcode($_GET['f_id']);
@@ -190,7 +183,7 @@ if ( isset( $_REQUEST['bt_html'] ) )
             if ( empty($Poste->row)) return;
             $Poste->load();
 
-            echo '<table class="result"  style="width:80%;margin-left:10%">';
+            echo '<table class="result" >';
             echo '<tr><td  class="mtitle" style="width:auto" colspan="6"><h2 class="info">'. $_GET['poste_id'].' '.h($Poste->label).'</h2></td></tr>';
             /* avoid duplicates */
             $old=array();
@@ -198,7 +191,7 @@ if ( isset( $_REQUEST['bt_html'] ) )
             {
                 if ( in_array($detail['jr_id'],$old) == TRUE ) continue;
                 $old[]=$detail['jr_id'];
-                echo '<tr><td class="mtitle" style="width:auto" colspan="6">'.$detail['j_date'].' '.$detail['jr_internal'].h($detail['description']).'</td></tr>';
+                echo '<tr><td style="text-align:center;background-color:lightgrey" colspan="6">'.$detail['j_date'].' '.$detail['jr_internal'].h($detail['description']).'</td></tr>';
 
                 $op=new Acc_Operation($cn);
                 $op->jr_id=$detail['jr_id'];
