@@ -24,7 +24,7 @@
  */
 
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once('class_lettering.php');
+require_once NOALYSS_INCLUDE.'/class_lettering.php';
 
 echo '<div class="content">';
 echo '<div id="search">';
