@@ -22,14 +22,14 @@
  */
 if (!defined('ALLOWED'))
     die('Appel direct ne sont pas permis');
-require_once("class_iselect.php");
-require_once("class_ihidden.php");
-require_once("class_manager.php");
-require_once("class_ibutton.php");
-require_once('class_iaction.php');
-require_once('class_fiche_def.php');
-require_once('class_iaction.php');
-require_once('class_fiche_def.php');
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_manager.php';
+require_once NOALYSS_INCLUDE.'/class_ibutton.php';
+require_once NOALYSS_INCLUDE.'/class_iaction.php';
+require_once NOALYSS_INCLUDE.'/class_fiche_def.php';
+require_once NOALYSS_INCLUDE.'/class_iaction.php';
+require_once NOALYSS_INCLUDE.'/class_fiche_def.php';
 
 global $g_user;
 
@@ -47,19 +47,22 @@ if ($low_action == "")
 //-----------------------------------------------------
 // Remove a card
 //-----------------------------------------------------
-if (isset($_POST['delete_card']))
+if (isset($_POST['action_fiche']))
 {
-    if ($g_user->check_action(FICADD) == 0)
+     if ( $_POST['action_fiche'] == 'delete_card') 
     {
-        alert('Vous  ne pouvez pas enlever de fiche');
-        return;
+        if ($g_user->check_action(FICADD) == 0)
+        {
+            alert(_('Vous  ne pouvez pas enlever de fiche'));
+            return;
+        }
+
+        $f_id = $_REQUEST['f_id'];
+
+        $fiche = new Manager($cn, $f_id);
+        $fiche->remove();
+        $low_action = "list";
     }
-
-    $f_id = $_REQUEST['f_id'];
-
-    $fiche = new Manager($cn, $f_id);
-    $fiche->remove();
-    $low_action = "list";
 }
 
 //-----------------------------------------------------
@@ -76,13 +79,24 @@ if ($low_action == "list")
                 echo dossier::hidden();
                 $a = (isset($_GET['query'])) ? $_GET['query'] : "";
                 printf(_('Recherche') . ' <input class="input_text" type="text" name="query" value="%s">', $a);
-                $sel_card = new ISelect('cat');
-                $sel_card->value = $cn->make_array('select fd_id, fd_label from fiche_def ' .
-                        ' where  frd_id=' . FICHE_TYPE_EMPL .
-                        ' order by fd_label ', 1);
-                $sel_card->selected = (isset($_GET['cat'])) ? $_GET['cat'] : -1;
-                $sel_card->javascript = ' onchange="submit(this);"';
-                echo _('Catégorie :') . $sel_card->input();
+                echo HtmlInput::request_to_hidden(array('ac'));
+                $choice_cat=HtmlInput::default_value_request("choice_cat", 1);
+                if ( $choice_cat == 1 )
+                {
+                    $sel_card = new ISelect('cat');
+                    $sel_card->value = $cn->make_array('select fd_id, fd_label from fiche_def ' .
+                            ' where  frd_id=' . FICHE_TYPE_EMPL .
+                            ' order by fd_label ', 1);
+                    $sel_card->selected = (isset($_GET['cat'])) ? $_GET['cat'] : -1;
+                    $sel_card->javascript = ' onchange="submit(this);"';
+                    echo _('Catégorie :') . $sel_card->input();
+                }
+                else
+                {
+                    $cat=HtmlInput::default_value_request('cat', '');
+                    echo HtmlInput::hidden("cat",$cat);
+                    echo HtmlInput::hidden('choice_cat', 0);
+                }
                 $nooperation = new ICheckBox('noop');
                 $nooperation->selected = (isset($_GET['noop'])) ? true : false;
                 echo _('Inclure les employés sans opération :') . $nooperation->input();
@@ -138,7 +152,7 @@ if ($low_action == "list")
 if ($low_action == 'detail')
 {
     /* Menu */
-    require_once('category_card.inc.php');
+    require_once NOALYSS_INCLUDE.'/category_card.inc.php';
     return;
 }
 
