@@ -27,9 +27,9 @@
  *
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once 'class_menu_ref.php';
-require_once 'class_sort_table.php';
-require_once 'class_extension.php';
+require_once NOALYSS_INCLUDE.'/class_menu_ref.php';
+require_once NOALYSS_INCLUDE.'/class_sort_table.php';
+require_once NOALYSS_INCLUDE.'/class_extension.php';
 
 
 echo '<div class="content">';
@@ -46,7 +46,6 @@ if ( isset($_POST['save_plugin']))
 	$plugin->me_description=$me_description;
 	$plugin->me_parameter='plugin_code='.$me_code;
 	$plugin->insert_plugin();
-        $plugin->insert_profile_module();
 }
 /**
  * if post update then we update
@@ -55,11 +54,11 @@ if (isset($_POST['mod_plugin']))
 {
 	extract ($_POST);
 	$plugin=new Extension($cn);
-	$plugin->me_code=$me_code;
+	$plugin->me_code=strtoupper($me_code);
 	$plugin->me_menu=$me_menu;
 	$plugin->me_file=$me_file;
 	$plugin->me_description=$me_description;
-	$plugin->me_parameter='plugin_code='.$me_code;
+	$plugin->me_parameter='plugin_code='.strtoupper($me_code);
 	if ( !isset ($delete_pl))
 	{
 		$plugin->update_plugin();
@@ -76,7 +75,7 @@ if ( isset($_POST['create_menu'])|| isset($_POST['modify_menu']))
 {
 	extract($_POST);
 	$menu_ref=new Menu_Ref($cn);
-	$menu_ref->me_code=$me_code;
+	$menu_ref->me_code=strtoupper($me_code);
 	$menu_ref->me_menu=$me_menu;
 	$menu_ref->me_file=$me_file;
 	$menu_ref->me_description=$me_description;
@@ -98,10 +97,6 @@ if ( isset($_POST['create_menu'])|| isset($_POST['modify_menu']))
 		}
 	}
 }
-/**
- * if delete then delete
- */
-
 //////////////////////////////////////////////////////////////////////////////
 // Show the list of menu
 //////////////////////////////////////////////////////////////////////////////
@@ -142,7 +137,7 @@ if ( $iselect->selected != '')
 $menu=new Menu_Ref_sql($cn);
 $ret=$menu->seek($sql.$order);
 ?>
-<fieldset><legend>Recherche</legend>
+<fieldset><legend><?php echo _('Recherche')?></legend>
 <form method="GET">
 	<?php echo $iselect->input()?>
 	<?php echo HtmlInput::submit("search", _("Recherche"))?>
