@@ -27,9 +27,9 @@
  *
  */
 if ( !defined ('ALLOWED')) die('Forbidden');
-require_once("class_itext.php");
-require_once("class_icheckbox.php");
-require_once ('class_extension.php');
+require_once NOALYSS_INCLUDE.'/class_itext.php';
+require_once NOALYSS_INCLUDE.'/class_icheckbox.php';
+require_once  NOALYSS_INCLUDE.'/class_extension.php';
 
 $sa = (isset($_REQUEST['sa'])) ? $_REQUEST['sa'] : 'list';
 if (isset($_POST['upd']) &&
@@ -64,12 +64,12 @@ if (isset($_POST["FMOD_NAME"]))
 
 	if ($encoding != 6)
 	{
-		alert('Désolé vous devez migrer ce modèle en unicode');
-		echo '<span class="error">la base de donnée ' .
-		domaine . 'mod' . $_POST["FMOD_DBID"] . " doit être migrée en unicode</span>";
-		echo '<span class="error"> Pour le passer en unicode, faites-en un backup puis restaurez le fichier reçu</span>';
+		alert(_('Désolé vous devez migrer ce modèle en unicode'));
+		echo '<span class="error">'._('la base de donnée')." " .
+		domaine . 'mod' . $_POST["FMOD_DBID"]." " . _("doit être migrée en unicode")."</span>";
+		echo '<span class="error"> '._("Pour le passer en unicode, faites-en un backup puis restaurez le fichier reçu").'</span>';
 
-		echo HtmlInput::button_anchor('Retour', 'admin_repo.php?action=dossier_mgt');
+		echo HtmlInput::button_anchor(_('Retour'), 'admin_repo.php?action=dossier_mgt');
 		return;
 	}
 
@@ -90,7 +90,7 @@ if (isset($_POST["FMOD_NAME"]))
 			if ($cn->exec_sql($Sql) == false)
 			{
 				ob_end_clean();
-				echo "<h2 class=\"error\"> Base de donn&eacute;e " . domaine . "dossier" . $_POST['FMOD_DBID'] . "  est accèd&eacute;e, d&eacute;connectez-vous en d'abord</h2>";
+				echo "<h2 class=\"error\"> Base de donn&eacute;e " . domaine . "dossier" . $_POST['FMOD_DBID'] . "  "._("est accèd&eacute;e, d&eacute;connectez-vous en d'abord")."</h2>";
 				$Res = $cn->exec_sql("delete from modeledef where mod_id=" . $l_id);
 
 				exit;
@@ -115,6 +115,7 @@ if (isset($_POST["FMOD_NAME"]))
 	$Res = $cn_mod->exec_sql("delete from del_jrn");
 	$Res = $cn_mod->exec_sql("delete from del_jrnx");
 	$Res = $cn_mod->exec_sql("truncate table  jrnx cascade ");
+	$Res = $cn_mod->exec_sql("truncate table  todo_list cascade ");
 	$Res = $cn_mod->exec_sql("delete from del_action");
 	$Res = $cn_mod->exec_sql("delete from profile_user");
 	$Res = $cn_mod->exec_sql("delete from jnt_letter");
@@ -200,16 +201,29 @@ if (isset($_POST["FMOD_NAME"]))
 		$Res = $cn_mod->exec_sql('delete from poste_analytique');
 		$Res = $cn_mod->exec_sql('delete from plan_analytique');
 	}
+        if ( isset ($_POST['PLUGIN'])) {
+            $a_schema=$cn_mod->get_array("
+                select nspname from pg_namespace 
+                where
+                nspname not like 'pg_%'
+                and nspname not in ('information_schema','public','comptaproc')
+                    ");      
+            $nb_schema=count($a_schema);
+            for ($i=0;$i < $nb_schema;$i++)
+            {
+                $cn_mod->exec_sql(" drop schema ".$a_schema[$i]['nspname']." cascade");
+            }
+        }
 
 }
 // Show all available templates
-require_once('class_sort_table.php');
+require_once NOALYSS_INCLUDE.'/class_sort_table.php';
 $url=$_SERVER['PHP_SELF']."?sa=list&action=".$_REQUEST['action'];
 
 $header=new Sort_Table();
-$header->add("id",$url," order by mod_id asc"," order by mod_id desc","ia","id");
-$header->add("Nom",$url," order by mod_name asc"," order by mod_name desc","na","nd");
-$header->add("Description",$url," order by mod_desc asc"," order by mod_desc desc","da","dd");
+$header->add(_("id"),$url," order by mod_id asc"," order by mod_id desc","ia","id");
+$header->add(_("Nom"),$url," order by mod_name asc"," order by mod_name desc","na","nd");
+$header->add(_("Description"),$url," order by mod_desc asc"," order by mod_desc desc","da","dd");
 
 $ord=(isset($_REQUEST['ord']))?$_REQUEST['ord']:'na';
 $sql_order=$header->get_sql_order($ord);
@@ -219,20 +233,20 @@ $Res = $cn->exec_sql("select mod_id,mod_name,mod_desc from
 
 $count = Database::num_row($Res);
 echo '<div class="content" style="width:80%;margin-left:10%">';
-echo "<H2>Modèles</H2>";
+echo "<H2>"._('Modèles')."</H2>";
 if ($sa == 'list')
 {
+        echo '<p>';
+        echo HtmlInput::button(_('Ajouter'),_('Ajouter un modèle')," onclick=\$('folder_add_id').show()");
+
+        echo '</p>';
 	if ($count == 0)
 	{
-		echo "Aucun modèle disponible";
+		echo _("Aucun modèle disponible");
 	}
 	else
 	{
 
-                echo '<p>';
-		echo HtmlInput::button_anchor('Rafra&icirc;chir', 'admin_repo.php?action=modele_mgt');
-		echo HtmlInput::button_anchor('Ajouter', 'admin_repo.php?action=modele_mgt&sa=add');
-                echo '</p>';
 		echo '<span style="display:block;margin-top:10">';
 		echo _('Filtre').HtmlInput::infobulle(23);
 		echo HtmlInput::filter_table("t_modele", "0,1,2","1");
@@ -242,6 +256,7 @@ if ($sa == 'list')
 				"<TH>".$header->get_header(0)."</TH>" .
 				"<TH>".$header->get_header(1)."</TH>" .
 				"<TH>".$header->get_header(2)."</TH>" .
+				"<TH>"._('Nom base de données')."</TH>" .
 		"<th> </th>" .
 		"<th> </th>" .
 		"</TR>";
@@ -250,30 +265,35 @@ if ($sa == 'list')
 		{
 			$mod = Database::fetch_array($Res, $i);
 			$class = ($i % 2 == 0) ? "odd" : "even";
+                        $str_name=domaine.'mod'.$mod['mod_id'];
 			printf('<TR class="' . $class . '" style="vertical-align:top">' .
 					'<TD>%d </td><td><b> %s</b> </TD>' .
 					'<TD><I> %s </I></TD>' .
+                                        '<td>'.$str_name.'</td>'.
 					'<td> ' .
-					HtmlInput::button_anchor('Effacer', '?action=modele_mgt&sa=del&m=' . $mod['mod_id']) . '</td>' .
+					HtmlInput::anchor(_('Effacer'), '?action=modele_mgt&sa=del&m=' . $mod['mod_id']," onclick = \"modele_drop('{$mod['mod_id']}') \"") . '</td>' .
 					'</td>' .
-					'<td>' . HtmlInput::button_anchor('Modifie', '?action=modele_mgt&sa=mod&m=' . $mod['mod_id']) . '</td>' .
+					'<td>' . HtmlInput::anchor(_('Modifie'), '?action=modele_mgt&sa=mod&m=' . $mod['mod_id']," onclick = \"modele_modify('{$mod['mod_id']}') \"") . '</td>' .
 					'</td>' .
-					'<td>' . HtmlInput::button_anchor('Backup', 'backup.php?action=backup&sa=b&t=m&d='
+					'<td>' . HtmlInput::anchor(_('Backup'), 'backup.php?action=backup&sa=b&t=m&d='
 							. $mod['mod_id']) . '</td>' .
 					'</TR>', $mod['mod_id'], $mod['mod_name'], $mod['mod_desc']);
 		}// for
 		echo "</table>";
 	}// if count = 0
-	echo "<p class=\"notice\">Si vous voulez r&eacute;cup&eacute;rer toutes les adaptations d'un dossier " .
+	echo "<p class=\"notice\">"._("Si vous voulez r&eacute;cup&eacute;rer toutes les adaptations d'un dossier " .
 	" dans un autre dossier, vous pouvez en faire un modèle." .
 	" Seules les fiches, la structure des journaux, les p&eacute;riodes,... seront reprises " .
-	"et aucune donn&eacute;e du dossier sur lequel le dossier est bas&eacute;. Les données contenues dans les extensions ne sont pas effacées</p>";
+	"et aucune donn&eacute;e du dossier sur lequel le dossier est bas&eacute;. Les données contenues dans les extensions ne sont pas effacées")."</p>";
 }
+?>
+<div id="folder_add_id" class="inner_box" style="display:none;top:50px">
+    <?php
+        echo HtmlInput::title_box(_("Ajout d'un modèle"), 'folder_add_id', "hide");
+
 //---------------------------------------------------------------------------
 // Add a template
 //---------------------------------------------------------------------------
-if ($sa == 'add')
-{
 // Show All available folder
 	$Res = $cn->exec_sql("select dos_id, dos_name,dos_description from ac_dossier
                        order by dos_name");
@@ -293,91 +313,41 @@ if ($sa == 'add')
 	<form action="admin_repo.php?action=modele_mgt" METHOD="post">
 		<TABLE>
 			<tr>
-				<td>Nom </TD>
-				<TD><INPUT TYPE="TEXT" VALUE="" NAME="FMOD_NAME"></TD>
+				<td><?php echo _('Nom')?> </TD>
+				<TD><INPUT TYPE="TEXT"  class="input_text"  VALUE="" NAME="FMOD_NAME"></TD>
 			</TR>
 			<TR>
-				<TD>Description</TD>
-				<TD><TEXTAREA ROWS="2" COLS="60" NAME="FMOD_DESC"></Textarea></TD>
-																							</TR>
-																							<TR>
-																							<TD> Bas&eacute;
-	sur </TD>
+				<TD><?php echo _('Description')?></TD>
+				<TD><TEXTAREA ROWS="2" class="input_text"  COLS="60" NAME="FMOD_DESC"></Textarea></TD>
+                        </TR>
+                        <TR>
+                        <TD> <?php echo _("Bas&eacute; sur")?> </TD>
 	<TD> <?php echo $available?></TD>
 	</TR>
 	<TR>
-		<TD>Nettoyage des Documents et courriers (ce qui  n'effacera pas les modèles de documents)</TD>
+		<TD><?php echo _("Nettoyage des Documents et courriers (ce qui  n'effacera pas les modèles de documents)")?></TD>
 		<TD> <input type="checkbox" name="DOC"></TD></TR>
 	<TR>
-		<TD>Nettoyage de toutes les fiches (ce qui effacera client,
-	op&eacute;rations pr&eacute;d&eacute;finies fournisseurs modèles de documents et documents)</TD>
+		<TD><?php echo _("Nettoyage de toutes les fiches (ce qui effacera client,
+	op&eacute;rations pr&eacute;d&eacute;finies fournisseurs modèles de documents et documents)")?></TD>
 		<TD> <input type="checkbox" name="CARD"></TD>
 	</TR>
 
 	<TR>
-		<TD>Nettoyage de la comptabilit&eacute; analytique : effacement des plans et des postes, les op&eacute;rations
-	sont de toute fa&ccedil;on effac&eacute;es </TD>
-		<TD> <input type="checkbox" name="CANAL"></TD>
+		<TD><?php echo _("Nettoyage de la comptabilit&eacute; analytique : effacement des plans et des postes, les op&eacute;rations
+	sont de toute fa&ccedil;on effac&eacute;es")?> </TD>
+		<TD> <input class="input_text" type="checkbox" name="CANAL"></TD>
+	</TR>
+	<TR>
+		<TD><?php echo _("Effacement de toutes les donn&eacute;es des plugins")?></TD>
+		<TD> <input type="checkbox" name="PLUGIN"></TD>
 	</TR>
 	</TABLE>
-
-		            '
-
-		            <INPUT TYPE="SUBMIT" class="button" VALUE="Ajout d'un modele">
-				<?php
-				echo HtmlInput::button_anchor('Retour', '?action=modele_mgt');
-				?>
-
-		            </form>
+  <INPUT TYPE="SUBMIT" class="button" VALUE="<?php echo _("Ajout d'un modele")?>" >
+</form>
+</div>
 		<?php
-	}
-	//---------------------------------------------------------------------------
-	// Modify
-	if ($sa == 'mod' && isset($_GET['m']))
-	{
-		$cn = new Database();
-
-		echo '<form method="post">';
-		$name = $cn->get_value(
-				"select mod_name from modeledef where " .
-				" mod_id=$1", array($_GET['m']));
-
-		$desc = $cn->get_value(
-				"select mod_desc from modeledef where " .
-				" mod_id=$1", array($_GET['m']));
-		$wText = new IText();
-		echo 'Nom : ' . $wText->input('name', $name);
-		$wDesc = new ITextArea();
-		$wDesc->heigh = 5;
-		echo '<br>Description :<br>';
-		echo $wDesc->input('desc', $desc);
-		echo HtmlInput::hidden('m', $_GET['m']);
-		echo HtmlInput::hidden('action', 'modele_mgt');
-		echo '<br>';
-		echo HtmlInput::button_anchor('Retour', '?action=modele_mgt');
-		echo HtmlInput::submit('upd', 'Modifie');
-		echo '</form>';
-	}
-
-	//---------------------------------------------------------------------------
-	// action = del
-	//---------------------------------------------------------------------------
-	if ($sa == 'del')
-	{
-		$cn = new Database();
-		$name = $cn->get_value('select mod_name from modeledef where mod_id=$1', array($_REQUEST['m']));
-		echo '<form method="post">';
-		echo HtmlInput::hidden('d', $_REQUEST['m']);
-		echo HtmlInput::hidden('sa', 'remove');
-		echo '<h2 class="error">Etes vous sure et certain de vouloir effacer ' . $name . ' ???</h2>';
-		$confirm = new ICheckBox();
-		$confirm->name = "p_confirm";
-		echo 'Cochez la case si vous êtes sûr de vouloir effacer ce modèle';
-		echo $confirm->input();
-		echo HtmlInput::submit('remove', 'Effacer');
-		echo HtmlInput::button_anchor('Retour', '?action=modele_mgt');
-		echo '</form>';
-	}
+	
 	//---------------------------------------------------------------------------
 	// action = del
 	//---------------------------------------------------------------------------
@@ -385,8 +355,8 @@ if ($sa == 'add')
 	{
 		if (!isset($_REQUEST['p_confirm']))
 		{
-			echo('Désolé, vous n\'avez pas coché la case');
-			echo HtmlInput::button_anchor('Retour', '?action=modele_mgt');
+			echo _('Désolé, vous n\'avez pas coché la case');
+			echo HtmlInput::button_anchor(_('Retour'), '?action=modele_mgt');
 			return;
 		}
 
@@ -404,16 +374,17 @@ if ($sa == 'add')
 		{
 			ob_end_clean();
 
-			echo "<h2 class=\"error\">
-	Base de donnée " . domaine . "mod" . $_REQUEST['m'] . "  est accèdée, déconnectez-vous d'abord</h2>";
+			echo "<h2 class=\"error\">";
+                        printf (_("Base de donnée %s mod %s est accèdée, déconnectez-vous d'abord"),domaine,$_REQUEST['m'] )
+                                . "</h2>";
 			exit;
 		}
 		ob_flush();
 		$sql = "delete from modeledef where mod_id=$1";
 		$cn->exec_sql($sql, array($_REQUEST['m']));
 		print '<h2 class="error">';
-		print "Le modèle $name est effacé</H2>";
-		echo HtmlInput::button_anchor('Retour', '?action=modele_mgt');
+		printf (_("Le modèle %s est effacé")."</H2>",$name );
+		echo HtmlInput::button_anchor(_('Retour'), '?action=modele_mgt');
 	}
 	echo '</div>';
 	?>
