@@ -25,8 +25,8 @@
  * \brief to write into the ledgers ODS a new operation
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once 'class_pre_op_ods.php';
-require_once 'class_iconcerned.php';
+require_once NOALYSS_INCLUDE.'/class_pre_op_ods.php';
+require_once NOALYSS_INCLUDE.'/class_iconcerned.php';
 
 global $g_user,$g_parameter;
 $cn=new Database(dossier::id());
@@ -65,17 +65,17 @@ if ( isset ($_GET['action']) && ! isset($_POST['correct']))
 {
 	if ( $_GET['action']=='use_opd')
 	{
-		// get data from predef. operation
-		$op=new Pre_op_advanced($cn);
-        $p_post=null;
-        if ( isset($_REQUEST['pre_def']) && $_REQUEST['pre_def'] != '')
-        {
-            $op->set_od_id($_REQUEST['pre_def']);
-            $p_post=$op->compute_array();
-        }
+            // get data from predef. operation
+            $op=new Pre_op_advanced($cn);
+            $p_post=null;
+            if ( isset($_REQUEST['pre_def']) && $_REQUEST['pre_def'] != '')
+            {
+                $op->set_od_id($_REQUEST['pre_def']);
+                $p_post=$op->compute_array();
+            }
 	}
 }
-
+$p_msg=(isset($p_msg))?$p_msg:"";
 print '<p class="notice">'.$p_msg.'</p>';
 echo '<form method="post"  class="print">';
 echo dossier::hidden();
