@@ -23,12 +23,12 @@
  * \brief Set the security for an user
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-include_once ("ac_common.php");
-require_once("class_iselect.php");
-require_once('class_dossier.php');
-include_once ("class_user.php");
-require_once('class_database.php');
-require_once 'class_sort_table.php';
+require_once  NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
+require_once  NOALYSS_INCLUDE.'/class_user.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_sort_table.php';
 
 $gDossier=dossier::id();
 $str_dossier=dossier::get();
@@ -39,7 +39,7 @@ global $g_user;
 $g_user->Check();
 $g_user->check_dossier($gDossier);
 
-include_once ("user_menu.php");
+require_once  NOALYSS_INCLUDE.'/user_menu.php';
 
 /////////////////////////////////////////////////////////////////////////
 // List users
@@ -61,17 +61,15 @@ if ( ! isset($_REQUEST['action']))
 
 
 	$repo=new Database();
-	/*  Show all the users, included local admin */
+	/*  Show all the active users, including admin */
 	$user_sql = $repo->exec_sql("select use_id,
                                             use_first_name,
                                             use_name,
                                             use_login,
-                                            use_admin,
-                                            priv_priv
-                                                from ac_users natural join jnt_use_dos " .
-                                               " join priv_user on (jnt_id=priv_jnt)
-					where use_login != 'phpcompta' and priv_priv <> 'X' and use_active=1
-					and dos_id=$1  " . $ord_sql, array($gDossier));
+                                            use_admin
+                                                from ac_users left join jnt_use_dos using (use_id)
+					where use_login != 'phpcompta' and use_active=1
+					and (dos_id=$1  or (dos_id is null and use_admin=1))" . $ord_sql, array($gDossier));
 
     $MaxUser = Database::num_row($user_sql);
 
@@ -89,10 +87,10 @@ if ( ! isset($_REQUEST['action']))
         $l_line=Database::fetch_array($user_sql,$i);
 
 
-		$str="";
-        $str=($l_line['priv_priv'] == 'R')?'Utilisateur Normal':$str;
+	$str="";
+        $str=_('Utilisateur Normal');
         if ( $l_line['use_admin'] == 1 )
-            $str=' Administrateur global';
+            $str=_('Administrateur');
 
 		// get profile
 		$profile=$cn->get_value("select p_name from profile
