@@ -23,12 +23,12 @@
  * \brief included file for managing the predefined operation
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_iselect.php");
-require_once("class_icheckbox.php");
-require_once("class_ihidden.php");
-require_once('class_database.php');
-require_once('ac_common.php');
-require_once('class_pre_operation.php');
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_icheckbox.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/ac_common.php';
+require_once NOALYSS_INCLUDE.'/class_pre_operation.php';
 
 /*
  * Value from $_GET or $_REQUEST
@@ -97,7 +97,7 @@ if ( $request_sa== 'jrn' )
         echo '<td>'.h($row['od_name']).'</td>';
         echo '<td>'.h($row['od_description']).'</td>';
         echo '<td>';
-	echo '<form method="POST" class="print" style="margin:0px;padding:0px;">';
+	echo '<form method="POST" id="preod_frm" class="print" style="margin:0px;padding:0px;">';
         echo dossier::hidden();
         echo $hid->input("sa","del");
         echo $hid->input("ac",$request_ac);
@@ -106,7 +106,7 @@ if ( $request_sa== 'jrn' )
         echo $hid->input("jrn",$get_jrn);
 
 	$b='<input type="submit" class="smallbutton" value="'._("Effacer").'"'.
-	  ' onClick="return confirm(\''._("Voulez-vous vraiment effacer cette operation ?").'\');" >';
+	  ' onClick="return confirm_box(\'preod_frm\',\''._("Voulez-vous vraiment effacer cette operation ?").'\');" >';
 	   echo $b;
 	   echo '</form>';
 
