@@ -23,16 +23,16 @@
  */
 if (!defined('ALLOWED'))
     die('Appel direct ne sont pas permis');
-include_once ("ac_common.php");
-include_once ("user_menu.php");
-require_once("class_ifile.php");
-require_once("class_ibutton.php");
-require_once('class_acc_report.php');
-require_once('class_dossier.php');
-require_once('class_database.php');
-include_once ("class_user.php");
-include_once ("user_menu.php");
-require_once('class_ipopup.php');
+require_once  NOALYSS_INCLUDE.'/ac_common.php';
+require_once  NOALYSS_INCLUDE.'/user_menu.php';
+require_once NOALYSS_INCLUDE.'/class_ifile.php';
+require_once NOALYSS_INCLUDE.'/class_ibutton.php';
+require_once NOALYSS_INCLUDE.'/class_acc_report.php';
+require_once NOALYSS_INCLUDE.'/class_dossier.php';
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once  NOALYSS_INCLUDE.'/class_user.php';
+require_once  NOALYSS_INCLUDE.'/user_menu.php';
+require_once NOALYSS_INCLUDE.'/class_ipopup.php';
 
 
 $gDossier=dossier::id();
