@@ -26,8 +26,8 @@
  *
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once 'class_stock_goods.php';
-require_once 'class_stock.php';
+require_once NOALYSS_INCLUDE.'/class_stock_goods.php';
+require_once NOALYSS_INCLUDE.'/class_stock.php';
 global $cn;
 
 $inv=new Stock_Goods($cn);
@@ -37,7 +37,7 @@ if ( isset ($_POST['save']))
 	try
 	{
 		$inv->record_save($_POST);
-		echo h2info("Opération sauvée");
+		echo h2info(_("Opération sauvée"));
 		$inv->input($_POST,true);
 
 	}catch(Exception $e)
