@@ -21,15 +21,15 @@
  * the supplier category
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once("class_iselect.php");
-require_once("class_ihidden.php");
-require_once("class_supplier.php");
-require_once("class_ibutton.php");
-require_once('class_iaction.php');
-require_once('class_fiche_def.php');
-require_once('class_iaction.php');
-require_once('class_fiche_def.php');
-require_once('class_ipopup.php');
+require_once NOALYSS_INCLUDE.'/class_iselect.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_supplier.php';
+require_once NOALYSS_INCLUDE.'/class_ibutton.php';
+require_once NOALYSS_INCLUDE.'/class_iaction.php';
+require_once NOALYSS_INCLUDE.'/class_fiche_def.php';
+require_once NOALYSS_INCLUDE.'/class_iaction.php';
+require_once NOALYSS_INCLUDE.'/class_fiche_def.php';
+require_once NOALYSS_INCLUDE.'/class_ipopup.php';
 global $g_user;
 
 $low_action=(isset($_REQUEST['sb']))?$_REQUEST['sb']:"list";
@@ -46,20 +46,22 @@ if ( $low_action  == "" )
 //-----------------------------------------------------
 // Remove a card
 //-----------------------------------------------------
-if ( isset($_POST['delete_card'] ) )
+if ( isset($_POST['action_fiche'] ) )
 {
-    if ( $g_user->check_action(FICADD) == 0 )
+    if ( $_POST['action_fiche'] == 'delete_card') 
     {
-        alert('Vous  ne pouvez pas enlever de fiche');
-        return;
+        if ( $g_user->check_action(FICADD) == 0 )
+        {
+            alert(_('Vous  ne pouvez pas enlever de fiche'));
+            return;
+        }
+
+        $f_id=$_REQUEST['f_id'];
+
+        $fiche=new Supplier($cn,$f_id);
+        $fiche->remove();
+        $low_action="list";
     }
-
-    $f_id=$_REQUEST['f_id'];
-
-    $fiche=new Supplier($cn,$f_id);
-    $fiche->remove();
-    $low_action="list";
-
 }
 
 //-----------------------------------------------------
@@ -78,13 +80,22 @@ if ( $low_action == "list" )
     $a=(isset($_GET['query']))?$_GET['query']:"";
     printf (_('Recherche').' <input class="input_text" type="text" name="query" value="%s">',
             $a);
-    $sel_card=new ISelect('cat');
-    $sel_card->value=$cn->make_array('select fd_id, fd_label from fiche_def '.
-                                     ' where  frd_id='.FICHE_TYPE_FOURNISSEUR.
-                                     ' order by fd_label ',1);
-    $sel_card->selected=(isset($_GET['cat']))?$_GET['cat']:-1;
-    $sel_card->javascript=' onchange="submit(this);"';
-    echo _('Catégorie :').$sel_card->input();
+    $choice_cat=HtmlInput::default_value_request("choice_cat", 1);
+    if ( $choice_cat == 1 )
+    {
+        $sel_card=new ISelect('cat');
+        $sel_card->value=$cn->make_array('select fd_id, fd_label from fiche_def '.
+                                         ' where  frd_id='.FICHE_TYPE_FOURNISSEUR.
+                                         ' order by fd_label ',1);
+        $sel_card->selected=(isset($_GET['cat']))?$_GET['cat']:-1;
+        $sel_card->javascript=' onchange="submit(this);"';
+        echo _('Catégorie :').$sel_card->input();
+    } else 
+    {
+        $cat=HtmlInput::default_value_request('cat', '');
+        echo HtmlInput::hidden("cat",$cat);
+        echo HtmlInput::hidden('choice_cat', 0);
+    }
     $nooperation=new ICheckBox('noop');
     $nooperation->selected=(isset($_GET['noop']))?true:false;
     echo _('Inclure les fournisseurs sans opération :').$nooperation->input();
@@ -142,7 +153,7 @@ if ( $low_action == "list" )
 if ( $low_action == 'detail')
 {
     /* Menu */
-    require_once('category_card.inc.php');
+    require_once NOALYSS_INCLUDE.'/category_card.inc.php';
     return;
 }
 
