@@ -7,11 +7,11 @@
 
 
     <table>
-			<tr>
+			<tr class="highlight">
             <TD>
 	    <?php echo _('N° document')?>
             </TD>
-            <TD class="highlight">
+            <TD >
               <?php echo $this->ag_id;?>
             </TD>
           </TR>
@@ -49,7 +49,10 @@
 	  <?php echo _('Contact')?>
           </TD>
           <TD>
-  <?php echo $ag_contact->search().$ag_contact->input();
+  <?php 
+  if  ($g_user->can_write_action($this->ag_id) == true ):
+    echo $ag_contact->search().$ag_contact->input();
+  endif;
             ?>
           </td>
           </Tr>
@@ -66,7 +69,10 @@
               <td id="concerned_card_td">
               <?php 
                     echo $this->display_linked();
-                    echo HtmlInput::button_action_add_concerned_card( $this->ag_id)?>
+                     if  ($g_user->can_write_action($this->ag_id) == true ):
+                        echo HtmlInput::button_action_add_concerned_card( $this->ag_id);
+                     endif;
+               ?>
               </td>
               <td>
 
@@ -130,7 +136,7 @@
           </TR>
           <tr>
             <TD>
-	    <?php echo _('Destinataire')?>
+	    <?php echo _('Groupe Gestion')?>
             </TD>
             <td>
               <?php echo $str_ag_dest;?>
@@ -187,11 +193,11 @@
 		{
 			if ( $p_view != 'READ' && $p_base != 'ajax')
 			{
-                            $rmAction=sprintf("javascript:if ( confirm('"._('Voulez-vous effacer cette action ')."')==true ) {remove_action('%s','%s','%s');}",
+                            $rmAction=sprintf("return confirm_box(null,'"._('Voulez-vous effacer cette action ')."', function () {remove_action('%s','%s','%s');});",
 					dossier::id(),
 					$action[$o]['ag_id'],$_REQUEST['ag_id']);
                             $showAction='<a class="line" href="'.$base."&ag_id=".$action[$o]['ag_id'].'">';
-                            $js= '<a class="tinybutton" id="acact'.$action[$o]['ag_id'].'" href="'.$rmAction.'">&#x2D5D;</a>';
+                            $js= '<a class="tinybutton" id="acact'.$action[$o]['ag_id'].'" href="javascript:void(0)" onclick="'.$rmAction.'">'.SMALLX.'</a>';
                             echo '<li id="act'.$action[$o]['ag_id'].'">'.$showAction.$action[$o]['str_date']." ".$action[$o]['ag_ref']." ".
 					h($action[$o]['sub_title']).'('.h($action[$o]['dt_value']).')</a>'." "
 				.$js.'</li>';
@@ -265,10 +271,10 @@ for( $c=0;$c<count($acomment);$c++){
 	<?php
         if ( $p_view != 'READ')
 	{
-		$rmComment=sprintf("javascript:if ( confirm('"._('Voulez-vous effacer ce commentaire')." ?')==true ) {remove_comment('%s','%s');}",
+		$rmComment=sprintf("return confirm_box(null,'"._('Voulez-vous effacer ce commentaire')." ?',function() {remove_comment('%s','%s');});",
 						dossier::id(),
 						$acomment[$c]['agc_id']);
-				$js= '<a class="tinybutton" id="accom'.$acomment[$c]['agc_id'].'" href="'.$rmComment.'">&#x2D5D;</a>';
+				$js= '<a class="tinybutton" id="accom'.$acomment[$c]['agc_id'].'" href="javascript:void(0)" onclick="'.$rmComment.'">'.SMALLX.'</a>';
 		echo hb('n°'.$acomment[$c]['agc_id'].'('.$acomment[$c]['tech_user']." ".$acomment[$c]['str_agc_date'].')').$js.
 				'<pre style="white-space: -moz-pre-wrap;white-space: pre-wrap;border:1px solid blue;width:80%;" id="com'.$acomment[$c]['agc_id'].'"> '.
 				" ".h($acomment[$c]['agc_comment']).'</pre>'
@@ -296,8 +302,8 @@ echo '</span>';
   </div>
 </div>
 <?php if ( $p_view !='READ'  ) :?>
-<input type='button' class="button" class="noprint" value='Montrer articles' id="toggleButton" onclick='toggleShowDetail()'>
-<input type='button' class="button" class="noprint" value='Générer' id="toggleButtonGenerate" onclick="$('div_generate_document').show()">
+<input type='button' class="button" class="noprint" value="<?php echo _('Montrer articles');?>" id="toggleButton" onclick='toggleShowDetail()'>
+<input type='button' class="button" class="noprint" value="<?php echo _('Générer')?>" id="toggleButtonGenerate" onclick="$('div_generate_document').show()">
 <?php endif; ?>
 <?php
 /**
@@ -372,10 +378,10 @@ function toggleShowDetail() {
 <?php if ( $show_row != 0 ): ?>
 <div>
   
-    <div style=" float:right;margin-right: 2px"" id="sum">
-    <br><span style="text-align: right;" class="highlight" id="htva">0.0</span>
-     <br><span style="text-align: right" class="highlight" id="tva">0.0</span>
-    <br><span style="text-align: right" class="highlight" id="tvac">0.0</span>
+    <div style=" float:right;margin-right: 2px" id="sum">
+    <br><span style="text-align: right;" class="highlight" id="htva"><?php echo bcsub($tot_item,$tot_vat) ?></span>
+     <br><span style="text-align: right" class="highlight" id="tva"><?php echo $tot_vat?></span>
+    <br><span style="text-align: right" class="highlight" id="tvac"><?php echo $tot_item?></span>
  </div>
 
     <div  style="float:right;margin-right: 230px" >
@@ -405,7 +411,7 @@ function toggleShowDetail() {
 <?php endif; ?>
 </div>
 <?php endif; ?>
-</div>
+
 <div style="clear:both"></div>    
 <?php if ($p_view != 'READ' && $str_select_doc != '') : ?>
 <div id="div_generate_document" class="noprint" style="display:none" >
@@ -456,14 +462,14 @@ for ($i=0;$i<sizeof($aAttachedFile);$i++) :
         <?php else: ?>
         </span>
         <?php endif;?>
-<?php $rmDoc=sprintf("javascript:if ( confirm('"._('Voulez-vous effacer le document')." %s')==true ) {remove_document('%s','%s');}",
+<?php $rmDoc=sprintf("return confirm_box(null,'"._('Voulez-vous effacer le document')." %s' , function(){remove_document('%s','%s');});",
 	$aAttachedFile[$i]['d_filename'],
 	dossier::id(),
 	$aAttachedFile[$i]['d_id']);
     ?>
         </td>
         <td>
-  <?php if ($p_view != 'READ') : ?>  <a class="line"  id="<?php echo "ac".$aAttachedFile[$i]['d_id'];?>" href="<?php echo $rmDoc;?>"><?php echo _("Effacer")?></a><?php endif;?>
+  <?php if ($p_view != 'READ') : ?>  <a class="line"  id="<?php echo "ac".$aAttachedFile[$i]['d_id'];?>" href="javascript:void(0)" onclick="<?php echo $rmDoc;?>"><?php echo _("Effacer")?></a><?php endif;?>
         </td>
   </tr>
   <?php
@@ -476,7 +482,7 @@ function addFiles() {
 try {
 	docAdded=document.getElementById('add_file');
 	new_element=document.createElement('li');
-	new_element.innerHTML='<input class="inp" type="file" value="" name="file_upload[]"/><br><label>Description</label><input type="input" class="input_text" name="input_desc[]" >';
+	new_element.innerHTML='<input class="inp" type="file" value="" name="file_upload[]"/><label>Description</label> <input type="input" class="input_text" name="input_desc[]" >';
 	docAdded.appendChild(new_element);
 }
 catch(exception) { alert('<?php echo j(_('Je ne peux pas ajouter de fichier'))?>'); alert(exception.message);}
@@ -500,4 +506,4 @@ catch(exception) { alert('<?php echo j(_('Je ne peux pas ajouter de fichier'))?>
  <?php endif;?>
 </div>
 </div>
-<script>compute_all_ledger()</script>
\ No newline at end of file
+<script>compute_all_ledger()</script>
