@@ -22,19 +22,20 @@
 <TR>
 <TD colspan='2'> <INPUT TYPE="CHECKBOX" NAME="create" CHECKED><?php echo _("Création automatique du poste comptable uniquement s'il n'y a qu'un seul poste")?></TD>
 </TR>
+</table>
+<h2>Modèles de catégorie</h2>
+<ul>
 <?php
   if ( sizeof($ref)  ) {
     foreach ($ref as $i=>$v) { ?>
-<TR><TD style="width:auto" COLSPAN="2">
+    <li style="list-style-type: none">
 <?php echo $iradio->input("FICHE_REF",$v['frd_id']);
    echo $v['frd_text'];
    if ( sizeof ($v['frd_class_base']) != 0 )
 	   echo "&nbsp;&nbsp<I>Class base = ".$v['frd_class_base']."</I>";
-      echo "</TD></TR>";
 
-    }
-
-  }
+    }?>
+    </li>
+  <?php }
 ?>
-
-</TABLE>
+</UL>
\ No newline at end of file
