@@ -47,7 +47,7 @@ if ( $div != "popup") :
     ?>
     <li class="<?php echo $class?>">
         <?php $div_tab_id=$a_value['id'];?>
-        <a href="javascript:void(0)" onclick="unselect_other_tab(this.parentNode.parentNode);var tab=Array('writing_div<?php echo $div?>','info_operation_div<?php echo $div?>','linked_operation_div<?php echo $div?>','document_operation_div<?php echo $div?>','linked_action_div<?php echo $div?>','analytic_div<?php echo $div?>');this.parentNode.className='tabs_selected' ;show_tabs(tab,'<?php echo $div_tab_id; ?>');"><?php echo $a_value['label']?></a>
+        <a href="javascript:void(0)" onclick="unselect_other_tab(this.parentNode.parentNode);var tab=Array('writing_div<?php echo $div?>','info_operation_div<?php echo $div?>','linked_operation_div<?php echo $div?>','document_operation_div<?php echo $div?>','linked_action_div<?php echo $div?>','analytic_div<?php echo $div?>');this.parentNode.className='tabs_selected' ;show_tabs(tab,'<?php echo $div_tab_id; ?>');"><?php echo _($a_value['label'])?></a>
     </li>
     <?php    endforeach; ?>
 </ul>
@@ -162,19 +162,20 @@ if ($aRap  != null ) {
     $opRap=new Acc_Operation($cn);
     $opRap->jr_id=$aRap[$e];
     $internal=$opRap->get_internal();
-    $array_jr=$cn->get_array('select jr_montant,jr_comment from jrn where jr_id=$1',array($aRap[$e]));
+    $array_jr=$cn->get_array('select jr_date,jr_montant,jr_comment from jrn where jr_id=$1',array($aRap[$e]));
     $amount=$array_jr[0]['jr_montant'];
     $str="modifyOperation(".$aRap[$e].",".$gDossier.")";
     $rmReconciliation=new IButton('rmr');
-    $rmReconciliation->label='&#x2D5D;';
+    $rmReconciliation->label=SMALLX;
     $rmReconciliation->class="tinybutton";
-    $rmReconciliation->javascript="if (confirm ('vous confirmez?') ) {";
-    $rmReconciliation->javascript.=sprintf('dropLink(\'%s\',\'%s\',\'%s\',\'%s\');deleteRowRec(\'%s\',this);}',
+    $rmReconciliation->javascript="return confirm_box(null,'"._("vous confirmez?")."',";
+    $rmReconciliation->javascript.=sprintf('function () { dropLink(\'%s\',\'%s\',\'%s\',\'%s\');deleteRowRec(\'%s\',$(\'row%d\'));})',
 					  $gDossier,
 					  $div,
 					  $jr_id,
 					   $aRap[$e],
-					   $tableid
+					   $tableid,
+                                          $e
 					  );
     if ( $access=='W')
       $remove=$rmReconciliation->input();
@@ -182,7 +183,11 @@ if ($aRap  != null ) {
       $remove='';
     
     $comment=strip_tags($array_jr[0]['jr_comment']);
-    echo tr (td('<a class="line" href="javascript:void(0)" onclick="'.$str.'" >'.$internal.'</A>').td(nbm($amount)).td($comment).td($remove));
+    echo tr (td(format_date($array_jr[0]['jr_date'])).
+            td('<a class="line" href="javascript:void(0)" onclick="'.$str.'" >'.$internal.'</A>').
+            td($comment).
+            td(nbm($amount)).
+            td($remove),' id = "row'.$e.'"');
   }
   echo '</table>';
 }
@@ -230,7 +235,7 @@ echo '</div>';
 
 <?php 
 
-require_once('template/ledger_detail_file.php');
+require_once NOALYSS_INCLUDE.'/template/ledger_detail_file.php';
 ?>
 
 
@@ -261,6 +266,7 @@ require_once('template/ledger_detail_file.php');
 
 <hr>
 <?php 
+      echo '<p style="text-align:center">';
 
 if ( $div != 'popup' ) {
   $a=new IButton('Fermer',_('Fermer'));
@@ -272,6 +278,7 @@ if ( $div != 'popup' ) {
 }
 
 ?>
+
 <?php 
 
 /**
@@ -281,14 +288,15 @@ if ( $div != 'popup' ) {
   echo HtmlInput::submit('save',_('Sauver'),'onClick="return verify_ca(\'popup\');"');
   $owner=new Own($cn);
   if ($owner->MY_ANALYTIC != 'nu' /*&& $div=='popup' */){
-    echo '<input type="button" class="button" value="'._('verifie CA').'" onClick="verify_ca(\''.$div.'\');">';
+    echo '<input type="button" class="smallbutton" value="'._('verifie CA').'" onClick="verify_ca(\''.$div.'\');">';
   }
 
   $per=new Periode($cn,$obj->det->jr_tech_per);
-  if ( $per->is_closed() == 0 && $owner->MY_STRICT=='N'){
+  if ( $per->is_closed() == 0 && $owner->MY_STRICT=='N' && $g_user->check_action(RMOPER)==1)
+  {
     $remove=new IButton('Effacer');
     $remove->label=_('Effacer');
-    $remove->javascript="if ( confirm('Vous confirmez effacement ?')) {removeOperation('".$obj->det->jr_id."',".dossier::id().",'".$div."')}";
+    $remove->javascript="return confirm_box(null,'Vous confirmez effacement ?',function () {removeOperation('".$obj->det->jr_id."',".dossier::id().",'".$div."')})";
     echo $remove->input();
   }
 
@@ -296,21 +304,31 @@ if ( $div != 'popup' ) {
   $reverse->label=_('Extourner');
   $reverse->javascript="g('ext".$div."').style.display='block'";
   echo $reverse->input();
-
+    echo '</p>';
 echo '</form>';
 
   echo '<div id="ext'.$div.'" class="inner_box" style="position:relative;top:-150px;display:none">';
   $date=new IDate('ext_date');
-  $r="<form id=\"form_".$div."\" onsubmit=\"this.divname='$div';return reverseOperation(this);\">";
-  $r.=HtmlInput::hidden('jr_id',$_REQUEST['jr_id']).HtmlInput::hidden('div',$div).dossier::hidden().HtmlInput::hidden('act','reverseop');
+  $r="<form id=\"form_".$div."\" onsubmit=\"return false;\">";
+  $r.=HtmlInput::hidden('jr_id',$_REQUEST['jr_id'])
+      . HtmlInput::hidden('div',$div).dossier::hidden().HtmlInput::hidden('act','reverseop');
   $r.=HtmlInput::title_box(_('Extourner'), 'ext'.$div, 'hide');
-  $r.="entrez une date :".$date->input();
-  $r.=HtmlInput::submit('x','accepter','onclick="return confirm(\'Vous confirmez  ? \');"');
+  $r.="<p>";
+  $r.= _("Extourner une opération vous permet de l'annuler par son écriture inverse");
+  $r.="</p>";
+
+  $r.=_("entrez une date")." :".$date->input();
+    $r.='<p  style="text-align:center">';
+  $r.=HtmlInput::submit('x','accepter',
+          'onclick="confirm_box($(\'form_'.$div.'\'),\'Vous confirmez  ? \',function () {$(\'form_'.$div.'\').divname=\''.$div.'\';reverseOperation($(\'form_'.$div.'\'))}); return false"');
+    $r.="</p>";
   $r.='</form>';
   echo $r;
   echo '</div>';
 
 
 
+}else {
+    echo '</p>';
 }
 ?>
