@@ -2,13 +2,13 @@
 //This file is part of NOALYSS and is under GPL 
 //see licence.txt
 $str_anc="";
-?><?php require_once('template/ledger_detail_top.php'); ?>
+?><?php require_once NOALYSS_INCLUDE.'/template/ledger_detail_top.php'; ?>
 <div class="content" style="padding:0;">
 <?php 
-  require_once('class_own.php');
+  require_once NOALYSS_INCLUDE.'/class_own.php';
   $owner=new Own($cn);
-require_once ('class_anc_plan.php');
-require_once('class_anc_operation.php');
+require_once  NOALYSS_INCLUDE.'/class_anc_plan.php';
+require_once NOALYSS_INCLUDE.'/class_anc_operation.php';
 
 ?>
     <?php if ( $access=='W') : ?>
@@ -141,6 +141,6 @@ echo td(_('Pièce')).td($itext->input());
 ?>
 </div>
 <?php 
-require_once 'ledger_detail_bottom.php';
+require_once NOALYSS_INCLUDE.'/template/ledger_detail_bottom.php';
 ?>
 </div>
\ No newline at end of file
