@@ -49,9 +49,26 @@
 }// end function
 
 ?>
-			<?php   $array=$cn->get_array("select ac_id, ac_description from action  where ac_id >=$1 and ac_id <=$2 order by ac_id ",
-				array(800,1000));
-                                display_security_fieldset(_('Fiche'),$array,$sec_User); ?>
-                        <?php   $array=$cn->get_array("select ac_id, ac_description from action  where ac_id >=$1 and ac_id <=$2 order by ac_id ",
-				array(1001,1100));
-                                display_security_fieldset(_('Suivi'),$array,$sec_User); ?>
+<?php  
+// Security Card
+$array=$cn->get_array("select ac_id, ac_description from action  where ac_id >=$1 and ac_id <=$2 order by ac_id ",
+    array(800,1000));
+    display_security_fieldset(_('Fiche'),$array,$sec_User); ?>
+<?php   
+// Security follow-up
+$array=$cn->get_array("select ac_id, ac_description from action  where ac_id >=$1 and ac_id <=$2 order by ac_id ",
+    array(1001,1100));
+    display_security_fieldset(_('Suivi'),$array,$sec_User); ?>
+
+<?php
+// Security Accountancy
+ $array=$cn->get_array("select ac_id, ac_description from action  where ac_id >=$1 and ac_id <=$2 order by ac_id ",
+    array(1101,1200));
+    display_security_fieldset(_('Comptabilité'),$array,$sec_User); ?>
+
+<?php
+// Note Sharing
+ $array=$cn->get_array("select ac_id, ac_description from action  where ac_id >=$1 and ac_id <=$2 order by ac_id ",
+    array(1200,1300));
+    display_security_fieldset(_('Note'),$array,$sec_User); 
+?>
