@@ -28,7 +28,7 @@
  */
 ?>
 <div style="<?php if ( ! $p_readonly) echo "position:absolute";?>" class="content">
-	<form method="POST" class="print" onsubmit="return confirm('<?php echo _("Vous confirmez ?")?>')">
+	<form method="POST" id="stock_reprise" class="print" onsubmit="return confirm_box(this,'<?php echo _("Vous confirmez ?")?>')">
 <table>
 	<tr><td>
 			<?php echo _("Date")?>
@@ -100,7 +100,7 @@
 	</tr>
 <?php endfor; ?>
 </table>
-<?php if ($p_readonly == false) echo HtmlInput::button_action(_('Ajouter une ligne'),'stock_add_row();','smallbutton')?>
+<?php if ($p_readonly == false) echo HtmlInput::button_action(_('Ajouter une ligne'),'stock_add_row();',"xx",'smallbutton')?>
 <?php if ($p_readonly == false) echo HtmlInput::submit('save',_('Sauver'))?>
 <?php if ($p_readonly == false) echo HtmlInput::hidden('row',$nb)?>
 <?php if ($p_readonly == false) echo HtmlInput::button("reprise_show",_('Reprise inventaire'),  " onclick=\"$('reprise_inventaire_div').show();\"")?>
@@ -128,6 +128,7 @@
             </td>
         </tr>
     </table>
-        <?php echo HtmlInput::submit("reprise_frm", _('Reprise inventaire'));?>
+        <?php echo HtmlInput::hidden('reprise_frm',1);?>
+        <?php echo HtmlInput::submit("reprise_frm_bt", _('Reprise inventaire'));?>
      </form>
 </div>
