@@ -23,11 +23,11 @@
 
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
 
-require_once('class_database.php');
-require_once("class_icheckbox.php");
-require_once("class_ihidden.php");
-require_once("class_document.php");
-require_once("class_acc_operation.php");
+require_once NOALYSS_INCLUDE.'/class_database.php';
+require_once NOALYSS_INCLUDE.'/class_icheckbox.php';
+require_once NOALYSS_INCLUDE.'/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class_document.php';
+require_once NOALYSS_INCLUDE.'/class_acc_operation.php';
 /*! \file
  * \brief Common functions
  */
@@ -211,6 +211,9 @@ function CleanUrl()
 }
 function redirect($p_string,$p_time=0)
 {
+    if (strpos( $p_string,'?') == 0 ) {
+        $p_string = $p_string.'?v='.microtime(true);
+    }
     echo '<HTML><head><META HTTP-EQUIV="REFRESH" content="'.$p_time.';url='.$p_string.'"></head><body> Connecting... </body></html>';
 }
 /*!\brief remove the useless space, change comma by period and try to return
